
# set this to be the directory where the files are
dir1 <- "D:\\Research\\EconMedia\\paper\\bias\\rep\\"

# Set the flag below to true if you would like to replicate tables A12-A15, which compute p-values
# using the wild-bootstrap. Since the wild-bootstrap is computationally complex, it is
# implemented using a dll compiled in c++. Since dll's are operating-system specific,
# this will only work in 64-bit windows
win64 <- FALSE

# load an r library, downloading if necesary
library0 <- function(s)
{
	if(s %in% rownames(installed.packages()) == FALSE)
	{
		if(s=="readxl") {
			install.packages(paste(dir1,"readxl_1.3.1.tar.gz",sep=""))
		} else if(s=="fastmatch") {
			install.packages(paste(dir1,"fastmatch_1.1-0.tar.gz",sep=""))
		} else if(s=="Formula") {
			install.packages(paste(dir1,"Formula_1.2-3.tar.gz",sep=""))
		} else if(s=="stringr") {
			install.packages(paste(dir1,"stringr_1.4.0.tar.gz",sep=""))
		} else if(s=="numDeriv") {
			install.packages(paste(dir1,"",sep="numDeriv_2016.8-1.1.tar.gz"))
		} else {
			install.packages(s,repos='http://cran.us.r-project.org')
		}
	}	
	require(s,character.only=TRUE)
}

# load some library
library0("readxl")
library0("fastmatch")
library0("Formula") # for formulas with multiple parts
library0("stringr")
library0("numDeriv") # for numerical derivatives
library0("MASS")

# various function definitions

dig <- function(x,k=3)
{
	y <- format(round(x,k),nsmall=k)
	for(i in 1:length(y)) {
		if(is.na(x[i])) y[i] <- ""
	}
	y
}

dig2 <- function(x) { dig(x,2) }
dig3 <- function(x) { dig(x,3) }

pval <- function(est,se) { 2*pnorm(-abs(est/se)) }

stars.scalar <- function(coef,se)
{
	if(is.na(coef)) {
		""
	} else if(is.na(se)) {
		"?"
	} else {
		pval1 <- pval(coef,se)
		if(pval1 <= 0.001) {
			"***"
		} else if(pval1 <= 0.01) {
			"**"
		} else if(pval1 <= 0.05) {
			"*"
		} else if(pval1 <= 0.1) {
			"+"
		} else {
			""
		}
	}
}

stars <- function(coef,se)
{
	if(is.matrix(coef))
	{
		m <- nrow(coef)
		n <- ncol(coef)
		res <- coef
		for(i in 1:m) for(j in 1:n) res[i,j] <- stars.scalar(coef[i,j],se[i,j])
	} else {
		m <- length(coef)
		res <- coef
		for(i in 1:m) res[i] <- stars.scalar(coef[i],se[i])
	}
	res
}

stars.pval <- function(pval1)
{
	n <- length(pval1)
	ret <- rep(NA,n)
	for(i in 1:n)
	{
		if(pval1[i] <= 0.001) {
			ret[i] <- "***"
		} else if(pval1[i] <= 0.01) {
			ret[i] <- "**"
		} else if(pval1[i] <= 0.05) {
			ret[i] <- "*"
		} else if(pval1[i] <= 0.1) {
			ret[i] <- "+"
		} else {
			ret[i] <- ""
		}
	}
	ret
}

as.coef <- function(coef,se,k=3,p.val=logical(0))
{
	if(length(p.val) == 0) {
		if(is.matrix(coef)) {
			res <- coef
			for(i in 1:ncol(coef)) res[,i] <- paste(dig(coef[,i],k),stars(coef[,i],se[,i]),sep="")
			res
		} else {
			paste(dig(coef,k),stars(coef,se),sep="")
		}
	} else {
		if(is.matrix(coef)) {
			res <- coef
			for(i in 1:ncol(coef)) res[,i] <- paste(dig(coef[,i],k),stars.pval(coef[,i],p.val[,i]),sep="")
			res
		} else {
			paste(dig(coef,k),stars.pval(p.val),sep="")
		}
	}
}

as.se <- function(se,k=3)
{
	if(is.matrix(se)) {
		res <- se
		for(i in 1:ncol(se)) res[,i] <- str_replace_all(paste("(",dig(se[,i],k),")",sep=""),"\\(\\)","")
		res
	} else {
		str_replace_all(paste("(",dig(se,k),")",sep=""),"\\(\\)","")
	}
}

pval.as.pval <- function(pval,k=3) { paste(dig(pval,k),stars.pval(pval),sep="") }

panel.lag <- function(x,time,id,lags=1)
{
	n <- length(x)
	ids <- sort(unique(id))
	m <- length(ids)
	p <- length(lags)
	xlag <- matrix(rep(NA,n*p),ncol=p)
	xs <- list()
	times <- list()
	for(i in 1:m)
	{
		xs[[i]] <- x[id==ids[i]]
		times[[i]] <- time[id==ids[i]]
	}
	for(i in 1:n)
	{
		j <- fmatch(id[i],ids)
		k <- fmatch(time[i]-lags,times[[j]])
		for(l in 1:length(k))
		if(!is.na(k[l])) {
			xlag[i,l] <- xs[[j]][k[l]]
		}
	}
	xlag
}

apply0 <- function(func1,x,subset=numeric(0),by=numeric(0),bys=numeric(0),...)
{
	if(length(subset) == 0) {
		x1 <- subset(x,!is.na(x))
		if(length(by) != 0) by1 <- subset(by,!is.na(x))
	} else if(length(subset) != length(x)) {
		# Error
		stop("Incompadible Dimensions")
	} else {
		x1 <- subset(x,subset&!is.na(x))
		if(length(by) != 0) by1 <- subset(by,subset&!is.na(x))
	}
	if(length(x1) == 0) {
		NA
	} else {
		if(length(by) == 0) {
			func1(x1,...)
		} else {
			if(length(bys) == 0) bys <- sort(unique(by1))
			dat1 <- cbind(x1,by1)[order(by1),]
			J <- length(unique(by1))
			start <- rep(NA,J)
			start[1] <- 1
			tab1 <- table(by1)
			if(J > 1) {
				for(j in 2:J) start[j] <- start[j-1] + tab1[j-1]
				end <- c(start[2:J]-1,length(x1))
			} else {
				end <- length(x)
			}
			ret <- rep(NA,length(bys))
			for(j in 1:J) {
				k <- fmatch(dat1[start[j],2],bys)
				if(!is.na(k)) ret[k] <- func1(as.numeric(dat1[start[j]:end[j],1]),...)
			}
			names(ret) <- bys
			ret
		}
	}
}

inv.logit <- function(x) { exp(x) / (1 + exp(x)) }

mean0 <- function(x,w=numeric(0),subset=numeric(0),by=numeric(0),bys=numeric(0),se=FALSE,ci=FALSE)
{
	n <- length(x)
	if(length(subset) != 0 & length(subset) != n) stop("error in mean0 -- incompadible dimensions (subset)")
	if(length(w) != 0 & length(w) != n) stop("error in mean0 -- incompadible dimensions (w)")
	if(!se & !ci) {
		if(length(w) == 0) {
			apply0(mean,x,subset,by,bys)
		} else {
			if(length(subset) == 0) {
				subset1 <- !is.na(x) & !is.na(w)
			} else {
				subset1 <- !is.na(x) & !is.na(w) & subset
			}
			apply0(mean,w*x,subset1,by,bys) / apply0(mean,w,subset1,by,bys)
		}
	} else {
		ret <- list()
		if(length(w) == 0) {
			ret$est <- apply0(mean,x,subset,by,bys)
			se1 <- ret$se <- (var0(x,subset,by,bys) / n0(x,subset,by,bys))^.5
		} else {
			if(length(subset) == 0) {
				subset1 <- !is.na(x) & !is.na(w)
			} else {
				subset1 <- !is.na(x) & !is.na(w) & subset
			}
			W = apply0(sum,w,subset1,by,bys)
			ret <- list()
			ret$est <- apply0(sum,w*x,subset1,by,bys) / W 
			se1 <- (var0(w*x,subset1,by,bys) * n0(w*x,subset1,by,bys) / W^2)^.5
		}
		if(se) ret$se <- se1
		if(ci) ret$ci <- c(ret$est - 1.96 * se1,ret$est + 1.96 * se1)
		ret
	}
}

median0 <- function(x,subset=numeric(0),by=numeric(0),bys=numeric(0),se=FALSE)
{
	if(!se) {
		apply0(median,x,subset,by,bys)
	} else {
		list(est=apply0(median,x,subset,by,bys),se=apply0(medianse,x,subset,by,bys))
	}
}

quantile0 <- function(x,probs,subset=logical(0),by=numeric(0),bys=numeric(0))
{
	n <- length(x)
	if(length(subset) != 0 & length(subset) != n) stop("error in quantile0 -- incompadible dimensions (subset)")
	k <- length(probs)
	if(length(by) == 0) {
		m <- 1
	} else {
		if(length(bys) == 0) bys <- sort(unique(by))
		m <- length(bys)
	}
	ret <- matrix(rep(NA,m*k),nrow=m)
	for(i in 1:k) ret[,i] <- apply0(quantile,x,subset,by,bys,probs=probs[i])
	rownames(ret) <- bys
	colnames(ret) <- probs
	ret
}

max0 <- function(x,subset=numeric(0),by=numeric(0),bys=numeric(0)) { apply0(max,x,subset,by,bys) }
min0 <- function(x,subset=numeric(0),by=numeric(0),bys=numeric(0)) { apply0(min,x,subset,by,bys) }
sum0 <- function(x,subset=numeric(0),by=numeric(0),bys=numeric(0)) { apply0(sum,x,subset,by,bys) }

sd0 <- function(x,subset=numeric(0),by=numeric(0),bys=numeric(0))
{
	if(length(subset) == 0) {
		subset1 <- subset(x,!is.na(x))
		if(length(by) != 0) by1 <- subset(by,!is.na(x))
	} else if(length(subset) != length(x)) {
		# Error
		stop("Incompadible Dimensions")
	} else {
		subset1 <- subset(x,subset&!is.na(x))
		if(length(by) != 0) by1 <- subset(by,subset&!is.na(x))
	}
	if(length(subset1) == 0) {
		NA
	} else {
		if(length(by) == 0) {
			sd(subset1)
		} else {
			if(length(bys) == 0) bys <- sort(unique(by1))
			n <- length(bys)
			ret <- rep(NA,n)
			for(i in 1:n)
			{
				if(length(subset(subset1,by1==bys[i])) > 0) {
					ret[i] <- sd(subset(subset1,by1==bys[i]))
				}
			}
			names(ret) <- bys
			ret
		}
	}
}

cor0 <- function(x,y,w=logical(0),subset=logical(0),by=logical(0),bys=logical(0),x.se=logical(0),y.se=logical(0))
{
	if(length(by) == 0)
	{
		if(length(subset) == 0) {
			if(length(w) == 0) {
				if(length(x.se) == 0) Rx <- 1
				else                  Rx <- (var0(x) - mean0(x.se^2)) / var0(x)
				if(length(y.se) == 0) Ry <- 1
				else                  Ry <- (var0(y) - mean0(y.se^2)) / var0(y)
				if(Rx <= 0) stop(paste("error in cor0 -- Rx < 0. Rx =",Rx))
				if(Rx <= 0) stop(paste("error in cor0 -- Ry < 0. Ry =",Ry))
				cor(x,y,use="pairwise") / sqrt(Rx * Ry)
			} else {
				subset <- !is.na(x) & !is.na(y) & !is.na(w)
				x0 <- subset(x,subset)
				y0 <- subset(y,subset)
				w0 <- subset(w,subset)
				if(length(x.se) > 0) x.se0 <- subset(x.se,subset)
				if(length(y.se) > 0) y.se0 <- subset(y.se,subset)
				if(length(x.se) == 0) Rx <- 1
				else                  Rx <- (var(x0) - mean0(x.se0^2)) / var(x0)
				if(length(y.se) == 0) Ry <- 1
				else                  Ry <- (var(y0) - mean0(y.se0^2)) / var(y0)
				if(Rx <= 0) stop(paste("error in cor0 -- Rx < 0. Rx =",Rx))
				if(Rx <= 0) stop(paste("error in cor0 -- Ry < 0. Ry =",Ry))
				cov.wt(cbind(x0,y0),wt=w0,cor=TRUE)$cor[1,2] / sqrt(Rx * Ry)
			}
		} else {
			if(length(w) == 0) {
				subset1 <- subset & !is.na(x) & !is.na(y)
				x0 <- subset(x,subset1)
				y0 <- subset(y,subset1)
				if(length(x.se) > 0) x.se0 <- subset(x.se,subset1)
				if(length(y.se) > 0) y.se0 <- subset(y.se,subset1)
				if(length(x.se)==0) Rx <- 1
				else                Rx <- (var(x0) - mean0(x.se0^2)) / var(x0)
				if(length(y.se)==0) Ry <- 1
				else                Ry <- (var(y0) - mean0(y.se0^2)) / var(y0)
				if(Rx <= 0) stop(paste("error in cor0 -- Rx < 0. Rx =",Rx))
				if(Rx <= 0) stop(paste("error in cor0 -- Ry < 0. Ry =",Ry))
				cor(x0,y0,use="pairwise") / sqrt(Rx * Ry)
			} else {
				subset1 <- subset & !is.na(x) & !is.na(y) & !is.na(w)
				x0 <- subset(x,subset1)
				y0 <- subset(y,subset1)
				w0 <- subset(w,subset1)
				if(length(x.se) > 0) x.se0 <- subset(x.se,subset1)
				if(length(y.se) > 0) y.se0 <- subset(y.se,subset1)
				if(length(x.se) == 0) Rx <- 1
				else                  Rx <- (var0(x0,w=w0) - mean0(x.se0^2,w=w0)) / var0(x0,w=w0)
				if(length(y.se) == 0) Ry <- 1
				else                  Ry <- (var0(y0,w=w0) - mean0(y.se0^2,w=w0)) / var0(y0,w=w0)
				if(Rx <= 0) stop(paste("error in cor0 -- Rx < 0. Rx =",Rx))
				if(Rx <= 0) stop(paste("error in cor0 -- Ry < 0. Ry =",Ry))
				cov.wt(cbind(x0,y0),wt=w0,cor=TRUE)$cor[1,2] / sqrt(Rx * Ry)
			}
		}
	} else {
		if(length(bys) == 0) {
			if(length(subset) == 0) bys <- sort(unique(by))
			else                    bys <- sort(unique(subset(by,subset)))
		}
		ret <- rep(NA,length(bys))
		for(i in 1:length(bys)) {
			if(length(subset) == 0) {
				x0 <- subset(x,by==bys[i])
				y0 <- subset(y,by==bys[i])
				if(length(x.se) > 0) x.se0 <- subset(x.se,by==bys[i])
				if(length(y.se) > 0) y.se0 <- subset(y.se,by==bys[i])
			} else {
				x0 <- subset(x,subset&by==bys[i])
				y0 <- subset(y,subset&by==bys[i])
				if(length(x.se) > 0) x.se0 <- subset(x.se,subset&by==bys[i])
				if(length(y.se) > 0) y.se0 <- subset(y.se,subset&by==bys[i])
			}
			if(length(x0) > 0) {
				
				if(length(x.se)==0) Rx <- 1
				else                Rx <- (var(x0) - mean0(x.se0^2)) / var(x0)
				if(length(y.se)==0) Ry <- 1
				else                Ry <- (var(y0) - mean0(y.se0^2)) / var(y0)
				if(Rx <= 0) stop(paste("error in cor0 -- Rx < 0. Rx =",Rx))
				if(Rx <= 0) stop(paste("error in cor0 -- Ry < 0. Ry =",Ry))
				if(length(w) == 0) {
					ret[i] <- cor(x0,y0,use="pairwise") / sqrt(Rx * Ry)
				} else {
					w0 <- subset(w,subset)
					ret[i] <- cov.wt(cbind(x0,y0),wt=w0,cor=TRUE)$cor[1,2] / sqrt(Rx * Ry)
				}
			}
		}
		names(ret) <- bys
		ret
	}
}

table0 <- function(x,subset=numeric(0))
{
	if(length(subset) == 0) {
		subset1 <- subset(x,!is.na(x))
	} else if(length(subset) != length(x)) {
		# Error
		stop("Incompadible Dimensions")
	} else {
		subset1 <- subset(x,subset&!is.na(x))
	}
	if(length(subset1) == 0) {
		NA
	} else {
		table(subset1)
	}
}

outlier <- function(x,subset=logical(0),cutoff=3) { abs((x - mean0(x)) / sd0(x)) > cutoff }

remove.outliers <- function(x,subset=logical(0),cutoff=3)
{
	out <- outlier(x,subset,cutoff)
	x[!out&subset]
}

rowmiss <- function(X) { rowSums(is.na(X))>0 }

drop.na <- function(x) { x[!is.na(x)] }

model.matrix0 <- function(f1,rhs=logical(0))
{
	mf <- model.frame(f1,na.action=na.pass)
	if(length(rhs) == 0) mm <- model.matrix(f1,data=mf)
	else                 mm <- model.matrix(f1,data=mf,rhs=rhs)
	mm
}

model.response0 <- function(f1,lhs=logical(0))
{
	mf <- model.frame(f1,na.action=na.pass)
	if(length(lhs) == 0) mr <- model.response(data=mf)
	else                 mr <- model.part(f1,data=mf,lhs=lhs)
	mr
}

formula.data <- function(f,subset=logical(0),list1=logical(0),se="",nointercept=FALSE)
{
	f1 <- Formula(f)
	len1 <- length(f1)
	if(length(len1) != 2) stop("error in formula.data -- invalid formula")
	y <- list()
	X <- list()
	for(i in 1:len1[1]) y[[i]] <- model.response0(f1,lhs=i)
	for(i in 1:len1[2]) X[[i]] <- model.matrix0(f1,rhs=i)
	ptm <- proc.time()
	y0 <- y
	X0 <- X
	n <- nrow(as.matrix(y[[1]]))
	drop <- rep(0,n)
	for(i in 1:len1[1]) drop <- drop | is.na(y[[i]])
	for(i in 1:len1[2]) drop <- drop | rowmiss(X[[i]])
	if(length(subset) == n) drop <- drop | !subset
	else if(length(subset) != 0) stop("error in formula data")
	for(i in 1:len1[1]) y[[i]] <- y[[i]][!drop]
	for(i in 1:len1[2]) X[[i]] <- X[[i]][!drop,]
	if(nointercept) {
		names1 <- colnames(X[[i]])[2:ncol(X[[i]])]
		for(i in 1:len1[2]) X[[i]] <- as.matrix(X[[i]][,2:ncol(X[[i]])])
		colnames(X[[i]]) <- names1
	}	
	if(length(list1) > 0) for(i in 1:length(list1)) if(length(list1[[i]]) > 0)
	{
		if(is.matrix(list1[[i]])) {
			if(nrow(list1[[i]]) != n) stop("error in formula.data -- element of list1 does not have n rows")
			list1[[i]] <- as.matrix(list1[[i]][!drop,])
		} else if(is.array(list1[[i]])) {
			if(length(dim(list1[[i]])) != 3) stop("error in formula.data -- array is not a 3D array")
			if(dim(list1[[i]])[1] != n) stop("error in formula.data -- element of list1 does not have n rows")
			list1[[i]] <- as.array(list1[[i]][!drop,,])
		} else {
			if(length(list1[[i]]) != n) stop("error in formula.data -- element of list1 is not of length n")
			list1[[i]] <- list1[[i]][!drop]
		}
	}

	# code to drop clusters for panel Newey-West
	if(se == "pnw" | se == "panelneweywest")
	{
		if(length(list1$unitid) == 0) stop("error in formula.data -- panel newey west standard errors requested, but unitid missing")
		if(length(list1$timeid) == 0) stop("error in formula.data -- panel newey west standard errors requested, but timeid missing")
		N <- length(y[[1]])
		miss <- rep(FALSE,N)
		for(i in 1:len1[1]) miss <- miss | is.na(y[[i]])
		for(i in 1:len1[2]) miss <- miss | is.na(X[[i]])
		unitids <- sort(unique(list1$unitid))
		T <- max(list1$timeid) - min(list1$timeid) + 1
		lag <- floor(4 * (T / 100)^(4/9))	
		pnwuse <- rep(TRUE,N)
		for(i in 1:length(unitids))
		{
			timecurr <- list1$timeid[list1$unitid==unitids[i]]
			misscurr <- miss[list1$unitid==unitids[i]]
			for(j in 1:length(timecurr)) if(misscurr[j]) timecurr[j] <- NA
			use <- TRUE
			for(j in 1:lag) if(sum(!is.na(fmatch(timecurr-j,timecurr))) < 20) use <- FALSE
			if(!use)
			{
				print(paste("Dropping cluster: ",unitids[i],sep=""))
				pnwuse[list1$unitid==unitids[i]] <- FALSE
			}
		}
		for(i in 1:len1[1]) y[[i]] <- y[[i]][pnwuse]
		for(i in 1:len1[2]) X[[i]] <- X[[i]][pnwuse,]
		list1$timeid <- list1$timeid[pnwuse]
		list1$unitid <- list1$unitid[pnwuse]
		if(length(y[[1]]) < 20) stop("error in formula.data -- panel newey west standard errors requested, but less than 20 observations are left")
	}

	list(y=y,X=X,y0=y0,X0=X0,list1=list1)
}

robust0 <- function(fm)
{
	require(sandwich, quietly = TRUE)
	require(lmtest, quietly = TRUE)
	N <- length(fm$residuals)
	M <- N
	K <- fm$rank
	dfc <- (M/(M-1))*((N-1)/(N-K))
	uj  <- apply(estfun(fm),2, function(x) tapply(x, 1:N, sum));
	vcovCL <- dfc*sandwich(fm, meat=crossprod(uj)/N)
	sm <- summary(fm)
	model <- coeftest(fm, vcovCL)
	if(length(sm$r.squared) > 0) {
		#list(model=model,N=N,r.squared=sm$r.squared,coef=model[1:K],theta=model[1:K],se=(diag(vcovCL))^.5,V=vcovCL)
		list(model=model,N=N,r.squared=sm$r.squared,coef=sm$coefficients[1:K],theta=sm$coefficients[1:K],se=(diag(vcovCL))^.5,V=vcovCL)	
	} else {
		#list(model=model,N=N,r.squared=fm$r.squared,coef=model[1:K],theta=model[1:K],se=(diag(vcovCL))^.5,V=vcovCL)
		list(model=model,N=N,r.squared=fm$r.squared,coef=fm$coefficients[1:K],theta=fm$coefficients[1:K],se=(diag(vcovCL))^.5,V=vcovCL)
	}
}

cluster0 <- function(fm, cl)
{
	require(sandwich, quietly = TRUE)
	require(lmtest, quietly = TRUE)
	not <- attr(fm$model,"na.action")
	if(!is.null(not)) { cl <- cl[-not] }
	M <- length(unique(cl))
	N <- length(cl)
	K <- fm$rank
	dfc <- (M/(M-1))*((N-1)/(N-K))
	uj <- apply(estfun(fm),2, function(x) tapply(x, cl, sum));
	vcovCL <- dfc*sandwich(fm, meat=crossprod(uj)/N)
	sm <- summary(fm)
	resid <- summary(fm)$residuals
	if(length(resid) > 0) {
		#sigmasqse <- (mean(((M / N) * aggregate((summary(fm)$residuals)^2,by=list(cl),FUN=sum)[2])^2)-(summary(fm)$sigma)^4)^.5 / M^.5
		sigmasqse <- NA
		model <- coeftest(fm, vcovCL)
		#list(model=model,N=N,Clusters=M,r.squared=summary(fm)$r.squared,sigmasq=summary(fm)$sigma^2,sigmasqse=sigmasqse,coef=model[1:K],se=diag(vcovCL)^.5,V=vcovCL)
		list(model=model,N=N,Clusters=M,r.squared=summary(fm)$r.squared,sigmasq=summary(fm)$sigma^2,sigmasqse=sigmasqse,coef=sm$coefficients[1:K],se=diag(vcovCL)^.5,V=vcovCL)

	} else {
		model <- coeftest(fm, vcovCL)
		#list(model=model,N=N,Clusters=M,r.squared=fm$r.squared,coef=model[1:K],se=diag(vcovCL)^.5,V=vcovCL)
		list(model=model,N=N,Clusters=M,r.squared=fm$r.squared,coef=fm$coefficients[1:K],se=diag(vcovCL)^.5,V=vcovCL)
	}
}

get.ses <- function(m1,se,unitid=logical(0),timeid=logical(0))
{
	     if(se == "classic"                     ) stop("error in get.ses --- don't call with classic")
	else if(se == "cluster"                     ) res <- cluster0(m1,unitid)
	else if(se == "nw" | se == "neweywest"      ) res <- neweywest0(m1,timeid)
	else if(se == "pnw" | se == "panelneweywest") res <- panelneweywest0(m1,timeid,unitid)
	else if(se == "robust")                       res <- robust0(m1) # the default option
	else                                          stop("invalid se option")
}

lm0 <- function(f1,se="robust",w=logical(0),subset=logical(0),nointercept=FALSE,unitid=logical(0),timeid=logical(0))
{
	# get y and x
	dat <- formula.data(f1,subset,list(unitid=unitid,timeid=timeid,w=w),se=se,nointercept=nointercept)
	if(length(dat$y) != 1) stop("error in lm0 -- invalid number of repsonses")
	if(length(dat$X) != 1) stop("error in lm0 -- invalid RHS")
	y1 <- dat$y[[1]]
	x1 <- dat$X[[1]]
	w1 <- dat$list1$w
	unitid1 <- dat$list1$unitid
	timeid1 <- dat$list1$timeid
	
	# estimate the model
	if(length(w1) == 0) {
		lm1 <- lm(y1 ~ 0 + x1)
	} else {
		lm1 <- lm(y1 ~ 0 + x1,weights=w1)
	}
	if(se=="classic") {
		s1 <- summary(lm1)
		res <- list()
		res$coef <- s1$coefficients[,1]
		res$se <- s1$coefficients[,2]
		res$N <- length(y1)
		res$r.squared <- s1$r.squared
		res$ivs <- names(lm1$coefficients)
	} else {
		res <- get.ses(lm1,se,timeid=timeid1,unitid=unitid1)
		res$ivs <- rownames(res$model)
	}

	if(length(unitid1) == 0) res$Clusters <- 1
	else                     res$Clusters <- length(unique(unitid1))
	
	# model predictions
	x <- dat$X0[[1]]
	if(nointercept) x <- x[,2:ncol(x)]
	pred <- x %*% lm1$coef
	XpX <- t(x1) %*% x1
	res$pred <- pred
	res$XpX <- XpX

	# hack to get correct model fit when intercept is included as a variable
	if(length(w1) == 0) {
		lm2 <- lm(y1 ~ x1)
	} else {
		lm2 <- lm(y1 ~ x1,weights=w1)
	}

	res$theta <- res$coef
	res$r.squared <- summary(lm2)$r.squared
	res$sigma <- summary(lm2)$sigma
	res$AIC <- AIC(lm2)
	res$BIC <- BIC(lm2)
	fac <- (res$N-1)/(res$N-ncol(x))
	res$r.squared.adj <- fac * res$r.squared + 1 - fac
	res$ivs <- substr(res$ivs,3,nchar(res$ivs))
	res$ivs[res$ivs=="tercept)"] <- "Intercept"
	if(se=="classic") {
		res$V <- res$sigma^2 * solve(XpX)
		res$predse <- rep(NA,nrow(x))
		for(n in 1:nrow(x)) res$predse[n] <- res$sigma * (1 + t(x[n,]) %*% solve(XpX) %*% x[n,])^.5
		tcrit <- qt(.975,res$N-ncol(x))
		res$predlow <- res$pred - tcrit * res$predse
		res$predhigh <- res$pred + tcrit * res$predse
	}
	res
}

drop.all.zero <- function(X,tol=0.00000001)
{
	K <- ncol(X)
	allzero <- rep(0,K)
	for(k in 1:K) allzero[k] <- max0(X[,k]) < tol & min0(X[,k]) > -tol
	cl <- colnames(X)
	X <- X[,(1:K)[!allzero]]
	if(!is.matrix(X)) {
		X <- matrix(X,ncol=1)
		colnames(X) <- cl
	}
	X	
}

logit0 <- function(f1,se="robust",subset=logical(0),nointercept=FALSE,unitid=logical(0),timeid=logical(0),w=logical(0))
{
	# get y and x
	dat <- formula.data(f1,subset,list(unitid=unitid,timeid=timeid,w=w),se=se,nointercept=nointercept)
	if(length(dat$y) != 1) stop("error in logit0 -- invalid number of repsonses")
	if(length(dat$X) != 1) stop("error in logit0 -- invalid RHS")
	y1 <- dat$y[[1]]
	x1 <- dat$X[[1]]
	if(length(w) > 0) w1 <- dat$list1$w
	unitid1 <- dat$list1$unitid
	timeid1 <- dat$list1$timeid
	x1 <- drop.all.zero(x1) # drops variables that are always zero

	# estimate the model
	if(length(w) == 0) {
		logit1 <- glm(formula = y1 ~ 0 + x1,family = "binomial")
	} else {
		logit1 <- glm(formula = y1 ~ 0 + x1,weights=w1,family = "binomial")
	}

	if(se=="classic") {
		s1 <- summary(logit1)
		res <- list()
		res$coef <- s1$coefficients[,1]
		res$se <- s1$coefficients[,2]
		res$N <- length(y1)
		res$ivs <- names(logit1$coefficients)
		if(nointercept == FALSE) res$ivs <- res$ivs[2:length(res$ivs)]
	} else {
		res <- get.ses(logit1,se,timeid=timeid1,unitid=unitid1)
		res$ivs <- rownames(res$model)
	}
	if(length(unitid1) == 0) res$Clusters <- 1
	else                     res$Clusters <- length(unique(unitid1))

	res$theta <- res$coef
	res$AIC <- AIC(logit1)
	res$BIC <- BIC(logit1)
	res$ivs <- substr(res$ivs,3,nchar(res$ivs))
	res$ivs[res$ivs=="ntercept)"] <- "(Intercept)"
	res
}

ologit0 <- function(f1,se="robust",subset=logical(0),unitid=logical(0),timeid=logical(0))
{
	# get y and x
	dat <- formula.data(f1,subset,list(unitid=unitid,timeid=timeid),se=se,nointercept=TRUE)
	if(length(dat$y) != 1) stop("error in ologit0 -- invalid number of repsonses")
	if(length(dat$X) != 1) stop("error in ologit0 -- invalid RHS")
	y1 <- dat$y[[1]]
	x1 <- dat$X[[1]]
	unitid1 <- dat$list1$unitid
	timeid1 <- dat$list1$timeid
	x1 <- drop.all.zero(x1) # drops variables that are always zero
	K <- ncol(x1)
	ivs <- colnames(x1)

	# estimate the model
	y2 <- factor(y1)
	ologit1 <- polr(y2 ~ x1,method = c("logistic"),Hess=TRUE)
	ll1 <- ologit1$deviance / -2
	ologit0 <- polr(y2 ~ 1,method = c("logistic"),Hess=TRUE)
	ll0 <- ologit0$deviance / -2
	v1 <- t(ologit1$coef) %*% var(x1) %*% ologit1$coef
	r.squared <- c(1-ll1/ll0,v1 / (v1 + pi^2/3))
	names(r.squared) <- c("McFadden","McKelvey-Zavoina")
	L <- length(ologit1$zeta)
	
	# trick robust se's into working by standarding ologit1 object
	ologit1$coef <- c(ologit1$coef,ologit1$zeta)
	ologit1$residuals <- rep(NA,ologit1$n)
	ologit1$rank <- length(ologit1$coef)
	ologit1$r.squared <- r.squared

	# estimate the model
	if(se=="classic") {
		s1 <- summary(ologit1)
		res <- list()
		res$coef <- s1$coefficients[,1]
		res$se <- s1$coefficients[,2]
		res$N <- length(y1)
		res$r.squared <- s1$r.squared
		res$ivs <- names(ologit1$coefficients)
	} else {
		res <- get.ses(ologit1,se,timeid=timeid1,unitid=unitid1)
		res$ivs <- colnames(res$V)
	}

	if(length(unitid1) == 0) res$Clusters <- 1
	else                     res$Clusters <- length(unique(unitid1))
	
	res$theta <- res$coef
	res$ivs[1:K] <- ivs[1:K]
	res$ivs[res$ivs=="tercept)"] <- "Intercept"
	res
}

one.true <- function(k,i)
{
	ret <- rep(FALSE,k)
	ret[i] <- TRUE
	ret
}

two.true <- function(k,i,j)
{
	if(i == j) stop("error in two.true -- i == j")
	ret <- rep(FALSE,k)
	ret[i] <- TRUE
	ret[j] <- TRUE
	ret
}

three.true <- function(l,i,j,k)
{
	if(i == j | i == k | j == k) stop("error in three.true -- i == j | i == k | j == k")
	ret <- rep(FALSE,l)
	ret[i] <- TRUE
	ret[j] <- TRUE
	ret[k] <- TRUE
	ret
}

lm.cluster.wild <- function(f1,idx=logical(0),x1=logical(0),y1=logical(0),unitid,subset=logical(0),R=1000,forceNull=FALSE)
{
	# check idx
	if(length(idx) == 0 & forceNull) stop("error in lm.cluster.wild -- length(idx)=0")
	if(is.matrix(idx) & forceNull) stop("error in lm.cluster.wild -- idx is a matrix, but forceNull = TRUE")
	if(!is.matrix(idx) & length(idx) > 0) if(sum0(idx) == length(idx) | sum0(idx) == 0) stop("error in lm.cluster.wild -- invalid test")
	if(is.matrix(idx)) for(l in 1:nrow(idx)) if(sum0(idx[l,]) == ncol(idx) | sum0(idx[l,]) == 0) stop("error in lm.cluster.wild -- invalid test")

	# setup data
	if(length(x1) == 0) {
		dat <- formula.data(f1,subset,list(unitid=unitid),se="cluster",nointercept=FALSE)
		if(length(dat$y) != 1) stop("error in lm.cluster.wild -- invalid number of repsonses")
		if(length(dat$X) != 1) stop("error in lm.cluster.wild -- invalid RHS")
		y1 <- dat$y[[1]]
		x1 <- dat$X[[1]]
		unitid1 <- dat$list1$unitid
	} else {
		unitid1 <- unitid
	}
	unitids <- unique(unitid1)
	C <- length(unitids) # number of clusters
	unitid2 <- fmatch(unitid1,unitids) - 1
	if(forceNull) idx_free <- !idx

	# drop variance zero columns (usefull for handling fixed effects)
	K <- ncol(x1)
	allzero <- rep(0,K)
	for(k in 1:K) allzero[k] <- max0(x1[,k]) < 0.00000001 & min0(x1[,k]) > -0.00000001
	x1 <- x1[,(1:K)[!allzero]]
	K <- ncol(x1)

	N <- length(y1)
	if(length(idx) == 0) {
		L <- 0
		p.vals <- rep(0,K)	
	} else if(is.matrix(idx)) {
		L <- nrow(idx)
		p.vals <- rep(0,L)	
	} else {
		L <- 1
		p.vals <- rep(0,L)
	}
	theta <- rep(0,K)
	thetavar <- rep(0,K^2)

	fastr_dll_loc <- paste(dir1,"fastr.dll",sep="")
	dyn.load(fastr_dll_loc)
	ret <- .C("lm_cluster_wild",PACKAGE="fastr",N = as.integer(N),
                                                  K = as.integer(K),
						              C = as.integer(C),
						              L = as.integer(L),
								  R = as.integer(R),
						              Y = as.double(y1),
					  	              X = as.double(x1),
						              UnitId = as.integer(unitid2),
						              Idx = as.integer(idx),
						              ForceNull = as.integer(forceNull),
								  PVals = as.double(p.vals),
								  Theta = as.double(theta),
								  ThetaVar = as.double(thetavar))
	dyn.unload(fastr_dll_loc)

	res <- list()
	res$N <- N
	res$coef <- ret$Theta
	res$theta <- ret$Theta
	res$V <- matrix(ret$ThetaVar,ncol=K)
	res$se <- diag(res$V)^.5
	res$p.val <- ret$PVals
	res$p.val[res$p.val<0] <- 0 # correction for numerical error
	res$Clusters <- C

	# some additional stuff
	lm1 <- lm0(y1 ~ 0 + x1)
	res$r.squared <- lm1$r.squared
	res$ivs <- lm1$ivs
	res$ivs <- substr(res$ivs,3,nchar(res$ivs))
	res$ivs[res$ivs=="tercept)"] <- "Intercept"

	res
}

delta.method <- function(func1,beta,V,...)
{
	c_beta <- jacobian(func1,beta,method="simple",...)
	Vc <- c_beta %*% V %*% t(c_beta)
	list(est=func1(beta,...),se=sqrt(diag(Vc)),V=Vc)
}

wald.test <- function(func1,beta,V,...)
{
	dm <- delta.method(func1,beta,V,...)
	cbeta <- func1(beta,...)
	W <- t(cbeta ) %*% solve(dm$V) %*% cbeta
	pval <- 1 - pchisq(W,length(dm$est))
	list(W=W,pval=pval)
}

cor.me <- function(x1,x2,y,subset=logical(0))
{
	miss <- is.na(x1) | is.na(x2) | is.na(y)
	x1m <- x1[!miss&subset]
	x2m <- x2[!miss&subset]
	ym <- y[!miss&subset]
	cov(x1m,ym) / (var(ym) * cov(x1m,x2m))^.5
}

latex.doc.start <- function(file1,packages=logical(0))
{
	cat("\\documentclass[11pt]{article}",file=file1,sep="\n")
	s <- "\\usepackage{float,amsmath,amssymb,amsthm,fullpage,setspace,natbib,enumerate,url,multirow,lscape"
	if(length(packages) > 0) for(i in 1:length(packages)) s <- paste(s,",",packages[i],sep="")
	s <- paste(s,"}",sep="")
	cat(s,file=file1,sep="\n",append=TRUE)
	#cat("\\usepackage[dvips]{graphicx,xcolor}",file=file1,sep="\n",append=TRUE)
	cat("\\onehalfspacing",file=file1,sep="\n",append=TRUE)
	cat("\\begin{document}",file=file1,sep="\n\n",append=TRUE)
}

latex.doc.end <- function(file1)
{
	cat("\\end{document}",file=file1,sep="\n",append=TRUE)
}

latex.table.start <- function(file1,k)
{
	cat("\\begin{table}[htp]\\centering\\scriptsize",file=file1,sep="\n",append=TRUE)
	cat("\\begin{singlespace}",file=file1,sep="\n",append=TRUE)
	cat("\\begin{tabular}{ l ",paste(rep("c",k),collapse=" ")," } \\hline \\hline",file=file1,sep="\n",append=TRUE)
}

latex.table.end <- function(file1,caption="",label="")
{
	cat("\\hline \\hline",file=file1,sep="\n",append=TRUE)
	cat("\\end{tabular}",file=file1,sep="\n",append=TRUE)
	cat("\\end{singlespace}",file=file1,sep="\n",append=TRUE)
	if(caption != "") cat(paste0(c("\\caption{\\footnotesize{",caption,"}}")),file=file1,sep="\n",append=TRUE)
	if(label != "") cat(paste0(c("\\label{",label,"}")),file=file1,sep="\n",append=TRUE)
	cat("\\end{table}",file=file1,sep="\n",append=TRUE)
}

latex.add.line <- function(file1,s)
{
	cat(s,file=file1,sep="\n",append=TRUE)
}

latex.table.entry <- function(file1,name,coef,bold=FALSE,italic=FALSE)
{
	if(bold)
	{
		name <- paste("\\textbf{",name,"}",sep="")
		coef <- paste("\\textbf{",coef,"}",sep="")
	}
	if(italic)
	{
		name <- paste("\\textit{",name,"}",sep="")
		coef <- paste("\\textit{",coef,"}",sep="")
	}
	s <- name
	n <- length(coef)
	for(i in 1:n) if(is.na(coef[i])) { coef[i] <- "" }
	if(n > 1) for(i in 1:(n-1)) { s <- paste(s," & ",coef[i],sep="") }
	s <- paste(s," & ",coef[n]," \\\\ \n",sep="")
	s
	cat(s,file=file1,sep="\n",append=TRUE)
}

latex.table.entries <- function(file1,names,coefs,bold=FALSE,italic=FALSE)
{
	m <- length(names)
	for(j in 1:m) latex.table.entry(file1,names[j],coefs[j,],bold)
}

make.transparent<-function(someColor, alpha=100)
{
	newColor<-col2rgb(someColor)
	apply(newColor, 2, function(curcoldata){rgb(red=curcoldata[1],green=curcoldata[2],blue=curcoldata[3],alpha=alpha, maxColorValue=255)})
}

check.rats <- function(rat,itemid,subset=logical(0))
{
	if(length(subset) == 0) {
		itemids <- sort(unique(itemid))
	} else {
		itemids <- sort(unique(subset(itemid,subset)))
	}

	if(!is.na(   fmatch("0",names(table0(rat,subset=subset)))  ))
	{
		zeros <- table0(rat,subset=subset)[["0"]]
	} else {
		zeros <- 0
	}
	sixs <- table0(rat,subset=subset)[["6"]]
	tots <- sum(table0(rat,subset=subset)) - zeros
	nos <- sixs / tots
	yess <- 1 - nos
	if(!is.na(   fmatch("1",names(table0(rat,subset=subset)))  ))
	{
		if(!is.na(   fmatch("2",names(table0(rat,subset=subset)))  ))
		{
			negs <- table0(rat,subset=subset)[["1"]] + table0(rat,subset=subset)[["2"]]
		} else {
			negs <- table0(rat,subset=subset)[["1"]]
		}
	} else {
		if(!is.na(   fmatch("2",names(table0(rat,subset=subset)))  ))
		{
			negs <- table0(rat,subset=subset)[["2"]]
		} else {
			negs <- 0
		}
	}
	if(!is.na(   fmatch("5",names(table0(rat,subset=subset)))  ))
	{
		poss <- table0(rat,subset=subset)[["4"]] + table0(rat,subset=subset)[["5"]]
	} else {
		poss <- table0(rat,subset=subset)[["4"]]
	}	
	negs <- negs / (poss + negs)
	poss <- 1 - negs
	
	k <- length(itemids)
	
	rat_comp <- list()
	if(length(subset) == 0)
	{
		for(i in 1:k)
		{
			rat_comp[[i]] <- subset(rat,itemid==itemids[i]&rat>=1&rat<=5)
		}
	} else {
		for(i in 1:k)
		{
			rat_comp[[i]] <- subset(rat,itemid==itemids[i]&rat>=1&rat<=5&subset)
		}
	}

	rat_comp2 <- list()
	curr <- 1
	for(i in 1:k)
	{
		if(length(rat_comp[[i]]) > 1) {
			rat_comp2[[curr]] <- rat_comp[[i]]
			curr <- curr + 1
		}
	}
	k2 <- length(rat_comp2)

	mat1 <- matrix(rep(0,25),nrow=5)
	if(k2 > 0)
	{
		for(i in 1:k2)
		{
			l <- length(rat_comp2[[i]])
			for(j in 1:l) {
				for(j2 in (j+1):l) {
					mat1[rat_comp2[[i]][j],rat_comp2[[i]][j2]] <- mat1[rat_comp2[[i]][j],rat_comp2[[i]][j2]] + 1
				}
			}
		}
	}

	mat1[1,2] <- mat1[1,2] + mat1[2,1]
	mat1[2,1] <- 0

	mat1[1,3] <- mat1[1,3] + mat1[3,1]
	mat1[3,1] <- 0

	mat1[1,4] <- mat1[1,4] + mat1[4,1]
	mat1[4,1] <- 0

	mat1[1,5] <- mat1[1,5] + mat1[5,1]
	mat1[5,1] <- 0

	mat1[2,3] <- mat1[2,3] + mat1[3,2]
	mat1[3,2] <- 0

	mat1[2,4] <- mat1[2,4] + mat1[4,2]
	mat1[4,2] <- 0

	mat1[2,5] <- mat1[2,5] + mat1[5,2]
	mat1[5,2] <- 0

	mat1[3,4] <- mat1[3,4] + mat1[4,3]
	mat1[4,3] <- 0

	mat1[3,5] <- mat1[3,5] + mat1[5,3]
	mat1[5,3] <- 0

	mat1[4,5] <- mat1[4,5] + mat1[5,4]
	mat1[5,4] <- 0

	corr <- mat1[1,1] + mat1[2,2] + mat1[3,3] + mat1[4,4] + mat1[5,5]
	samedir <- mat1[1,2] + mat1[4,5]
	nueterr <- mat1[1,3] + mat1[2,3] + mat1[3,4] + mat1[3,5]
	err <- mat1[1,4] + mat1[1,5] + mat1[2,4] + mat1[2,5]
	tot <- corr + samedir + nueterr + err

	kappa <- (corr/tot + samedir/tot - poss^2 - negs^2) / (1 - poss^2 - negs^2)

	rat_has <- list()
	for(i in 1:k)
	{
		rat_has[[i]] <- subset(rat,itemid==itemids[i]&rat>=1&rat<=6)
	}

	for(i in 1:k)
	{
		if(length(rat_has[[i]]) > 0)
		{
			for(j in 1:length(rat_has[[i]])) {
				if(rat_has[[i]][j] < 6) {
					rat_has[[i]][j] <- 2
				} else {
					rat_has[[i]][j] <- 1
				}
			}
		}
	}

	rat_has2 <- list()
	curr <- 1
	for(i in 1:k)
	{
		if(length(rat_has[[i]]) > 1) {
			rat_has2[[curr]] <- rat_has[[i]]
			curr <- curr + 1
		}
	}
	k2 <- length(rat_has2)

	mat2 <- matrix(rep(0,4),nrow=2)
	if(k2 > 0)
	{
		for(i in 1:k2)
		{
			l <- length(rat_has2[[i]])
			for(j in 1:l) {
				for(j2 in (j+1):l) {
					mat2[rat_has2[[i]][j],rat_has2[[i]][j2]] <- mat2[rat_has2[[i]][j],rat_has2[[i]][j2]] + 1
				}
			}
		}
	}

	mat2[1,2] <- mat2[1,2] + mat2[2,1]
	mat2[2,1] <- 0

	bothyes <- mat2[2,2] / sum(mat2)
	bothno <- mat2[1,1] / sum(mat2)
	err2 <- mat2[1,2] / sum(mat2)

	kappa2 <- (bothyes + bothno - yess^2 - nos^2) / (1 - yess^2 - nos^2)

	if(tot > 0)
	{
		list(mat1=mat1,corr=corr/tot,samedir=samedir/tot,nueterr=nueterr/tot,err=err/tot,kappa=kappa,n=tot,mat2=mat2,bothyes=mat2[2,2]/sum(mat2),bothno=mat2[1,1]/sum(mat2),err2=mat2[1,2]/sum(mat2),n2=sum(mat2),kappa2=kappa2)
	} else {
		list(mat1=mat1,corr=NA,samedir=NA,nueterr=NA,err=NA,kappa=NA,n=tot,mat2=mat2,bothyes=mat2[2,2]/sum(mat2),bothno=mat2[1,1]/sum(mat2),err2=mat2[1,2]/sum(mat2),n2=sum(mat2),kappa2=kappa2)
	}
}

# set up the data
clang <- c("English","German","English","French","German","English","English","Italian","Enlgish","French","English","Portuguese","Spanish","German","English","English")
countries <- c("Australia","Austria","Canada","France","Germany","Ireland","Israel","Italy","Japan","Luxembourg","New Zealand","Portugal","Spain","Switzerland","United Kingdom","United States")
newspapers <- c("The Age (Australia)","Herald Sun (Australia)","Der Standard (Austria)","Die Presse (Austria)","Toronto Star (Canada)","The Globe and Mail (Canada)","Le Monde (France)","Le Figaro (France)","Die Zeit (Germany)","Frankfurter (Germany)","Irish Times (Ireland)","Irish Independent (Ireland)","Globes (Israel)","Jerumselum Post (Israel)","La Stampa (Italy)","Cor (Italy)","Nikkei (Japan)","Yomiuri (Japan)","Le Quotidien (Luxembourg)","Age Fi (Luxembourg)","New Zealand Press","New Zealand Herald","Cor (Portugal)","Noticias (Portugal)","El Pais (Spain)","El Mundo (Spain)","Tages (Switzerland)","NZZ (Switzerland)","Guardian (U.K.)","London Times (U.K.)","New York Times (U.S.)","Wall Street Journal (U.S.)")

# load country-month data
data1 <- read_excel(paste(dir1,"qjps_newspapers_data.xlsx",sep=""),sheet="cm")
monthid <- data1$monthid
monthn  <- data1$monthn
year    <- data1$year
newsid  <- data1$newsid
country <- data1$country
first   <- 1 * (data1$newsid %% 2 == 1)
monthyear <- paste(monthn,substr(lapply(year,toString),3,4),sep="/")
pmonth <- paste(newsid,monthyear,sep="_")
elecin6 <- data1$elecin6
articles <- as.numeric(data1$articles)
econ_pos <- as.numeric(data1$econ_pos)
econ_tot <- as.numeric(data1$econ_tot)
econ_frac_pos  <- as.numeric(data1$econ_frac_pos)
gr_frac_pos    <- as.numeric(data1$gr_frac_pos)
un_frac_pos    <- as.numeric(data1$un_frac_pos)
inf_frac_pos   <- as.numeric(data1$inf_frac_pos)
econ_frac_pos_hl  <- as.numeric(data1$econ_frac_pos_hl)
gr_frac_pos_hl    <- as.numeric(data1$gr_frac_pos_hl)
un_frac_pos_hl    <- as.numeric(data1$un_frac_pos_hl)
inf_frac_pos_hl   <- as.numeric(data1$inf_frac_pos_hl)
gr_sh    <- as.numeric(data1$gr_sh)
un_sh    <- as.numeric(data1$un_sh)
inf_sh   <- as.numeric(data1$inf_sh)
gr_sh_hl    <- as.numeric(data1$gr_sh_hl)
un_sh_hl    <- as.numeric(data1$un_sh_hl)
inf_sh_hl   <- as.numeric(data1$inf_sh_hl)
cong_econ_frac_pos <- as.numeric(data1$cong_econ_frac_pos)
cong_gr_frac_pos <- as.numeric(data1$cong_gr_frac_pos)
cong_un_frac_pos <- as.numeric(data1$cong_un_frac_pos)
cong_inf_frac_pos <- as.numeric(data1$cong_inf_frac_pos)
cong_gr_sh <- as.numeric(data1$cong_gr_sh)
cong_un_sh <- as.numeric(data1$cong_un_sh)
cong_inf_sh <- as.numeric(data1$cong_inf_sh)
gr_frac_pos_oth    <- as.numeric(data1$gr_frac_pos_oth) # the other paper in the country, using to calculate correlation between left and right papers
un_frac_pos_oth    <- as.numeric(data1$un_frac_pos_oth)
inf_frac_pos_oth   <- as.numeric(data1$inf_frac_pos_oth)
gr_frac_pos_th <- as.numeric(data1$gr_frac_pos_th) # sentiment coded on the first thousand words
un_frac_pos_th <- as.numeric(data1$un_frac_pos_th)
inf_frac_pos_th <- as.numeric(data1$inf_frac_pos_th)
gr_sh_th <- as.numeric(data1$gr_sh_th) # share of coverage in the first thousand words
un_sh_th <- as.numeric(data1$un_sh_th)
inf_sh_th <- as.numeric(data1$inf_sh_th)
gr    <- as.numeric(data1$gr) # monthly growth
un    <- as.numeric(data1$un) # monthly unemployment
inf   <- as.numeric(data1$inf) # monthly inflation
unch  <- un  - panel.lag(un,monthid,newsid)
infch <- inf - panel.lag(inf,monthid,newsid)
econ_per_article <- as.numeric(data1$econ_per_article)
econ_per_headline <- as.numeric(data1$econ_per_headline)

# quarterly econ data
gr_qr    <- 100*(exp(rowSums(log(1+panel.lag(gr,monthid,newsid,lags=0:2)/100)))-1)
un_qr    <- rowMeans(panel.lag(un,monthid,newsid,lags=0:2))
unch_qr  <- un_qr - panel.lag(un_qr,monthid,newsid,lags=3)
inf_qr   <- 100*(exp(rowSums(log(1+panel.lag(inf,monthid,newsid,lags=0:2)/100)))-1)
infch_qr <- inf_qr - panel.lag(inf_qr,monthid,newsid,lags=3)

# semi_yearly econ data
gr_sy    <- 100*(exp(rowSums(log(1+panel.lag(gr,monthid,newsid,lags=0:5)/100)))-1)
un_sy    <- rowMeans(panel.lag(un,monthid,newsid,lags=0:5))
unch_sy  <- un_sy - panel.lag(un_sy,monthid,newsid,lags=6)
inf_sy   <- 100*(exp(rowSums(log(1+panel.lag(inf,monthid,newsid,lags=0:5)/100)))-1)
infch_sy <- inf_sy - panel.lag(inf_sy,monthid,newsid,lags=6)

# yearly econ data
gr_yr <- 100*(exp(rowSums(log(1+panel.lag(gr,monthid,newsid,lags=0:11)/100)))-1)
un_yr <- rowMeans(panel.lag(un,monthid,newsid,lags=0:11))
unch_yr <- un_yr - panel.lag(un_yr,monthid,newsid,lags=12)
inf_yr <- 100*(exp(rowSums(log(1+panel.lag(inf,monthid,newsid,lags=0:11)/100)))-1)
infch_yr <- inf_yr - panel.lag(inf_yr,monthid,newsid,lags=12)

# 2-y econ data
gr_2y <- 100*(exp(rowSums(log(1+panel.lag(gr,monthid,newsid,lags=0:23)/100)))-1)
un_2y <- rowMeans(panel.lag(un,monthid,newsid,lags=0:23))
unch_2y <- un_2y - panel.lag(un_2y,monthid,newsid,lags=24)
inf_2y <- 100*(exp(rowSums(log(1+panel.lag(inf,monthid,newsid,lags=0:23)/100)))-1)
infch_2y <- inf_2y - panel.lag(inf_2y,monthid,newsid,lags=24)

# 4-y econ data
gr_4y <- 100*(exp(rowSums(log(1+panel.lag(gr,monthid,newsid,lags=0:47)/100)))-1)
un_4y <- rowMeans(panel.lag(un,monthid,newsid,lags=0:47))
unch_4y <- un_4y - panel.lag(un_4y,monthid,newsid,lags=48)
inf_4y <- 100*(exp(rowSums(log(1+panel.lag(inf,monthid,newsid,lags=0:47)/100)))-1)
infch_4y <- inf_4y - panel.lag(inf_4y,monthid,newsid,lags=48)

# newspaper bias variables
leadpos <- as.numeric(data1$leadpos)
leadrightconst <- leadpos > 0
newspos <- as.numeric(data1$newspos)
ideomatch <- ((leadpos > 0) * (newspos > 0)) + ((leadpos < 0) * (newspos < 0))
gr_yr_ideomatch    <- ideomatch * gr_yr
un_yr_ideomatch     <- ideomatch * un_yr
unch_yr_ideomatch  <- ideomatch * unch_yr
inf_yr_ideomatch    <- ideomatch * inf_yr
infch_yr_ideomatch <- ideomatch * infch_yr

leadpos_newspos <- leadpos * newspos
gr_leadpos <- gr_yr * leadpos
gr_newspos <- gr_yr * newspos
gr_leadpos_newspos <- gr_yr * leadpos * newspos

un_leadpos <- un_yr * leadpos
un_newspos <- un_yr * newspos
un_leadpos_newspos <- un_yr * leadpos * newspos

unch_leadpos <- unch_yr * leadpos
unch_newspos <- unch_yr * newspos
unch_leadpos_newspos <- unch_yr * leadpos * newspos

inf_leadpos <- inf_yr * leadpos
inf_newspos <- inf_yr * newspos
inf_leadpos_newspos <- inf_yr * leadpos * newspos

infch_leadpos <- infch_yr * leadpos
infch_newspos <- infch_yr * newspos
infch_leadpos_newspos <- infch_yr * leadpos * newspos

gr_yr_left <- gr_yr * (newspos < 0)
gr_yr_right <- gr_yr * (newspos > 0)

un_yr_left <- un_yr * (newspos < 0)
un_yr_right <- un_yr * (newspos > 0)

unch_yr_left <- unch_yr * (newspos < 0)
unch_yr_right <- unch_yr * (newspos > 0)

inf_yr_left <- inf_yr * (newspos < 0)
inf_yr_right <- inf_yr * (newspos > 0)

infch_yr_left <- infch_yr * (newspos < 0)
infch_yr_right <- infch_yr * (newspos > 0)

ideomatch_left <- ideomatch * (newspos < 0)
ideomatch_right <- ideomatch * (newspos > 0)

gr_yr_ideomatch_left <- gr_yr_ideomatch * (newspos < 0)
gr_yr_ideomatch_right <- gr_yr_ideomatch * (newspos > 0)

un_yr_ideomatch_left <- un_yr_ideomatch * (newspos < 0)
un_yr_ideomatch_right <- un_yr_ideomatch * (newspos > 0)

unch_yr_ideomatch_left <- unch_yr_ideomatch * (newspos < 0)
unch_yr_ideomatch_right <- unch_yr_ideomatch * (newspos > 0)

inf_yr_ideomatch_left <- inf_yr_ideomatch * (newspos < 0)
inf_yr_ideomatch_right <- inf_yr_ideomatch * (newspos > 0)

infch_yr_ideomatch_left <- infch_yr_ideomatch * (newspos < 0)
infch_yr_ideomatch_right <- infch_yr_ideomatch * (newspos > 0)

# points used for calculated effect sizes
inf_yr_noout   <- remove.outliers(inf_yr,subset=first==1,cut=5)
infch_yr_noout <- remove.outliers(infch_yr,subset=first==1,cut=5)

mean_gr    <- mean0(gr_yr,subset=first==0)
mean_un    <- mean0(un_yr,subset=first==0)
mean_unch  <- mean0(unch_yr,subset=first==0)
mean_inf   <- mean0(inf_yr_noout)
mean_infch <- mean0(infch_yr_noout)

sd_gr    <- sd0(gr_yr,subset=first==0)
sd_un    <- sd0(un_yr,subset=first==0)
sd_unch  <- sd0(unch_yr,subset=first==0)
sd_inf   <- sd0(inf_yr_noout)
sd_infch <- sd0(infch_yr_noout)

grs1 <- quantile0(gr_yr,.02,subset=first==1)
grs2 <- mean_gr - sd_gr
grs3 <- mean_gr
grs4 <- mean_gr + sd_gr
grs5 <- quantile0(gr_yr,.98,subset=first==1)

uns1 <- quantile0(un_yr,.98,subset=first==1)
uns2 <- mean_un + sd_un
uns3 <- mean_un
uns4 <- mean_un - sd_un
uns5 <- quantile0(un_yr,.02,subset=first==1)

unchs1 <- quantile0(unch_yr,.98,subset=first==1)
unchs2 <- mean_unch + sd_unch
unchs3 <- mean_unch
unchs4 <- mean_unch - sd_unch
unchs5 <- quantile0(unch_yr,.02,subset=first==1)

infs1 <- quantile0(inf_yr_noout,.98)
infs2 <- mean_inf + sd_inf
infs3 <- mean_inf
infs4 <- mean_inf - sd_inf
infs5 <- quantile0(inf_yr_noout,.02)

infchs1 <- quantile0(infch_yr_noout,.98)
infchs2 <- mean_infch + sd_infch
infchs3 <- mean_infch
infchs4 <- mean_infch - sd_infch
infchs5 <- quantile0(infch_yr_noout,.02)

# human-coding data 
data2 <- read_excel(paste(dir1,"qjps_newspapers_data.xlsx",sep=""),sheet="hc")
m2 <- nrow(data2)
rat     <- as.numeric(data2$rat)
gr_rat  <- as.numeric(data2$gr_rat)
un_rat  <- as.numeric(data2$un_rat)
inf_rat <- as.numeric(data2$inf_rat)
ratmat <- cbind(rat,gr_rat,un_rat,inf_rat)
itemid <- data2$itemid
train <- data2$train
type <- data2$type
lang <- data2$lang

# dictionary-coded sentiment at the article level, for the human-coded articles
gr2      <- as.numeric(data2$gr)
grpos2   <- as.numeric(data2$grpos)
grneg2   <- as.numeric(data2$grneg)
un2      <- as.numeric(data2$un)
unpos2   <- as.numeric(data2$unpos)
unneg2   <- as.numeric(data2$unneg)
inf2     <- as.numeric(data2$inf)
infpos2  <- as.numeric(data2$infpos)
infneg2  <- as.numeric(data2$infneg)
econ2    <- as.numeric(data2$econ) # pos. or neg. econ. words
econpos2 <- as.numeric(data2$econpos) # positive econ. words
econneg2 <- as.numeric(data2$econneg) # negative econ. words
words2   <- as.numeric(data2$words) # number of words
sent2    <- as.numeric(data2$sent) # number of sentences
econfracpos2 <- rep(NA,m2)
grfracpos2   <- rep(NA,m2)
unfracpos2   <- rep(NA,m2)
inffracpos2  <- rep(NA,m2)
for(i in 1:m2)
{
	if(econpos2[i] + econneg2[i] > 0) econfracpos2[i] <- econpos2[i] / (econpos2[i] + econneg2[i])
	if(grpos2[i] + grneg2[i] > 0) grfracpos2[i] <- grpos2[i] / (grpos2[i] + grneg2[i])
	if(unpos2[i] + unneg2[i] > 0) unfracpos2[i] <- unpos2[i] / (unpos2[i] + unneg2[i])
	if(infpos2[i] + infneg2[i] > 0) inffracpos2[i] <- infpos2[i] / (infpos2[i] + infneg2[i])
}
econfrac2 <- econ2 / words2
grfrac2   <- gr2 / words2
unfrac2   <- un2 / words2
inffrac2  <- inf2 / words2

# recode the human coded data

# the article/headline was about the economy/gr/un/inf
ratn6     <- rat     >= 1 & rat     <= 5
gr_ratn6  <- gr_rat  >= 1 & gr_rat  <= 5
un_ratn6  <- un_rat  >= 1 & un_rat  <= 5
inf_ratn6 <- inf_rat >= 1 & inf_rat <= 5

# rating was positive (among not nuetral)
ratpn     <- rat     == 4 | rat     == 5
gr_ratpn  <- gr_rat  == 4 | gr_rat  == 5
un_ratpn  <- un_rat  == 4 | un_rat  == 5
inf_ratpn <- inf_rat == 4 | inf_rat == 5

for(i in 1:m2)
{
	if(!is.na(rat[i]))
	{
		if(rat[i] == 0) ratn6[i] <- NA
		if(rat[i] == 0 | rat[i] == 3 | rat[i] == 6) ratpn[i] <- NA
	}

	if(!is.na(gr_rat[i]))
	{
		if(gr_rat[i] == 0) gr_ratn6[i] <- NA
		if(gr_rat[i] == 0 | gr_rat[i] == 3 | gr_rat[i] == 6) gr_ratpn[i] <- NA
	}

	if(!is.na(un_rat[i]))
	{
		if(un_rat[i] == 0) un_ratn6[i] <- NA
		if(un_rat[i] == 0 | un_rat[i] == 3 | un_rat[i] == 6) un_ratpn[i] <- NA
	}

	if(!is.na(inf_rat[i]))
	{
		if(inf_rat[i] == 0) inf_ratn6[i] <- NA
		if(inf_rat[i] == 0 | inf_rat[i] == 3 | inf_rat[i] == 6) inf_ratpn[i] <- NA
	}
}

country2 <- data2$country
newsid2 <- data2$newsid
monthn2 <- data2$monthn
year2 <- data2$year
monthyear2 <- paste(monthn2,substr(lapply(year2,toString),3,4),sep="/")
pmonth2 <- paste(newsid2,monthyear2,sep="_")

# get the monthly economic and ideological data for the human-coded articles
gr_yr2     <- gr_yr[    fmatch(pmonth2,pmonth)]
un_yr2     <- un_yr[    fmatch(pmonth2,pmonth)]
unch_yr2   <- unch_yr[  fmatch(pmonth2,pmonth)]
inf_yr2    <- inf_yr[   fmatch(pmonth2,pmonth)]
infch_yr2  <- infch_yr[ fmatch(pmonth2,pmonth)]
ideomatch2 <- ideomatch[fmatch(pmonth2,pmonth)]
gr_yr_ideomatch2    <- gr_yr2 * ideomatch2
un_yr_ideomatch2    <- un_yr2 * ideomatch2
unch_yr_ideomatch2  <- unch_yr2 * ideomatch2
inf_yr_ideomatch2   <- inf_yr2 * ideomatch2
infch_yr_ideomatch2 <- infch_yr2 * ideomatch2

# for wald test
wald25   <- function(x) { c(x[2],x[5])      } # coefficients 2 and 5 jointly zero
wald34   <- function(x) { c(x[3],x[4])      } # coefficients 3 and 4 jointly zero
wald456  <- function(x) { c(x[4],x[5],x[6]) } # etc.
wald47   <- function(x) { c(x[4],x[7])      }
wald4_7  <- function(x) { x[4:7]            }
wald6_11 <- function(x) { x[6:11]           }

# create the data for the tables

# table 1 -- not a result

# table 2
tab2 <- matrix(rep(NA,7*10),nrow=10)

tab2[1,1] <- dig2(cor0(gr_frac_pos,gr,subset=newsid<=32&!is.na(gr_4y)))
tab2[1,2] <- dig2(cor0(gr_frac_pos,gr_qr,subset=newsid<=32&!is.na(gr_4y)))
tab2[1,3] <- dig2(cor0(gr_frac_pos,gr_sy,subset=newsid<=32&!is.na(gr_4y)))
tab2[1,4] <- dig2(cor0(gr_frac_pos,gr_yr,subset=newsid<=32&!is.na(gr_4y)))
tab2[1,5] <- dig2(cor0(gr_frac_pos,gr_2y,subset=newsid<=32&!is.na(gr_4y)))
tab2[1,6] <- dig2(cor0(gr_frac_pos,gr_4y,subset=newsid<=32&!is.na(gr_4y)))
tab2[1,7] <- sum(!is.na(gr_frac_pos) & !is.na(gr_4y))

tab2[3,1] <- dig2(cor0(un_frac_pos,un,subset=newsid<=32&!is.na(unch_4y)))
tab2[3,2] <- dig2(cor0(un_frac_pos,un_qr,subset=newsid<=32&!is.na(unch_4y)))
tab2[3,3] <- dig2(cor0(un_frac_pos,un_sy,subset=newsid<=32&!is.na(unch_4y)))
tab2[3,4] <- dig2(cor0(un_frac_pos,un_yr,subset=newsid<=32&!is.na(unch_4y)))
tab2[3,5] <- dig2(cor0(un_frac_pos,un_2y,subset=newsid<=32&!is.na(unch_4y)))
tab2[3,6] <- dig2(cor0(un_frac_pos,un_4y,subset=newsid<=32&!is.na(unch_4y)))
tab2[3,7] <- sum(!is.na(un_frac_pos) & !is.na(unch_4y))

tab2[5,1] <- dig2(cor0(un_frac_pos,unch,subset=newsid<=32&!is.na(unch_4y)))
tab2[5,2] <- dig2(cor0(un_frac_pos,unch_qr,subset=newsid<=32&!is.na(unch_4y)))
tab2[5,3] <- dig2(cor0(un_frac_pos,unch_sy,subset=newsid<=32&!is.na(unch_4y)))
tab2[5,4] <- dig2(cor0(un_frac_pos,unch_yr,subset=newsid<=32&!is.na(unch_4y)))
tab2[5,5] <- dig2(cor0(un_frac_pos,unch_2y,subset=newsid<=32&!is.na(unch_4y)))
tab2[5,6] <- dig2(cor0(un_frac_pos,unch_4y,subset=newsid<=32&!is.na(unch_4y)))
tab2[5,7] <- sum(!is.na(un_frac_pos) & !is.na(unch_4y))

tab2[7,1] <- dig2(cor0(inf_frac_pos,inf,subset=newsid<=32&!is.na(infch_4y)))
tab2[7,2] <- dig2(cor0(inf_frac_pos,inf_qr,subset=newsid<=32&!is.na(infch_4y)))
tab2[7,3] <- dig2(cor0(inf_frac_pos,inf_sy,subset=newsid<=32&!is.na(infch_4y)))
tab2[7,4] <- dig2(cor0(inf_frac_pos,inf_yr,subset=newsid<=32&!is.na(infch_4y)))
tab2[7,5] <- dig2(cor0(inf_frac_pos,inf_2y,subset=newsid<=32&!is.na(infch_4y)))
tab2[7,6] <- dig2(cor0(inf_frac_pos,inf_4y,subset=newsid<=32&!is.na(infch_4y)))
tab2[7,7] <- sum(!is.na(inf_frac_pos) & !is.na(infch_4y))

tab2[9,1] <- dig2(cor0(inf_frac_pos,infch,subset=newsid<=32&!is.na(infch_4y)))
tab2[9,2] <- dig2(cor0(inf_frac_pos,infch_qr,subset=newsid<=32&!is.na(infch_4y)))
tab2[9,3] <- dig2(cor0(inf_frac_pos,infch_sy,subset=newsid<=32&!is.na(infch_4y)))
tab2[9,4] <- dig2(cor0(inf_frac_pos,infch_yr,subset=newsid<=32&!is.na(infch_4y)))
tab2[9,5] <- dig2(cor0(inf_frac_pos,infch_2y,subset=newsid<=32&!is.na(infch_4y)))
tab2[9,6] <- dig2(cor0(inf_frac_pos,infch_4y,subset=newsid<=32&!is.na(infch_4y)))
tab2[9,7] <- sum(!is.na(inf_frac_pos) & !is.na(infch_4y))

tab2[1,which.max(tab2[1,1:6])] <- paste("\\textbf{",tab2[1,which.max(tab2[1,1:6])],"}",sep="")
tab2[5,which.min(tab2[5,1:6])] <- paste("\\textbf{",tab2[5,which.min(tab2[5,1:6])],"}",sep="")
tab2[9,which.min(tab2[9,1:6])] <- paste("\\textbf{",tab2[9,which.min(tab2[9,1:6])],"}",sep="")

# corrected for measurement error
tab2[2,1] <- dig2(cor.me(gr_frac_pos,gr_frac_pos_oth,gr,subset=newsid<=32&!is.na(gr_4y)))
tab2[2,2] <- dig2(cor.me(gr_frac_pos,gr_frac_pos_oth,gr_qr,subset=newsid<=32&!is.na(gr_4y)))
tab2[2,3] <- dig2(cor.me(gr_frac_pos,gr_frac_pos_oth,gr_sy,subset=newsid<=32&!is.na(gr_4y)))
tab2[2,4] <- dig2(cor.me(gr_frac_pos,gr_frac_pos_oth,gr_yr,subset=newsid<=32&!is.na(gr_4y)))
tab2[2,5] <- dig2(cor.me(gr_frac_pos,gr_frac_pos_oth,gr_2y,subset=newsid<=32&!is.na(gr_4y)))
tab2[2,6] <- dig2(cor.me(gr_frac_pos,gr_frac_pos_oth,gr_4y,subset=newsid<=32&!is.na(gr_4y)))
tab2[2,7] <- sum(!is.na(gr_frac_pos) & !is.na(gr_frac_pos_oth) & !is.na(gr_4y))

tab2[4,1] <- dig2(cor.me(un_frac_pos,un_frac_pos_oth,un,subset=newsid<=32&!is.na(unch_4y)))
tab2[4,2] <- dig2(cor.me(un_frac_pos,un_frac_pos_oth,un_qr,subset=newsid<=32&!is.na(unch_4y)))
tab2[4,3] <- dig2(cor.me(un_frac_pos,un_frac_pos_oth,un_sy,subset=newsid<=32&!is.na(unch_4y)))
tab2[4,4] <- dig2(cor.me(un_frac_pos,un_frac_pos_oth,un_yr,subset=newsid<=32&!is.na(unch_4y)))
tab2[4,5] <- dig2(cor.me(un_frac_pos,un_frac_pos_oth,un_2y,subset=newsid<=32&!is.na(unch_4y)))
tab2[4,6] <- dig2(cor.me(un_frac_pos,un_frac_pos_oth,un_4y,subset=newsid<=32&!is.na(unch_4y)))
tab2[4,7] <- sum(!is.na(un_frac_pos) & !is.na(un_frac_pos_oth) & !is.na(unch_4y))

tab2[6,1] <- dig2(cor.me(un_frac_pos,un_frac_pos_oth,unch,subset=newsid<=32&!is.na(unch_4y)))
tab2[6,2] <- dig2(cor.me(un_frac_pos,un_frac_pos_oth,unch_qr,subset=newsid<=32&!is.na(unch_4y)))
tab2[6,3] <- dig2(cor.me(un_frac_pos,un_frac_pos_oth,unch_sy,subset=newsid<=32&!is.na(unch_4y)))
tab2[6,4] <- dig2(cor.me(un_frac_pos,un_frac_pos_oth,unch_yr,subset=newsid<=32&!is.na(unch_4y)))
tab2[6,5] <- dig2(cor.me(un_frac_pos,un_frac_pos_oth,unch_2y,subset=newsid<=32&!is.na(unch_4y)))
tab2[6,6] <- dig2(cor.me(un_frac_pos,un_frac_pos_oth,unch_4y,subset=newsid<=32&!is.na(unch_4y)))
tab2[6,7] <- sum(!is.na(un_frac_pos) & !is.na(un_frac_pos_oth) & !is.na(unch_4y))

tab2[8,1] <- dig2(cor.me(inf_frac_pos,inf_frac_pos_oth,inf,subset=newsid<=32&!is.na(unch_4y)))
tab2[8,2] <- dig2(cor.me(inf_frac_pos,inf_frac_pos_oth,inf_qr,subset=newsid<=32&!is.na(unch_4y)))
tab2[8,3] <- dig2(cor.me(inf_frac_pos,inf_frac_pos_oth,inf_sy,subset=newsid<=32&!is.na(unch_4y)))
tab2[8,4] <- dig2(cor.me(inf_frac_pos,inf_frac_pos_oth,inf_yr,subset=newsid<=32&!is.na(unch_4y)))
tab2[8,5] <- dig2(cor.me(inf_frac_pos,inf_frac_pos_oth,inf_2y,subset=newsid<=32&!is.na(unch_4y)))
tab2[8,6] <- dig2(cor.me(inf_frac_pos,inf_frac_pos_oth,inf_4y,subset=newsid<=32&!is.na(unch_4y)))
tab2[8,7] <- sum(!is.na(inf_frac_pos) & !is.na(inf_frac_pos_oth) & !is.na(infch_4y))

tab2[10,1] <- dig2(cor.me(inf_frac_pos,inf_frac_pos_oth,infch,subset=newsid<=32&!is.na(unch_4y)))
tab2[10,2] <- dig2(cor.me(inf_frac_pos,inf_frac_pos_oth,infch_qr,subset=newsid<=32&!is.na(unch_4y)))
tab2[10,3] <- dig2(cor.me(inf_frac_pos,inf_frac_pos_oth,infch_sy,subset=newsid<=32&!is.na(unch_4y)))
tab2[10,4] <- dig2(cor.me(inf_frac_pos,inf_frac_pos_oth,infch_yr,subset=newsid<=32&!is.na(unch_4y)))
tab2[10,5] <- dig2(cor.me(inf_frac_pos,inf_frac_pos_oth,infch_2y,subset=newsid<=32&!is.na(unch_4y)))
tab2[10,6] <- dig2(cor.me(inf_frac_pos,inf_frac_pos_oth,infch_4y,subset=newsid<=32&!is.na(unch_4y)))
tab2[10,7] <- sum(!is.na(inf_frac_pos) & !is.na(inf_frac_pos_oth) & !is.na(infch_4y))

tab2[2,which.max(tab2[2,1:6])] <- paste("\\textbf{",tab2[2,which.max(tab2[2,1:6])],"}",sep="")
tab2[6,which.min(tab2[6,1:6])] <- paste("\\textbf{",tab2[6,which.min(tab2[6,1:6])],"}",sep="")
tab2[10,which.min(tab2[10,1:6])] <- paste("\\textbf{",tab2[10,which.min(tab2[10,1:6])],"}",sep="")

tab2

# table 3
pred1 <- function(coef,econs) { coef[1] + t(coef[2:4]) %*% econs + median0(c(0,coef[5:length(coef)])) }

tab3 <- matrix(rep(NA,4*22),nrow=22)

lm1 <- lm0(econ_frac_pos ~ gr_yr + unch_yr + infch_yr + factor(newsid),subset=newsid<=32,se="cluster",unitid=newsid)
lm2 <- lm0(econ_frac_pos ~ gr_yr + unch_yr + infch_yr + factor(newsid),subset=newsid<=32,se="cluster",unitid=country)
tab3[1:8,1] <- as.vector(t(cbind(as.coef(lm1$coef[1:4],lm1$se[1:4]),as.se(lm1$se[1:4]))))
tab3[9,1] <- lm1$N
tab3[10,1] <- lm1$Clusters
tab3[11,1] <- lm2$Clusters
tab3[12,1] <- dig3(lm1$r.squared)
d <- delta.method(pred1,lm1$coef,lm1$V,econs=c(grs1,unchs1,infchs1))
tab3[13,1] <- dig3(d$est)
tab3[14,1] <- as.se(d$se)
d <- delta.method(pred1,lm1$coef,lm1$V,econs=c(grs2,unchs2,infchs2))
tab3[15,1] <- dig3(d$est)
tab3[16,1] <- as.se(d$se)
d <- delta.method(pred1,lm1$coef,lm1$V,econs=c(grs3,unchs3,infchs3))
tab3[17,1] <- dig3(d$est)
tab3[18,1] <- as.se(d$se)
d <- delta.method(pred1,lm1$coef,lm1$V,econs=c(grs4,unchs4,infchs4))
tab3[19,1] <- dig3(d$est)
tab3[20,1] <- as.se(d$se)
d <- delta.method(pred1,lm1$coef,lm1$V,econs=c(grs5,unchs5,infchs5))
tab3[21,1] <- dig3(d$est)
tab3[22,1] <- as.se(d$se)

lm1 <- lm0(gr_frac_pos ~ gr_yr + unch_yr + infch_yr + factor(newsid),subset=newsid<=32,se="cluster",unitid=newsid)
lm2 <- lm0(gr_frac_pos ~ gr_yr + unch_yr + infch_yr + factor(newsid),subset=newsid<=32,se="cluster",unitid=country)
tab3[1:8,2] <- as.vector(t(cbind(as.coef(lm1$coef[1:4],lm1$se[1:4]),as.se(lm1$se[1:4]))))
tab3[9,2] <- lm1$N
tab3[10,2] <- lm1$Clusters
tab3[11,2] <- lm2$Clusters
tab3[12,2] <- dig3(lm1$r.squared)
d <- delta.method(pred1,lm1$coef,lm1$V,econs=c(grs1,unchs1,infchs1))
tab3[13,2] <- dig3(d$est)
tab3[14,2] <- as.se(d$se)
d <- delta.method(pred1,lm1$coef,lm1$V,econs=c(grs2,unchs2,infchs2))
tab3[15,2] <- dig3(d$est)
tab3[16,2] <- as.se(d$se)
d <- delta.method(pred1,lm1$coef,lm1$V,econs=c(grs3,unchs3,infchs3))
tab3[17,2] <- dig3(d$est)
tab3[18,2] <- as.se(d$se)
d <- delta.method(pred1,lm1$coef,lm1$V,econs=c(grs4,unchs4,infchs4))
tab3[19,2] <- dig3(d$est)
tab3[20,2] <- as.se(d$se)
d <- delta.method(pred1,lm1$coef,lm1$V,econs=c(grs5,unchs5,infchs5))
tab3[21,2] <- dig3(d$est)
tab3[22,2] <- as.se(d$se)

lm1 <- lm0(un_frac_pos ~ gr_yr + unch_yr + infch_yr + factor(newsid),subset=newsid<=32,se="cluster",unitid=newsid)
lm2 <- lm0(un_frac_pos ~ gr_yr + unch_yr + infch_yr + factor(newsid),subset=newsid<=32,se="cluster",unitid=country)
tab3[1:8,3] <- as.vector(t(cbind(as.coef(lm1$coef[1:4],lm1$se[1:4]),as.se(lm1$se[1:4]))))
tab3[9,3] <- lm1$N
tab3[10,3] <- lm1$Clusters
tab3[11,3] <- lm2$Clusters
tab3[12,3] <- dig3(lm1$r.squared)
d <- delta.method(pred1,lm1$coef,lm1$V,econs=c(grs1,unchs1,infchs1))
tab3[13,3] <- dig3(d$est)
tab3[14,3] <- as.se(d$se)
d <- delta.method(pred1,lm1$coef,lm1$V,econs=c(grs2,unchs2,infchs2))
tab3[15,3] <- dig3(d$est)
tab3[16,3] <- as.se(d$se)
d <- delta.method(pred1,lm1$coef,lm1$V,econs=c(grs3,unchs3,infchs3))
tab3[17,3] <- dig3(d$est)
tab3[18,3] <- as.se(d$se)
d <- delta.method(pred1,lm1$coef,lm1$V,econs=c(grs4,unchs4,infchs4))
tab3[19,3] <- dig3(d$est)
tab3[20,3] <- as.se(d$se)
d <- delta.method(pred1,lm1$coef,lm1$V,econs=c(grs5,unchs5,infchs5))
tab3[21,3] <- dig3(d$est)
tab3[22,3] <- as.se(d$se)

lm1 <- lm0(inf_frac_pos ~ gr_yr + unch_yr + infch_yr + factor(newsid),subset=newsid<=32,se="cluster",unitid=newsid)
lm2 <- lm0(inf_frac_pos ~ gr_yr + unch_yr + infch_yr + factor(newsid),subset=newsid<=32,se="cluster",unitid=country)
tab3[1:8,4] <- as.vector(t(cbind(as.coef(lm1$coef[1:4],lm1$se[1:4]),as.se(lm1$se[1:4]))))
tab3[9,4] <- lm1$N
tab3[10,4] <- lm1$Clusters
tab3[11,4] <- lm2$Clusters
tab3[12,4] <- dig3(lm1$r.squared)
d <- delta.method(pred1,lm1$coef,lm1$V,econs=c(grs1,unchs1,infchs1))
tab3[13,4] <- dig3(d$est)
tab3[14,4] <- as.se(d$se)
d <- delta.method(pred1,lm1$coef,lm1$V,econs=c(grs2,unchs2,infchs2))
tab3[15,4] <- dig3(d$est)
tab3[16,4] <- as.se(d$se)
d <- delta.method(pred1,lm1$coef,lm1$V,econs=c(grs3,unchs3,infchs3))
tab3[17,4] <- dig3(d$est)
tab3[18,4] <- as.se(d$se)
d <- delta.method(pred1,lm1$coef,lm1$V,econs=c(grs4,unchs4,infchs4))
tab3[19,4] <- dig3(d$est)
tab3[20,4] <- as.se(d$se)
d <- delta.method(pred1,lm1$coef,lm1$V,econs=c(grs5,unchs5,infchs5))
tab3[21,4] <- dig3(d$est)
tab3[22,4] <- as.se(d$se)
tab3

# table 4
tab4 <- matrix(rep(NA,5*7),nrow=5)

tab4[1,1] <- dig2(cor0(gr_sh,gr,subset=newsid<=32& !is.na(gr_4y)))
tab4[1,2] <- dig2(cor0(gr_sh,gr_qr,subset=newsid<=32& !is.na(gr_4y)))
tab4[1,3] <- dig2(cor0(gr_sh,gr_sy,subset=newsid<=32& !is.na(gr_4y)))
tab4[1,4] <- dig2(cor0(gr_sh,gr_yr,subset=newsid<=32& !is.na(gr_4y)))
tab4[1,5] <- dig2(cor0(gr_sh,gr_2y,subset=newsid<=32& !is.na(gr_4y)))
tab4[1,6] <- dig2(cor0(gr_sh,gr_4y,subset=newsid<=32& !is.na(gr_4y)))
tab4[1,7] <- sum(!is.na(gr_sh) & !is.na(gr_4y))

tab4[2,1] <- dig2(cor0(un_sh,un,subset=newsid<=32 & !is.na(unch_4y)))
tab4[2,2] <- dig2(cor0(un_sh,un_qr,subset=newsid<=32 & !is.na(unch_4y)))
tab4[2,3] <- dig2(cor0(un_sh,un_sy,subset=newsid<=32 & !is.na(unch_4y)))
tab4[2,4] <- dig2(cor0(un_sh,un_yr,subset=newsid<=32 & !is.na(unch_4y)))
tab4[2,5] <- dig2(cor0(un_sh,un_2y,subset=newsid<=32 & !is.na(unch_4y)))
tab4[2,6] <- dig2(cor0(un_sh,un_4y,subset=newsid<=32 & !is.na(unch_4y)))
tab4[2,7] <- sum(!is.na(un_sh) & !is.na(unch_4y))

tab4[3,1] <- dig2(cor0(un_sh,unch,subset=newsid<=32 & !is.na(unch_4y)))
tab4[3,2] <- dig2(cor0(un_sh,unch_qr,subset=newsid<=32 & !is.na(unch_4y)))
tab4[3,3] <- dig2(cor0(un_sh,unch_sy,subset=newsid<=32 & !is.na(unch_4y)))
tab4[3,4] <- dig2(cor0(un_sh,unch_yr,subset=newsid<=32 & !is.na(unch_4y)))
tab4[3,5] <- dig2(cor0(un_sh,unch_2y,subset=newsid<=32 & !is.na(unch_4y)))
tab4[3,6] <- dig2(cor0(un_sh,unch_4y,subset=newsid<=32 & !is.na(unch_4y)))
tab4[3,7] <- sum(!is.na(un_sh) & !is.na(unch_4y))

tab4[4,1] <- dig2(cor0(inf_sh,inf,subset=newsid<=32& !is.na(infch_4y)))
tab4[4,2] <- dig2(cor0(inf_sh,inf_qr,subset=newsid<=32& !is.na(infch_4y)))
tab4[4,3] <- dig2(cor0(inf_sh,inf_sy,subset=newsid<=32& !is.na(infch_4y)))
tab4[4,4] <- dig2(cor0(inf_sh,inf_yr,subset=newsid<=32& !is.na(infch_4y)))
tab4[4,5] <- dig2(cor0(inf_sh,inf_2y,subset=newsid<=32& !is.na(infch_4y)))
tab4[4,6] <- dig2(cor0(inf_sh,inf_4y,subset=newsid<=32& !is.na(infch_4y)))
tab4[4,7] <- sum(!is.na(inf_sh) & !is.na(infch_4y))

tab4[5,1] <- dig2(cor0(inf_sh,infch,subset=newsid<=32& !is.na(infch_4y)))
tab4[5,2] <- dig2(cor0(inf_sh,infch_qr,subset=newsid<=32& !is.na(infch_4y)))
tab4[5,3] <- dig2(cor0(inf_sh,infch_sy,subset=newsid<=32& !is.na(infch_4y)))
tab4[5,4] <- dig2(cor0(inf_sh,infch_yr,subset=newsid<=32& !is.na(infch_4y)))
tab4[5,5] <- dig2(cor0(inf_sh,infch_2y,subset=newsid<=32& !is.na(infch_4y)))
tab4[5,6] <- dig2(cor0(inf_sh,infch_4y,subset=newsid<=32& !is.na(infch_4y)))
tab4[5,7] <- sum(!is.na(inf_sh) & !is.na(infch_4y))

tab4[1,which.min(tab4[1,1:6])] <- paste("\\textbf{",tab4[1,which.min(tab4[1,1:6])],"}",sep="")
tab4[2,4] <- paste("\\textbf{",tab4[2,4],"}",sep="")
tab4[4,which.max(tab4[4,1:6])] <- paste("\\textbf{",tab4[4,which.max(tab4[4,1:6])],"}",sep="")

tab4

# table 5
tab5 <- matrix(rep("",4*10),nrow=10)

lm1 <- lm0(econ_per_article ~ gr_yr + un_yr + inf_yr + factor(newsid),subset=newsid<=32,se="cluster",unitid=newsid)
lm2 <- lm0(econ_per_article ~ gr_yr + un_yr + inf_yr + factor(newsid),subset=newsid<=32,se="cluster",unitid=country)
tab5[1,1] <- as.coef(lm1$coef[2],lm1$se[2])
tab5[2,1] <- as.se(lm1$se[2])
tab5[3,1] <- as.coef(lm1$coef[3],lm1$se[3])
tab5[4,1] <- as.se(lm1$se[3])
tab5[5,1] <- as.coef(lm1$coef[4],lm1$se[4])
tab5[6,1] <- as.se(lm1$se[4])
tab5[7,1] <- lm1$N
tab5[8,1] <- lm1$Clusters
tab5[9,1] <- lm2$Clusters
tab5[10,1] <- dig3(lm1$r.squared)

lm1 <- lm0(gr_sh ~ gr_yr + factor(newsid),subset=newsid<=32,se="cluster",unitid=newsid)
lm2 <- lm0(gr_sh ~ gr_yr + factor(newsid),subset=newsid<=32,se="cluster",unitid=country)
tab5[1,2] <- as.coef(lm1$coef[2],lm1$se[2])
tab5[2,2] <- as.se(lm1$se[2])
tab5[7,2] <- lm1$N
tab5[8,2] <- lm1$Clusters
tab5[9,2] <- lm2$Clusters
tab5[10,2] <- dig3(lm1$r.squared)

lm1 <- lm0(un_sh ~ un_yr + factor(newsid),subset=newsid<=32,se="cluster",unitid=newsid)
lm2 <- lm0(un_sh ~ un_yr + factor(newsid),subset=newsid<=32,se="cluster",unitid=country)
tab5[3,3] <- as.coef(lm1$coef[2],lm1$se[2])
tab5[4,3] <- as.se(lm1$se[2])
tab5[7,3] <- lm1$N
tab5[8,3] <- lm1$Clusters
tab5[9,3] <- lm2$Clusters
tab5[10,3] <- dig3(lm1$r.squared)

lm1 <- lm0(inf_sh ~ inf_yr + factor(newsid),subset=newsid<=32,se="cluster",unitid=newsid)
lm2 <- lm0(inf_sh ~ inf_yr + factor(newsid),subset=newsid<=32,se="cluster",unitid=country)
tab5[5,4] <- as.coef(lm1$coef[2],lm1$se[2])
tab5[6,4] <- as.se(lm1$se[2])
tab5[7,4] <- lm1$N
tab5[8,4] <- lm1$Clusters
tab5[9,4] <- lm2$Clusters
tab5[10,4] <- dig3(lm1$r.squared)

tab5

# table 6
tab6 <- matrix(rep(NA,2*16),nrow=16)
for(i in 1:16)
{
	temp1 <- cor0(subset(econ_frac_pos,newsid==2*i-1),subset(econ_frac_pos,newsid==2*i))
	x1 <- subset(econ_frac_pos,newsid==2*i-1)
	x2 <- subset(econ_frac_pos,newsid==2*i)
	print(c(countries[i],clang[i],round(temp1,2),sum(!is.na(x1)&!is.na(x2))))
	tab6[i,1] <- dig2(temp1)
	tab6[i,2] <- sum(!is.na(x1)&!is.na(x2))
}
tab6

# table 7
tab7 <- matrix(rep("",19*6),nrow=19)

lm1 <- lm0(gr_frac_pos ~ gr_yr + ideomatch + gr_yr_ideomatch + factor(newsid),subset=newsid<=32,se="cluster",unitid=newsid)
lm2 <- lm0(gr_frac_pos ~ gr_yr + ideomatch + gr_yr_ideomatch + factor(newsid),subset=newsid<=32,se="cluster",unitid=country)
tab7[1,1] <- as.coef(lm1$coef[2],lm1$se[2])
tab7[2,1] <- as.se(lm1$se[2])
tab7[7,1] <- as.coef(lm1$coef[3],lm1$se[3])
tab7[8,1] <- as.se(lm1$se[3])
tab7[9,1] <- as.coef(lm1$coef[4],lm1$se[4])
tab7[10,1] <- as.se(lm1$se[4])
tab7[15,1] <- lm1$N
tab7[16,1] <- lm1$Clusters
tab7[17,1] <- lm2$Clusters
tab7[18,1] <- dig3(lm1$r.squared)
tab7[19,1] <- paste(dig3(wald.test(wald34,lm1$coef,lm1$V)$pval),stars.pval(wald.test(wald34,lm1$coef,lm1$V)$pval),sep="")

lm1 <- lm0(un_frac_pos ~ gr_yr + unch_yr + ideomatch + gr_yr_ideomatch + unch_yr_ideomatch + factor(newsid),subset=newsid<=32,se="cluster",unitid=newsid)
lm2 <- lm0(un_frac_pos ~ gr_yr + unch_yr + ideomatch + gr_yr_ideomatch + unch_yr_ideomatch + factor(newsid),subset=newsid<=32,se="cluster",unitid=country)
tab7[1,2] <- as.coef(lm1$coef[2],lm1$se[2])
tab7[2,2] <- as.se(lm1$se[2])
tab7[3,2] <- as.coef(lm1$coef[3],lm1$se[3])
tab7[4,2] <- as.se(lm1$se[3])
tab7[7,2] <- as.coef(lm1$coef[4],lm1$se[4])
tab7[8,2] <- as.se(lm1$se[4])
tab7[9,2] <- as.coef(lm1$coef[5],lm1$se[5])
tab7[10,2] <- as.se(lm1$se[5])
tab7[11,2] <- as.coef(lm1$coef[6],lm1$se[6])
tab7[12,2] <- as.se(lm1$se[6])
tab7[15,2] <- lm1$N
tab7[16,2] <- lm1$Clusters
tab7[17,2] <- lm2$Clusters
tab7[18,2] <- dig3(lm1$r.squared)
tab7[19,2] <- paste(dig3(wald.test(wald456,lm1$coef,lm1$V)$pval),stars.pval(wald.test(wald456,lm1$coef,lm1$V)$pval),sep="")

lm1 <- lm0(inf_frac_pos ~ gr_yr + infch_yr + ideomatch + gr_yr_ideomatch + infch_yr_ideomatch + factor(newsid),subset=newsid<=32,se="cluster",unitid=newsid)
lm2 <- lm0(inf_frac_pos ~ gr_yr + infch_yr + ideomatch + gr_yr_ideomatch + infch_yr_ideomatch + factor(newsid),subset=newsid<=32,se="cluster",unitid=country)
tab7[1,3] <- as.coef(lm1$coef[2],lm1$se[2])
tab7[2,3] <- as.se(lm1$se[2])
tab7[5,3] <- as.coef(lm1$coef[3],lm1$se[3])
tab7[6,3] <- as.se(lm1$se[3])
tab7[7,3] <- as.coef(lm1$coef[4],lm1$se[4])
tab7[8,3] <- as.se(lm1$se[4])
tab7[9,3] <- as.coef(lm1$coef[5],lm1$se[5])
tab7[10,3] <- as.se(lm1$se[5])
tab7[13,3] <- as.coef(lm1$coef[6],lm1$se[6])
tab7[14,3] <- as.se(lm1$se[6])
tab7[15,3] <- lm1$N
tab7[16,3] <- lm1$Clusters
tab7[17,3] <- lm2$Clusters
tab7[18,3] <- dig3(lm1$r.squared)
tab7[19,3] <- paste(dig3(wald.test(wald456,lm1$coef,lm1$V)$pval),stars.pval(wald.test(wald456,lm1$coef,lm1$V)$pval),sep="")

lm1 <- lm0(gr_frac_pos_hl ~ gr_yr + ideomatch + gr_yr_ideomatch + factor(newsid),subset=newsid<=32,se="cluster",unitid=newsid)
lm2 <- lm0(gr_frac_pos_hl ~ gr_yr + ideomatch + gr_yr_ideomatch + factor(newsid),subset=newsid<=32,se="cluster",unitid=country)
tab7[1,4] <- as.coef(lm1$coef[2],lm1$se[2])
tab7[2,4] <- as.se(lm1$se[2])
tab7[7,4] <- as.coef(lm1$coef[3],lm1$se[3])
tab7[8,4] <- as.se(lm1$se[3])
tab7[9,4] <- as.coef(lm1$coef[4],lm1$se[4])
tab7[10,4] <- as.se(lm1$se[4])
tab7[15,4] <- lm1$N
tab7[16,4] <- lm1$Clusters
tab7[17,4] <- lm2$Clusters
tab7[18,4] <- dig3(lm1$r.squared)
tab7[19,4] <- paste(dig3(wald.test(wald34,lm1$coef,lm1$V)$pval),stars.pval(wald.test(wald34,lm1$coef,lm1$V)$pval),sep="")

lm1 <- lm0(un_frac_pos_hl ~ gr_yr + unch_yr + ideomatch + gr_yr_ideomatch + unch_yr_ideomatch + factor(newsid),subset=newsid<=32,se="cluster",unitid=newsid)
lm2 <- lm0(un_frac_pos_hl ~ gr_yr + unch_yr + ideomatch + gr_yr_ideomatch + unch_yr_ideomatch + factor(newsid),subset=newsid<=32,se="cluster",unitid=country)
tab7[1,5] <- as.coef(lm1$coef[2],lm1$se[2])
tab7[2,5] <- as.se(lm1$se[2])
tab7[3,5] <- as.coef(lm1$coef[3],lm1$se[3])
tab7[4,5] <- as.se(lm1$se[3])
tab7[7,5] <- as.coef(lm1$coef[4],lm1$se[4])
tab7[8,5] <- as.se(lm1$se[4])
tab7[9,5] <- as.coef(lm1$coef[5],lm1$se[5])
tab7[10,5] <- as.se(lm1$se[5])
tab7[11,5] <- as.coef(lm1$coef[6],lm1$se[6])
tab7[12,5] <- as.se(lm1$se[6])
tab7[15,5] <- lm1$N
tab7[16,5] <- lm1$Clusters
tab7[17,5] <- lm2$Clusters
tab7[18,5] <- dig3(lm1$r.squared)
tab7[19,5] <- paste(dig3(wald.test(wald456,lm1$coef,lm1$V)$pval),stars.pval(wald.test(wald456,lm1$coef,lm1$V)$pval),sep="")

lm1 <- lm0(inf_frac_pos_hl ~ gr_yr + infch_yr + ideomatch + gr_yr_ideomatch + infch_yr_ideomatch + factor(newsid),subset=newsid<=32,se="cluster",unitid=newsid)
lm2 <- lm0(inf_frac_pos_hl ~ gr_yr + infch_yr + ideomatch + gr_yr_ideomatch + infch_yr_ideomatch + factor(newsid),subset=newsid<=32,se="cluster",unitid=country)
tab7[1,6] <- as.coef(lm1$coef[2],lm1$se[2])
tab7[2,6] <- as.se(lm1$se[2])
tab7[5,6] <- as.coef(lm1$coef[3],lm1$se[3])
tab7[6,6] <- as.se(lm1$se[3])
tab7[7,6] <- as.coef(lm1$coef[4],lm1$se[4])
tab7[8,6] <- as.se(lm1$se[4])
tab7[9,6] <- as.coef(lm1$coef[5],lm1$se[5])
tab7[10,6] <- as.se(lm1$se[5])
tab7[13,6] <- as.coef(lm1$coef[6],lm1$se[6])
tab7[14,6] <- as.se(lm1$se[6])
tab7[15,6] <- lm1$N
tab7[16,6] <- lm1$Clusters
tab7[17,6] <- lm2$Clusters
tab7[18,6] <- dig3(lm1$r.squared)
tab7[19,6] <- paste(dig3(wald.test(wald456,lm1$coef,lm1$V)$pval),stars.pval(wald.test(wald456,lm1$coef,lm1$V)$pval),sep="")

tab7

# table 8
tab8 <- matrix(rep("",19*6),nrow=19)

lm1 <- lm0(gr_sh ~ gr_yr + ideomatch + gr_yr_ideomatch + factor(newsid),subset=newsid<=32,se="cluster",unitid=newsid)
lm2 <- lm0(gr_sh ~ gr_yr + ideomatch + gr_yr_ideomatch + factor(newsid),subset=newsid<=32,se="cluster",unitid=country)
tab8[1,1] <- as.coef(lm1$coef[2],lm1$se[2])
tab8[2,1] <- as.se(lm1$se[2])
tab8[7,1] <- as.coef(lm1$coef[3],lm1$se[3])
tab8[8,1] <- as.se(lm1$se[3])
tab8[9,1] <- as.coef(lm1$coef[4],lm1$se[4])
tab8[10,1] <- as.se(lm1$se[4])
tab8[15,1] <- lm1$N
tab8[16,1] <- lm1$Clusters
tab8[17,1] <- lm2$Clusters
tab8[18,1] <- dig3(lm1$r.squared)
tab8[19,1] <- paste(dig3(wald.test(wald34,lm1$coef,lm1$V)$pval),stars.pval(wald.test(wald34,lm1$coef,lm1$V)$pval),sep="")

lm1 <- lm0(un_sh ~ un_yr + ideomatch + un_yr_ideomatch + factor(newsid),subset=newsid<=32,se="cluster",unitid=newsid)
lm2 <- lm0(un_sh ~ un_yr + ideomatch + un_yr_ideomatch + factor(newsid),subset=newsid<=32,se="cluster",unitid=country)
tab8[3,2] <- as.coef(lm1$coef[2],lm1$se[2])
tab8[4,2] <- as.se(lm1$se[2])
tab8[7,2] <- as.coef(lm1$coef[3],lm1$se[3])
tab8[8,2] <- as.se(lm1$se[3])
tab8[11,2] <- as.coef(lm1$coef[4],lm1$se[4])
tab8[12,2] <- as.se(lm1$se[4])
tab8[15,2] <- lm1$N
tab8[16,2] <- lm1$Clusters
tab8[17,2] <- lm2$Clusters
tab8[18,2] <- dig3(lm1$r.squared)
tab8[19,2] <- paste(dig3(wald.test(wald34,lm1$coef,lm1$V)$pval),stars.pval(wald.test(wald34,lm1$coef,lm1$V)$pval),sep="")

lm1 <- lm0(inf_sh ~ inf_yr + ideomatch + inf_yr_ideomatch + factor(newsid),subset=newsid<=32,se="cluster",unitid=newsid)
lm2 <- lm0(inf_sh ~ inf_yr + ideomatch + inf_yr_ideomatch + factor(newsid),subset=newsid<=32,se="cluster",unitid=country)
tab8[5,3] <- as.coef(lm1$coef[2],lm1$se[2])
tab8[6,3] <- as.se(lm1$se[2])
tab8[7,3] <- as.coef(lm1$coef[3],lm1$se[3])
tab8[8,3] <- as.se(lm1$se[3])
tab8[13,3] <- as.coef(lm1$coef[4],lm1$se[4])
tab8[14,3] <- as.se(lm1$se[4])
tab8[15,3] <- lm1$N
tab8[16,3] <- lm1$Clusters
tab8[17,3] <- lm2$Clusters
tab8[18,3] <- dig3(lm1$r.squared)
tab8[19,3] <- paste(dig3(wald.test(wald34,lm1$coef,lm1$V)$pval),stars.pval(wald.test(wald34,lm1$coef,lm1$V)$pval),sep="")

lm1 <- lm0(gr_sh_hl ~ gr_yr + ideomatch + gr_yr_ideomatch + factor(newsid),subset=newsid<=32,se="cluster",unitid=newsid)
lm2 <- lm0(gr_sh_hl ~ gr_yr + ideomatch + gr_yr_ideomatch + factor(newsid),subset=newsid<=32,se="cluster",unitid=country)
tab8[1,4] <- as.coef(lm1$coef[2],lm1$se[2])
tab8[2,4] <- as.se(lm1$se[2])
tab8[7,4] <- as.coef(lm1$coef[3],lm1$se[3])
tab8[8,4] <- as.se(lm1$se[3])
tab8[9,4] <- as.coef(lm1$coef[4],lm1$se[4])
tab8[10,4] <- as.se(lm1$se[4])
tab8[15,4] <- lm1$N
tab8[16,4] <- lm1$Clusters
tab8[17,4] <- lm2$Clusters
tab8[18,4] <- dig3(lm1$r.squared)
tab8[19,4] <- paste(dig3(wald.test(wald34,lm1$coef,lm1$V)$pval),stars.pval(wald.test(wald34,lm1$coef,lm1$V)$pval),sep="")

lm1 <- lm0(un_sh_hl ~ un_yr + ideomatch + un_yr_ideomatch + factor(newsid),subset=newsid<=32,se="cluster",unitid=newsid)
lm2 <- lm0(un_sh_hl ~ un_yr + ideomatch + un_yr_ideomatch + factor(newsid),subset=newsid<=32,se="cluster",unitid=country)
tab8[3,5] <- as.coef(lm1$coef[2],lm1$se[2])
tab8[4,5] <- as.se(lm1$se[2])
tab8[7,5] <- as.coef(lm1$coef[3],lm1$se[3])
tab8[8,5] <- as.se(lm1$se[3])
tab8[11,5] <- as.coef(lm1$coef[4],lm1$se[4])
tab8[12,5] <- as.se(lm1$se[4])
tab8[15,5] <- lm1$N
tab8[16,5] <- lm1$Clusters
tab8[17,5] <- lm2$Clusters
tab8[18,5] <- dig3(lm1$r.squared)
tab8[19,5] <- paste(dig3(wald.test(wald34,lm1$coef,lm1$V)$pval),stars.pval(wald.test(wald34,lm1$coef,lm1$V)$pval),sep="")

lm1 <- lm0(inf_sh_hl ~ inf_yr + ideomatch + inf_yr_ideomatch + factor(newsid),subset=newsid<=32,se="cluster",unitid=newsid)
lm2 <- lm0(inf_sh_hl ~ inf_yr + ideomatch + inf_yr_ideomatch + factor(newsid),subset=newsid<=32,se="cluster",unitid=country)
tab8[5,6] <- as.coef(lm1$coef[2],lm1$se[2])
tab8[6,6] <- as.se(lm1$se[2])
tab8[7,6] <- as.coef(lm1$coef[3],lm1$se[3])
tab8[8,6] <- as.se(lm1$se[3])
tab8[13,6] <- as.coef(lm1$coef[4],lm1$se[4])
tab8[14,6] <- as.se(lm1$se[4])
tab8[15,6] <- lm1$N
tab8[16,6] <- lm1$Clusters
tab8[17,6] <- lm2$Clusters
tab8[18,6] <- dig3(lm1$r.squared)
tab8[19,6] <- paste(dig3(wald.test(wald34,lm1$coef,lm1$V)$pval),stars.pval(wald.test(wald34,lm1$coef,lm1$V)$pval),sep="")

tab8

# table A1
tabA1 <- matrix(rep("",44*8),nrow=44)

for(j in 1:4)
{
	cs <- list()
	cs[[1]] <- check.rats(ratmat[,j],itemid,train==0&type=="articles")
	cs[[2]] <- check.rats(ratmat[,j],itemid,train==0&type=="headlines")

	cs[[3]] <- check.rats(ratmat[,j],itemid,train==0&type=="articles"&lang=="english")
	cs[[4]] <- check.rats(ratmat[,j],itemid,train==0&type=="headlines"&lang=="english")

	cs[[5]] <- check.rats(ratmat[,j],itemid,train==0&type=="articles"&lang=="french")
	cs[[6]] <- check.rats(ratmat[,j],itemid,train==0&type=="headlines"&lang=="french")

	cs[[7]] <- check.rats(ratmat[,j],itemid,train==0&type=="articles"&lang=="german")
	cs[[8]] <- check.rats(ratmat[,j],itemid,train==0&type=="headlines"&lang=="german")

	for(i in 1:8)
	{
		tabA1[11*(j-1)+1,i] <- dig3(cs[[i]]$bothyes)
		tabA1[11*(j-1)+2,i] <- dig3(cs[[i]]$bothno)
		tabA1[11*(j-1)+3,i] <- dig3(cs[[i]]$err2)
		tabA1[11*(j-1)+4,i] <- dig3(cs[[i]]$kappa2)
		tabA1[11*(j-1)+5,i] <- cs[[i]]$n2
		tabA1[11*(j-1)+6,i] <- dig3(cs[[i]]$corr)
		tabA1[11*(j-1)+7,i] <- dig3(cs[[i]]$samedir)
		tabA1[11*(j-1)+8,i] <- dig3(cs[[i]]$nueterr)
		tabA1[11*(j-1)+9,i] <- dig3(cs[[i]]$err)
		tabA1[11*(j-1)+10,i] <- dig3(cs[[i]]$kappa)
		tabA1[11*(j-1)+11,i] <- cs[[i]]$n
	}
}

tabA1

# table A2
se1 <- (econ_frac_pos * (1 - econ_frac_pos) / econ_tot)^.5
me1 <- mean0(se1,by=newsid)
lower1 <- drop.na(quantile0(se1,probs=0.025,by=newsid,subset=newsid<=32))
upper1 <- drop.na(quantile0(se1,probs=0.975,by=newsid,subset=newsid<=32))
tabA2 <- cbind(dig3(me1),dig3(lower1),dig3(upper1))

tabA2

# Table A3
tabA3 <- matrix(rep(NA,8*13),nrow=13)

logits <- list()
logits[[1]] <- logit0(ratn6     ~ econfrac2,subset=rat    !=0&train==0&type=="articles")
logits[[2]] <- logit0(gr_ratn6  ~ grfrac2  ,subset=gr_rat !=0&train==0&type=="articles")
logits[[3]] <- logit0(un_ratn6  ~ unfrac2  ,subset=un_rat !=0&train==0&type=="articles")
logits[[4]] <- logit0(inf_ratn6 ~ inffrac2 ,subset=inf_rat!=0&train==0&type=="articles")
logits[[5]] <- logit0(ratn6     ~ econfrac2,subset=rat    !=0&train==0&type=="headlines")
logits[[6]] <- logit0(gr_ratn6  ~ grfrac2  ,subset=gr_rat !=0&train==0&type=="headlines")
logits[[7]] <- logit0(un_ratn6  ~ unfrac2  ,subset=un_rat !=0&train==0&type=="headlines")
logits[[8]] <- logit0(inf_ratn6 ~ inffrac2 ,subset=inf_rat!=0&train==0&type=="headlines")

for(i in 1:8)
{
	tabA3[1,i] <- paste(dig2(logits[[i]]$coef[1]),stars(logits[[i]]$coef[1],logits[[i]]$se[1]),sep="")
	tabA3[2,i] <- as.se(logits[[i]]$se[1],k=2)
	tabA3[3,i] <- paste(dig2(logits[[i]]$coef[2]),stars(logits[[i]]$coef[2],logits[[i]]$se[2]),sep="")
	tabA3[4,i] <- as.se(logits[[i]]$se[2],k=2)
	tabA3[5,i] <- logits[[i]]$N
}

logits[[1]] <- logit0(ratpn     ~ econfracpos2,subset=(rat    !=0&rat    !=6&rat    !=3&train==0)&type=="articles")
logits[[2]] <- logit0(gr_ratpn  ~ grfracpos2  ,subset=(gr_rat !=0&gr_rat !=6&gr_rat !=3&train==0)&type=="articles")
logits[[3]] <- logit0(un_ratpn  ~ unfracpos2  ,subset=(un_rat !=0&un_rat !=6&un_rat !=3&train==0)&type=="articles")
logits[[4]] <- logit0(inf_ratpn ~ inffracpos2 ,subset=(inf_rat!=0&inf_rat!=6&inf_rat!=3&train==0)&type=="articles")
logits[[5]] <- logit0(ratpn     ~ econfracpos2,subset=(rat    !=0&rat    !=6&rat    !=3&train==0)&type=="headlines")
logits[[6]] <- logit0(gr_ratpn  ~ grfracpos2  ,subset=(gr_rat !=0&gr_rat !=6&gr_rat !=3&train==0)&type=="headlines")
logits[[7]] <- logit0(un_ratpn  ~ unfracpos2  ,subset=(un_rat !=0&un_rat !=6&un_rat !=3&train==0)&type=="headlines")
logits[[8]] <- logit0(inf_ratpn ~ inffracpos2 ,subset=(inf_rat!=0&inf_rat!=6&inf_rat!=3&train==0)&type=="headlines")

for(i in 1:8)
{
	tabA3[6,i] <- paste(dig2(logits[[i]]$coef[1]),stars(logits[[i]]$coef[1],logits[[i]]$se[1]),sep="")
	tabA3[7,i] <- as.se(logits[[i]]$se[1],k=2)
	tabA3[8,i] <- paste(dig2(logits[[i]]$coef[2]),stars(logits[[i]]$coef[2],logits[[i]]$se[2]),sep="")
	tabA3[9,i] <- as.se(logits[[i]]$se[2],k=2)
	tabA3[10,i] <- logits[[i]]$N
}

logits[[1]] <- ologit0(rat     ~ econfracpos2,subset=(rat    >=1&rat    <=5&train==0)&type=="articles")
logits[[2]] <- ologit0(gr_rat  ~ grfracpos2  ,subset=(gr_rat >=1&gr_rat <=5&train==0)&type=="articles")
logits[[3]] <- ologit0(un_rat  ~ unfracpos2  ,subset=(un_rat >=1&un_rat <=5&train==0)&type=="articles")
logits[[4]] <- ologit0(inf_rat ~ inffracpos2 ,subset=(inf_rat>=1&inf_rat<=5&train==0)&type=="articles")
logits[[5]] <- ologit0(rat     ~ econfracpos2,subset=(rat    >=1&rat    <=5&train==0)&type=="headlines")
logits[[6]] <- ologit0(gr_rat  ~ grfracpos2  ,subset=(gr_rat >=1&gr_rat <=5&train==0)&type=="headlines")
logits[[7]] <- ologit0(un_rat  ~ unfracpos2  ,subset=(un_rat >=1&un_rat <=5&train==0)&type=="headlines")
logits[[8]] <- ologit0(inf_rat ~ inffracpos2 ,subset=(inf_rat>=1&inf_rat<=5&train==0)&type=="headlines")

for(i in 1:8)
{
	tabA3[11,i] <- paste(dig2(logits[[i]]$coef[1]),stars(logits[[i]]$coef[1],logits[[i]]$se[1]),sep="")
	tabA3[12,i] <- as.se(logits[[i]]$se[1],k=2)
	tabA3[13,i] <- logits[[i]]$N
}

tabA3

# table A4
tabA4 <- matrix(rep(NA,4*14),nrow=14)

lm1 <- lm0(econ_frac_pos_hl ~ gr_yr + unch_yr + infch_yr,subset=newsid<=32,se="cluster",unitid=newsid)
lm2 <- lm0(econ_frac_pos_hl ~ gr_yr + unch_yr + infch_yr,subset=newsid<=32,se="cluster",unitid=country)
tabA4[1:8,1] <- as.vector(t(cbind(as.coef(lm1$coef[1:4],lm1$se[1:4]),as.se(lm1$se[1:4]))))
tabA4[9,1] <- lm1$N
tabA4[10,1] <- lm1$Clusters
tabA4[11,1] <- lm2$Clusters
tabA4[12,1] <- dig3(lm1$r.squared)
d <- delta.method(pred1,lm1$coef,lm1$V,econs=c(grs5,unchs5,infchs5))
tabA4[13,1] <- as.coef(as.vector(d$est),d$se)
tabA4[14,1] <- as.se(d$se)

lm1 <- lm0(gr_frac_pos_hl ~ gr_yr + unch_yr + infch_yr,subset=newsid<=32,se="cluster",unitid=newsid)
lm2 <- lm0(gr_frac_pos_hl ~ gr_yr + unch_yr + infch_yr,subset=newsid<=32,se="cluster",unitid=country)
tabA4[1:8,2] <- as.vector(t(cbind(as.coef(lm1$coef[1:4],lm1$se[1:4]),as.se(lm1$se[1:4]))))
tabA4[9,2] <- lm1$N
tabA4[10,2] <- lm1$Clusters
tabA4[11,2] <- lm2$Clusters
tabA4[12,2] <- dig3(lm1$r.squared)
d <- delta.method(pred1,lm1$coef,lm1$V,econs=c(grs5,unchs5,infchs5))
tabA4[13,2] <- as.coef(as.vector(d$est),d$se)
tabA4[14,2] <- as.se(d$se)

lm1 <- lm0(un_frac_pos_hl ~ gr_yr + unch_yr + infch_yr,subset=newsid<=32,se="cluster",unitid=newsid)
lm2 <- lm0(un_frac_pos_hl ~ gr_yr + unch_yr + infch_yr,subset=newsid<=32,se="cluster",unitid=country)
tabA4[1:8,3] <- as.vector(t(cbind(as.coef(lm1$coef[1:4],lm1$se[1:4]),as.se(lm1$se[1:4]))))
tabA4[9,3] <- lm1$N
tabA4[10,3] <- lm1$Clusters
tabA4[11,3] <- lm2$Clusters
tabA4[12,3] <- dig3(lm1$r.squared)
d <- delta.method(pred1,lm1$coef,lm1$V,econs=c(grs5,unchs5,infchs5))
tabA4[13,3] <- as.coef(as.vector(d$est),d$se)
tabA4[14,3] <- as.se(d$se)

lm1 <- lm0(inf_frac_pos_hl ~ gr_yr + unch_yr + infch_yr,subset=newsid<=32,se="cluster",unitid=newsid)
lm2 <- lm0(inf_frac_pos_hl ~ gr_yr + unch_yr + infch_yr,subset=newsid<=32,se="cluster",unitid=country)
tabA4[1:8,4] <- as.vector(t(cbind(as.coef(lm1$coef[1:4],lm1$se[1:4]),as.se(lm1$se[1:4]))))
tabA4[9,4] <- lm1$N
tabA4[10,4] <- lm1$Clusters
tabA4[11,4] <- lm2$Clusters
tabA4[12,4] <- dig3(lm1$r.squared)
d <- delta.method(pred1,lm1$coef,lm1$V,econs=c(grs5,unchs5,infchs5))
tabA4[13,4] <- as.coef(as.vector(d$est),d$se)
tabA4[14,4] <- as.se(d$se)

tabA4

# table A5
tabA5 <- matrix(rep(NA,4*10),nrow=10)

lm1 <- lm0(econ_per_headline ~ gr_yr + un_yr + inf_yr + factor(newsid),subset=newsid<=32,se="cluster",unitid=newsid)
lm2 <- lm0(econ_per_headline ~ gr_yr + un_yr + inf_yr + factor(newsid),subset=newsid<=32,se="cluster",unitid=country)
tabA5[1,1] <- as.coef(lm1$coef[2],lm1$se[2])
tabA5[2,1] <- as.se(lm1$se[2])
tabA5[3,1] <- as.coef(lm1$coef[3],lm1$se[3])
tabA5[4,1] <- as.se(lm1$se[3])
tabA5[5,1] <- as.coef(lm1$coef[4],lm1$se[4])
tabA5[6,1] <- as.se(lm1$se[4])
tabA5[7,1] <- lm1$N
tabA5[8,1] <- lm1$Clusters
tabA5[9,1] <- lm2$Clusters
tabA5[10,1] <- dig3(lm1$r.squared)

lm1 <- lm0(gr_sh_hl ~ gr_yr + factor(newsid),subset=newsid<=32,se="cluster",unitid=newsid)
lm2 <- lm0(gr_sh_hl ~ gr_yr + factor(newsid),subset=newsid<=32,se="cluster",unitid=country)
tabA5[1,2] <- as.coef(lm1$coef[2],lm1$se[2])
tabA5[2,2] <- as.se(lm1$se[2])
tabA5[7,2] <- lm1$N
tabA5[8,2] <- lm1$Clusters
tabA5[9,2] <- lm2$Clusters
tabA5[10,2] <- dig3(lm1$r.squared)

lm1 <- lm0(un_sh_hl ~ un_yr + factor(newsid),subset=newsid<=32,se="cluster",unitid=newsid)
lm2 <- lm0(un_sh_hl ~ un_yr + factor(newsid),subset=newsid<=32,se="cluster",unitid=country)
tabA5[3,3] <- as.coef(lm1$coef[2],lm1$se[2])
tabA5[4,3] <- as.se(lm1$se[2])
tabA5[7,3] <- lm1$N
tabA5[8,3] <- lm1$Clusters
tabA5[9,3] <- lm2$Clusters
tabA5[10,3] <- dig3(lm1$r.squared)

lm1 <- lm0(inf_sh_hl ~ inf_yr + factor(newsid),subset=newsid<=32,se="cluster",unitid=newsid)
lm2 <- lm0(inf_sh_hl ~ inf_yr + factor(newsid),subset=newsid<=32,se="cluster",unitid=country)
tabA5[5,4] <- as.coef(lm1$coef[2],lm1$se[2])
tabA5[6,4] <- as.se(lm1$se[2])
tabA5[7,4] <- lm1$N
tabA5[8,4] <- lm1$Clusters
tabA5[9,4] <- lm2$Clusters
tabA5[10,4] <- dig3(lm1$r.squared)

tabA5

# Table A6
tabA6 <- matrix(rep("",25*6),ncol=6)

lm1 <- lm0(cong_gr_frac_pos ~ gr_yr + ideomatch + gr_yr_ideomatch)
tabA6[1,1] <- as.coef(lm1$coef[2],lm1$se[2])
tabA6[2,1] <- as.se(lm1$se[2])
tabA6[11,1] <- as.coef(lm1$coef[3],lm1$se[3])
tabA6[12,1] <- as.se(lm1$se[3])
tabA6[13,1] <- as.coef(lm1$coef[4],lm1$se[4])
tabA6[14,1] <- as.se(lm1$se[4])
tabA6[23,1] <- lm1$N
tabA6[24,1] <- dig3(lm1$r.squared)
tabA6[25,1] <- paste(dig3(wald.test(wald34,lm1$coef,lm1$V)$pval),stars.pval(wald.test(wald34,lm1$coef,lm1$V)$pval),sep="")

lm1 <- lm0(cong_un_frac_pos ~ gr_yr + unch_yr + ideomatch + gr_yr_ideomatch + unch_yr_ideomatch)
tabA6[1,2] <- as.coef(lm1$coef[2],lm1$se[2])
tabA6[2,2] <- as.se(lm1$se[2])
tabA6[5,2] <- as.coef(lm1$coef[3],lm1$se[3])
tabA6[6,2] <- as.se(lm1$se[3])
tabA6[11,2] <- as.coef(lm1$coef[4],lm1$se[4])
tabA6[12,2] <- as.se(lm1$se[4])
tabA6[13,2] <- as.coef(lm1$coef[5],lm1$se[5])
tabA6[14,2] <- as.se(lm1$se[5])
tabA6[17,2] <- as.coef(lm1$coef[6],lm1$se[6])
tabA6[18,2] <- as.se(lm1$se[6])
tabA6[23,2] <- lm1$N
tabA6[24,2] <- dig3(lm1$r.squared)
tabA6[25,2] <- paste(dig3(wald.test(wald456,lm1$coef,lm1$V)$pval),stars.pval(wald.test(wald456,lm1$coef,lm1$V)$pval),sep="")

lm1 <- lm0(cong_inf_frac_pos ~ gr_yr + infch_yr + ideomatch + gr_yr_ideomatch + infch_yr_ideomatch)
tabA6[1,3] <- as.coef(lm1$coef[2],lm1$se[2]) # gr
tabA6[2,3] <- as.se(lm1$se[2])
tabA6[9,3] <- as.coef(lm1$coef[3],lm1$se[3]) # infch
tabA6[10,3] <- as.se(lm1$se[3])
tabA6[11,3] <- as.coef(lm1$coef[4],lm1$se[4]) # ideo
tabA6[12,3] <- as.se(lm1$se[4])
tabA6[13,3] <- as.coef(lm1$coef[5],lm1$se[5]) # ideo * gr
tabA6[14,3] <- as.se(lm1$se[5])
tabA6[21,3] <- as.coef(lm1$coef[6],lm1$se[6]) # ideo * infch
tabA6[22,3] <- as.se(lm1$se[6])
tabA6[23,3] <- lm1$N
tabA6[24,3] <- dig3(lm1$r.squared)
tabA6[25,3] <- paste(dig3(wald.test(wald456,lm1$coef,lm1$V)$pval),stars.pval(wald.test(wald456,lm1$coef,lm1$V)$pval),sep="")

lm1 <- lm0(cong_gr_sh ~ gr_yr + ideomatch + gr_yr_ideomatch)
tabA6[1,4] <- as.coef(lm1$coef[2],lm1$se[2]) # gr
tabA6[2,4] <- as.se(lm1$se[2])
tabA6[11,4] <- as.coef(lm1$coef[3],lm1$se[3]) # ideo
tabA6[12,4] <- as.se(lm1$se[3])
tabA6[13,4] <- as.coef(lm1$coef[4],lm1$se[4]) # ideo * gr
tabA6[14,4] <- as.se(lm1$se[4])
tabA6[23,4] <- lm1$N
tabA6[24,4] <- dig3(lm1$r.squared)
tabA6[25,4] <- paste(dig3(wald.test(wald34,lm1$coef,lm1$V)$pval),stars.pval(wald.test(wald34,lm1$coef,lm1$V)$pval),sep="")

lm1 <- lm0(cong_un_sh ~ un_yr + ideomatch + un_yr_ideomatch)
tabA6[3,5] <- as.coef(lm1$coef[2],lm1$se[2]) # un
tabA6[4,5] <- as.se(lm1$se[2])
tabA6[11,5] <- as.coef(lm1$coef[3],lm1$se[3]) # ideo
tabA6[12,5] <- as.se(lm1$se[3])
tabA6[15,5] <- as.coef(lm1$coef[4],lm1$se[4]) # ideo * un
tabA6[16,5] <- as.se(lm1$se[4])
tabA6[23,5] <- lm1$N
tabA6[24,5] <- dig3(lm1$r.squared)
tabA6[25,5] <- paste(dig3(wald.test(wald34,lm1$coef,lm1$V)$pval),stars.pval(wald.test(wald34,lm1$coef,lm1$V)$pval),sep="")

lm1 <- lm0(cong_inf_sh ~ inf_yr + ideomatch + inf_yr_ideomatch)
tabA6[7,6] <- as.coef(lm1$coef[2],lm1$se[2]) # inf
tabA6[8,6] <- as.se(lm1$se[2])
tabA6[11,6] <- as.coef(lm1$coef[3],lm1$se[3]) # ideo
tabA6[12,6] <- as.se(lm1$se[3])
tabA6[19,6] <- as.coef(lm1$coef[4],lm1$se[4]) # ideo * inf
tabA6[20,6] <- as.se(lm1$se[4])
tabA6[23,6] <- lm1$N
tabA6[24,6] <- dig3(lm1$r.squared)
tabA6[25,6] <- paste(dig3(wald.test(wald34,lm1$coef,lm1$V)$pval),stars.pval(wald.test(wald34,lm1$coef,lm1$V)$pval),sep="")

tabA6

# table A7
tabA7 <- matrix(rep("",27*6),ncol=6)

# gr sent
lm1 <- lm0(gr_frac_pos ~ gr_yr + ideomatch + gr_yr_ideomatch + factor(newsid),subset=newsid<=32&elecin6==1,se="cluster",unitid=newsid)
lm2 <- lm0(gr_frac_pos ~ gr_yr + ideomatch + gr_yr_ideomatch + factor(newsid),subset=newsid<=32&elecin6==1,se="cluster",unitid=country)
tabA7[1,1] <- as.coef(lm1$coef[2],lm1$se[2])
tabA7[2,1] <- as.se(lm1$se[2])
tabA7[11,1] <- as.coef(lm1$coef[3],lm1$se[3])
tabA7[12,1] <- as.se(lm1$se[3])
tabA7[13,1] <- as.coef(lm1$coef[4],lm1$se[4])
tabA7[14,1] <- as.se(lm1$se[4])
tabA7[23,1] <- lm1$N
tabA7[24,1] <- lm1$Clusters
tabA7[25,1] <- lm2$Clusters
tabA7[26,1] <- dig3(lm1$r.squared)
tabA7[27,1] <- paste(dig3(wald.test(wald34,lm1$coef,lm1$V)$pval),stars.pval(wald.test(wald34,lm1$coef,lm1$V)$pval),sep="")

# un sent
lm1 <- lm0(un_frac_pos ~ gr_yr + unch_yr + ideomatch + gr_yr_ideomatch + unch_yr_ideomatch + factor(newsid),subset=newsid<=32&elecin6==1,se="cluster",unitid=newsid)
lm2 <- lm0(un_frac_pos ~ gr_yr + unch_yr + ideomatch + gr_yr_ideomatch + unch_yr_ideomatch + factor(newsid),subset=newsid<=32&elecin6==1,se="cluster",unitid=country)
tabA7[1,2] <- as.coef(lm1$coef[2],lm1$se[2])
tabA7[2,2] <- as.se(lm1$se[2])
tabA7[5,2] <- as.coef(lm1$coef[3],lm1$se[3])
tabA7[6,2] <- as.se(lm1$se[3])
tabA7[11,2] <- as.coef(lm1$coef[4],lm1$se[4])
tabA7[12,2] <- as.se(lm1$se[4])
tabA7[13,2] <- as.coef(lm1$coef[5],lm1$se[5])
tabA7[14,2] <- as.se(lm1$se[5])
tabA7[17,2] <- as.coef(lm1$coef[6],lm1$se[6])
tabA7[18,2] <- as.se(lm1$se[6])
tabA7[23,2] <- lm1$N
tabA7[24,2] <- lm1$Clusters
tabA7[25,2] <- lm2$Clusters
tabA7[26,2] <- dig3(lm1$r.squared)
tabA7[27,2] <- paste(dig3(wald.test(wald456,lm1$coef,lm1$V)$pval),stars.pval(wald.test(wald456,lm1$coef,lm1$V)$pval),sep="")

# inf sent
lm1 <- lm0(inf_frac_pos ~ gr_yr + infch_yr + ideomatch + gr_yr_ideomatch + infch_yr_ideomatch + factor(newsid),subset=newsid<=32&elecin6==1,se="cluster",unitid=newsid)
lm2 <- lm0(inf_frac_pos ~ gr_yr + infch_yr + ideomatch + gr_yr_ideomatch + infch_yr_ideomatch + factor(newsid),subset=newsid<=32&elecin6==1,se="cluster",unitid=country)
tabA7[1,3] <- as.coef(lm1$coef[2],lm1$se[2]) # gr
tabA7[2,3] <- as.se(lm1$se[2])
tabA7[9,3] <- as.coef(lm1$coef[3],lm1$se[3]) # infch
tabA7[10,3] <- as.se(lm1$se[3])
tabA7[11,3] <- as.coef(lm1$coef[4],lm1$se[4]) # ideo
tabA7[12,3] <- as.se(lm1$se[4])
tabA7[13,3] <- as.coef(lm1$coef[5],lm1$se[5]) # ideo * gr
tabA7[14,3] <- as.se(lm1$se[5])
tabA7[21,3] <- as.coef(lm1$coef[6],lm1$se[6]) # ideo * infch
tabA7[22,3] <- as.se(lm1$se[6])
tabA7[23,3] <- lm1$N
tabA7[24,3] <- lm1$Clusters
tabA7[25,3] <- lm2$Clusters
tabA7[26,3] <- dig3(lm1$r.squared)
tabA7[27,3] <- paste(dig3(wald.test(wald456,lm1$coef,lm1$V)$pval),stars.pval(wald.test(wald456,lm1$coef,lm1$V)$pval),sep="")

# gr cov
lm1 <- lm0(gr_sh ~ gr_yr + ideomatch + gr_yr_ideomatch + factor(newsid),subset=newsid<=32&elecin6==1,se="cluster",unitid=newsid)
lm2 <- lm0(gr_sh ~ gr_yr + ideomatch + gr_yr_ideomatch + factor(newsid),subset=newsid<=32&elecin6==1,se="cluster",unitid=country)
tabA7[1,4] <- as.coef(lm1$coef[2],lm1$se[2]) # gr
tabA7[2,4] <- as.se(lm1$se[2])
tabA7[11,4] <- as.coef(lm1$coef[3],lm1$se[3]) # ideo
tabA7[12,4] <- as.se(lm1$se[3])
tabA7[13,4] <- as.coef(lm1$coef[4],lm1$se[4]) # ideo * gr
tabA7[14,4] <- as.se(lm1$se[4])
tabA7[23,4] <- lm1$N
tabA7[24,4] <- lm1$Clusters
tabA7[25,4] <- lm2$Clusters
tabA7[26,4] <- dig3(lm1$r.squared)
tabA7[27,4] <- paste(dig3(wald.test(wald34,lm1$coef,lm1$V)$pval),stars.pval(wald.test(wald34,lm1$coef,lm1$V)$pval),sep="")

# un cov
lm1 <- lm0(un_sh ~ un_yr + ideomatch + un_yr_ideomatch + factor(newsid),subset=newsid<=32&elecin6==1,se="cluster",unitid=newsid)
lm2 <- lm0(un_sh ~ un_yr + ideomatch + un_yr_ideomatch + factor(newsid),subset=newsid<=32&elecin6==1,se="cluster",unitid=country)
tabA7[3,5] <- as.coef(lm1$coef[2],lm1$se[2]) # un
tabA7[4,5] <- as.se(lm1$se[2])
tabA7[11,5] <- as.coef(lm1$coef[3],lm1$se[3]) # ideo
tabA7[12,5] <- as.se(lm1$se[3])
tabA7[15,5] <- as.coef(lm1$coef[4],lm1$se[4]) # ideo * un
tabA7[16,5] <- as.se(lm1$se[4])
tabA7[23,5] <- lm1$N
tabA7[24,5] <- lm1$Clusters
tabA7[25,5] <- lm2$Clusters
tabA7[26,5] <- dig3(lm1$r.squared)
tabA7[27,5] <- paste(dig3(wald.test(wald34,lm1$coef,lm1$V)$pval),stars.pval(wald.test(wald34,lm1$coef,lm1$V)$pval),sep="")

# inf cov
lm1 <- lm0(inf_sh ~ inf_yr + ideomatch + inf_yr_ideomatch + factor(newsid),subset=newsid<=32&elecin6==1,se="cluster",unitid=newsid)
lm2 <- lm0(inf_sh ~ inf_yr + ideomatch + inf_yr_ideomatch + factor(newsid),subset=newsid<=32&elecin6==1,se="cluster",unitid=country)
tabA7[7,6] <- as.coef(lm1$coef[2],lm1$se[2]) # inf
tabA7[8,6] <- as.se(lm1$se[2])
tabA7[11,6] <- as.coef(lm1$coef[3],lm1$se[3]) # ideo
tabA7[12,6] <- as.se(lm1$se[3])
tabA7[19,6] <- as.coef(lm1$coef[4],lm1$se[4]) # ideo * inf
tabA7[20,6] <- as.se(lm1$se[4])
tabA7[23,6] <- lm1$N
tabA7[24,6] <- lm1$Clusters
tabA7[25,6] <- lm2$Clusters
tabA7[26,6] <- dig3(lm1$r.squared)
tabA7[27,6] <- paste(dig3(wald.test(wald34,lm1$coef,lm1$V)$pval),stars.pval(wald.test(wald34,lm1$coef,lm1$V)$pval),sep="")

tabA7

# Table A8
tabA8 <- matrix(rep("",27*6),ncol=6)

# gr sent
lm1 <- lm0(gr_frac_pos_th ~ gr_yr + ideomatch + gr_yr_ideomatch + factor(newsid),subset=newsid<=32,se="cluster",unitid=newsid)
lm2 <- lm0(gr_frac_pos_th ~ gr_yr + ideomatch + gr_yr_ideomatch + factor(newsid),subset=newsid<=32,se="cluster",unitid=country)
tabA8[1,1] <- as.coef(lm1$coef[2],lm1$se[2])
tabA8[2,1] <- as.se(lm1$se[2])
tabA8[11,1] <- as.coef(lm1$coef[3],lm1$se[3])
tabA8[12,1] <- as.se(lm1$se[3])
tabA8[13,1] <- as.coef(lm1$coef[4],lm1$se[4])
tabA8[14,1] <- as.se(lm1$se[4])
tabA8[23,1] <- lm1$N
tabA8[24,1] <- lm1$Clusters
tabA8[25,1] <- lm2$Clusters
tabA8[26,1] <- dig3(lm1$r.squared)
tabA8[27,1] <- paste(dig3(wald.test(wald34,lm1$coef,lm1$V)$pval),stars.pval(wald.test(wald34,lm1$coef,lm1$V)$pval),sep="")

# un sent
lm1 <- lm0(un_frac_pos_th ~ gr_yr + unch_yr + ideomatch + gr_yr_ideomatch + unch_yr_ideomatch + factor(newsid),subset=newsid<=32,se="cluster",unitid=newsid)
lm2 <- lm0(un_frac_pos_th ~ gr_yr + unch_yr + ideomatch + gr_yr_ideomatch + unch_yr_ideomatch + factor(newsid),subset=newsid<=32,se="cluster",unitid=country)
tabA8[1,2] <- as.coef(lm1$coef[2],lm1$se[2])
tabA8[2,2] <- as.se(lm1$se[2])
tabA8[5,2] <- as.coef(lm1$coef[3],lm1$se[3])
tabA8[6,2] <- as.se(lm1$se[3])
tabA8[11,2] <- as.coef(lm1$coef[4],lm1$se[4])
tabA8[12,2] <- as.se(lm1$se[4])
tabA8[13,2] <- as.coef(lm1$coef[5],lm1$se[5])
tabA8[14,2] <- as.se(lm1$se[5])
tabA8[17,2] <- as.coef(lm1$coef[6],lm1$se[6])
tabA8[18,2] <- as.se(lm1$se[6])
tabA8[23,2] <- lm1$N
tabA8[24,2] <- lm1$Clusters
tabA8[25,2] <- lm2$Clusters
tabA8[26,2] <- dig3(lm1$r.squared)
tabA8[27,2] <- paste(dig3(wald.test(wald456,lm1$coef,lm1$V)$pval),stars.pval(wald.test(wald456,lm1$coef,lm1$V)$pval),sep="")

# inf sent
lm1 <- lm0(inf_frac_pos_th ~ gr_yr + infch_yr + ideomatch + gr_yr_ideomatch + infch_yr_ideomatch + factor(newsid),subset=newsid<=32,se="cluster",unitid=newsid)
lm2 <- lm0(inf_frac_pos_th ~ gr_yr + infch_yr + ideomatch + gr_yr_ideomatch + infch_yr_ideomatch + factor(newsid),subset=newsid<=32,se="cluster",unitid=country)
tabA8[1,3] <- as.coef(lm1$coef[2],lm1$se[2]) # gr
tabA8[2,3] <- as.se(lm1$se[2])
tabA8[9,3] <- as.coef(lm1$coef[3],lm1$se[3]) # infch
tabA8[10,3] <- as.se(lm1$se[3])
tabA8[11,3] <- as.coef(lm1$coef[4],lm1$se[4]) # ideo
tabA8[12,3] <- as.se(lm1$se[4])
tabA8[13,3] <- as.coef(lm1$coef[5],lm1$se[5]) # ideo * gr
tabA8[14,3] <- as.se(lm1$se[5])
tabA8[21,3] <- as.coef(lm1$coef[6],lm1$se[6]) # ideo * infch
tabA8[22,3] <- as.se(lm1$se[6])
tabA8[23,3] <- lm1$N
tabA8[24,3] <- lm1$Clusters
tabA8[25,3] <- lm2$Clusters
tabA8[26,3] <- dig3(lm1$r.squared)
tabA8[27,3] <- paste(dig3(wald.test(wald456,lm1$coef,lm1$V)$pval),stars.pval(wald.test(wald456,lm1$coef,lm1$V)$pval),sep="")


# gr cov
lm1 <- lm0(gr_sh_th ~ gr_yr + ideomatch + gr_yr_ideomatch + factor(newsid),subset=newsid<=32,se="cluster",unitid=newsid)
lm2 <- lm0(gr_sh_th ~ gr_yr + ideomatch + gr_yr_ideomatch + factor(newsid),subset=newsid<=32,se="cluster",unitid=country)
tabA8[1,4] <- as.coef(lm1$coef[2],lm1$se[2]) # gr
tabA8[2,4] <- as.se(lm1$se[2])
tabA8[11,4] <- as.coef(lm1$coef[3],lm1$se[3]) # ideo
tabA8[12,4] <- as.se(lm1$se[3])
tabA8[13,4] <- as.coef(lm1$coef[4],lm1$se[4]) # ideo * gr
tabA8[14,4] <- as.se(lm1$se[4])
tabA8[23,4] <- lm1$N
tabA8[24,4] <- lm1$Clusters
tabA8[25,4] <- lm2$Clusters
tabA8[26,4] <- dig3(lm1$r.squared)
tabA8[27,4] <- paste(dig3(wald.test(wald34,lm1$coef,lm1$V)$pval),stars.pval(wald.test(wald34,lm1$coef,lm1$V)$pval),sep="")

# un cov
lm1 <- lm0(un_sh_th ~ un_yr + ideomatch + un_yr_ideomatch + factor(newsid),subset=newsid<=32,se="cluster",unitid=newsid)
lm2 <- lm0(un_sh_th ~ un_yr + ideomatch + un_yr_ideomatch + factor(newsid),subset=newsid<=32,se="cluster",unitid=country)
tabA8[3,5] <- as.coef(lm1$coef[2],lm1$se[2]) # un
tabA8[4,5] <- as.se(lm1$se[2])
tabA8[11,5] <- as.coef(lm1$coef[3],lm1$se[3]) # ideo
tabA8[12,5] <- as.se(lm1$se[3])
tabA8[15,5] <- as.coef(lm1$coef[4],lm1$se[4]) # ideo * un
tabA8[16,5] <- as.se(lm1$se[4])
tabA8[23,5] <- lm1$N
tabA8[24,5] <- lm1$Clusters
tabA8[25,5] <- lm2$Clusters
tabA8[26,5] <- dig3(lm1$r.squared)
tabA8[27,5] <- paste(dig3(wald.test(wald34,lm1$coef,lm1$V)$pval),stars.pval(wald.test(wald34,lm1$coef,lm1$V)$pval),sep="")

# inf cov
lm1 <- lm0(inf_sh_th ~ inf_yr + ideomatch + inf_yr_ideomatch + factor(newsid),subset=newsid<=32,se="cluster",unitid=newsid)
lm2 <- lm0(inf_sh_th ~ inf_yr + ideomatch + inf_yr_ideomatch + factor(newsid),subset=newsid<=32,se="cluster",unitid=country)
tabA8[7,6] <- as.coef(lm1$coef[2],lm1$se[2]) # inf
tabA8[8,6] <- as.se(lm1$se[2])
tabA8[11,6] <- as.coef(lm1$coef[3],lm1$se[3]) # ideo
tabA8[12,6] <- as.se(lm1$se[3])
tabA8[19,6] <- as.coef(lm1$coef[4],lm1$se[4]) # ideo * inf
tabA8[20,6] <- as.se(lm1$se[4])
tabA8[23,6] <- lm1$N
tabA8[24,6] <- lm1$Clusters
tabA8[25,6] <- lm2$Clusters
tabA8[26,6] <- dig3(lm1$r.squared)
tabA8[27,6] <- paste(dig3(wald.test(wald34,lm1$coef,lm1$V)$pval),stars.pval(wald.test(wald34,lm1$coef,lm1$V)$pval),sep="")

tabA8

# Table A9
tabA9 <- matrix(rep(NA,6),ncol=6)

lm1 <- lm0(gr_frac_pos ~ gr_yr + leadpos + leadpos_newspos + gr_leadpos + gr_newspos + gr_leadpos_newspos + factor(newsid),subset=newsid<=32,se="cluster",unitid=country)
tabA9[1,1] <- pval.as.pval(wald.test(wald47,lm1$coef,lm1$V)$pval)

lm1 <- lm0(un_frac_pos ~ unch_yr + leadpos + leadpos_newspos + unch_leadpos + unch_newspos + unch_leadpos_newspos + factor(newsid),subset=newsid<=32,se="cluster",unitid=country)
tabA9[1,2] <- pval.as.pval(wald.test(wald47,lm1$coef,lm1$V)$pval)

lm1 <- lm0(inf_frac_pos ~ infch_yr + leadpos + leadpos_newspos + infch_leadpos + infch_newspos + infch_leadpos_newspos + factor(newsid),se="cluster",unitid=country,subset=newsid<=32)
tabA9[1,3] <- pval.as.pval(wald.test(wald47,lm1$coef,lm1$V)$pval)

lm1 <- lm0(gr_sh ~ gr_yr + leadpos + leadpos_newspos + gr_leadpos + gr_newspos + gr_leadpos_newspos + factor(newsid),se="cluster",unitid=country,subset=newsid<=32)
tabA9[1,4] <- pval.as.pval(wald.test(wald47,lm1$coef,lm1$V)$pval)

lm1 <- lm0(un_sh ~ un_yr + leadpos + leadpos_newspos + un_leadpos + un_newspos + un_leadpos_newspos + factor(newsid),se="cluster",unitid=country,subset=newsid<=32)
tabA9[1,5] <- pval.as.pval(wald.test(wald47,lm1$coef,lm1$V)$pval)

lm1 <- lm0(inf_sh ~ inf_yr + leadpos + leadpos_newspos + inf_leadpos + inf_newspos + inf_leadpos_newspos + factor(newsid),se="cluster",unitid=country,subset=newsid<=32)
tabA9[1,6] <- pval.as.pval(wald.test(wald47,lm1$coef,lm1$V)$pval)

tabA9

# table A10 is just raw data reported

# table A11
tabA11 <- matrix(rep(NA,6),ncol=6)

# gr sent
lm1 <- lm0(gr_frac_pos ~ gr_yr + gr_yr_left + ideomatch + ideomatch_left + gr_yr_ideomatch + gr_yr_ideomatch_left + factor(newsid),subset=newsid<=32,se="cluster",unitid=newsid)
tabA11[1,1] <- pval.as.pval(wald.test(wald4_7,lm1$coef,lm1$V)$pval)

# un sent
lm1 <- lm0(un_frac_pos ~ gr_yr + gr_yr_left + unch_yr + unch_yr_left + ideomatch + ideomatch_left + gr_yr_ideomatch + unch_yr_ideomatch + gr_yr_ideomatch_left + unch_yr_ideomatch_left + factor(newsid),subset=newsid<=32,se="cluster",unitid=newsid)
tabA11[1,2] <- pval.as.pval(wald.test(wald6_11,lm1$coef,lm1$V)$pval)

# inf sent
lm1 <- lm0(inf_frac_pos ~ gr_yr + gr_yr_left + infch_yr + infch_yr_left + ideomatch + ideomatch_left + gr_yr_ideomatch + infch_yr_ideomatch + gr_yr_ideomatch_left + infch_yr_ideomatch_left + factor(newsid),subset=newsid<=32,se="cluster",unitid=newsid)
tabA11[1,3] <- pval.as.pval(wald.test(wald6_11,lm1$coef,lm1$V)$pval)

# gr cov
lm1 <- lm0(gr_sh ~ gr_yr + gr_yr_left + ideomatch + ideomatch_left + gr_yr_ideomatch + gr_yr_ideomatch_left + factor(newsid),subset=newsid<=32,se="cluster",unitid=newsid)
tabA11[1,4] <- pval.as.pval(wald.test(wald4_7,lm1$coef,lm1$V)$pval)

# un cov
lm1 <- lm0(un_sh ~ un_yr + un_yr_left + ideomatch + ideomatch_left + un_yr_ideomatch + un_yr_ideomatch_left + factor(newsid),subset=newsid<=32,se="cluster",unitid=newsid)
tabA11[1,5] <- pval.as.pval(wald.test(wald4_7,lm1$coef,lm1$V)$pval)

# inf cov
lm1 <- lm0(inf_sh ~ inf_yr + inf_yr_left + ideomatch + ideomatch_left + inf_yr_ideomatch + inf_yr_ideomatch_left + factor(newsid),subset=newsid<=32,se="cluster",unitid=newsid)
tabA11[1,6] <- pval.as.pval(wald.test(wald4_7,lm1$coef,lm1$V)$pval)

tabA11

if(win64)
{
	
# table A12
tabA12 <- matrix(rep(NA,4*12),nrow=12)

lm1 <- lm.cluster.wild(econ_frac_pos ~ gr_yr + unch_yr + infch_yr + factor(newsid),subset=newsid<=32,unitid=newsid)
lm2 <- lm0(econ_frac_pos ~ gr_yr + unch_yr + infch_yr + factor(newsid),subset=newsid<=32,se="cluster",unitid=country)
tabA12[1:8,1] <- as.vector(t(cbind(as.coef(lm1$coef[1:4],p.val=lm1$p.val[1:4]),as.se(lm1$se[1:4]))))
tabA12[9,1] <- lm1$N
tabA12[10,1] <- lm1$Clusters
tabA12[11,1] <- lm2$Clusters
tabA12[12,1] <- dig3(lm1$r.squared)

lm1 <- lm.cluster.wild(gr_frac_pos ~ gr_yr + unch_yr + infch_yr + factor(newsid),subset=newsid<=32,unitid=newsid)
lm2 <- lm0(gr_frac_pos ~ gr_yr + unch_yr + infch_yr + factor(newsid),subset=newsid<=32,se="cluster",unitid=country)
tabA12[1:8,2] <- as.vector(t(cbind(as.coef(lm1$coef[1:4],p.val=lm1$p.val[1:4]),as.se(lm1$se[1:4]))))
tabA12[9,2] <- lm1$N
tabA12[10,2] <- lm1$Clusters
tabA12[11,2] <- lm2$Clusters
tabA12[12,2] <- dig3(lm1$r.squared)

lm1 <- lm.cluster.wild(un_frac_pos ~ gr_yr + unch_yr + infch_yr + factor(newsid),subset=newsid<=32,unitid=newsid)
lm2 <- lm0(un_frac_pos ~ gr_yr + unch_yr + infch_yr + factor(newsid),subset=newsid<=32,se="cluster",unitid=country)
tabA12[1:8,3] <- as.vector(t(cbind(as.coef(lm1$coef[1:4],p.val=lm1$p.val[1:4]),as.se(lm1$se[1:4]))))
tabA12[9,3] <- lm1$N
tabA12[10,3] <- lm1$Clusters
tabA12[11,3] <- lm2$Clusters
tabA12[12,3] <- dig3(lm1$r.squared)

lm1 <- lm.cluster.wild(inf_frac_pos ~ gr_yr + unch_yr + infch_yr + factor(newsid),subset=newsid<=32,unitid=newsid)
lm2 <- lm0(inf_frac_pos ~ gr_yr + unch_yr + infch_yr + factor(newsid),subset=newsid<=32,se="cluster",unitid=country)
tabA12[1:8,4] <- as.vector(t(cbind(as.coef(lm1$coef[1:4],p.val=lm1$p.val[1:4]),as.se(lm1$se[1:4]))))
tabA12[9,4] <- lm1$N
tabA12[10,4] <- lm1$Clusters
tabA12[11,4] <- lm2$Clusters
tabA12[12,4] <- dig3(lm1$r.squared)

tabA12

# table A13
tabA13 <- matrix(rep("",4*10),nrow=10)

lm1 <- lm.cluster.wild(econ_per_article ~ gr_yr + un_yr + inf_yr + factor(newsid),subset=newsid<=32,unitid=newsid)
lm2 <- lm0(econ_per_article ~ gr_yr + un_yr + inf_yr + factor(newsid),subset=newsid<=32,se="cluster",unitid=country)
tabA13[1,1] <- as.coef(lm1$coef[2],p.val=lm1$p.val[2])
tabA13[2,1] <- as.se(lm1$se[2])
tabA13[3,1] <- as.coef(lm1$coef[3],p.val=lm1$p.val[3])
tabA13[4,1] <- as.se(lm1$se[3])
tabA13[5,1] <- as.coef(lm1$coef[4],p.val=lm1$p.val[4])
tabA13[6,1] <- as.se(lm1$se[4])
tabA13[7,1] <- lm1$N
tabA13[8,1] <- lm1$Clusters
tabA13[9,1] <- lm2$Clusters
tabA13[10,1] <- dig3(lm1$r.squared)

lm1 <- lm.cluster.wild(gr_sh ~ gr_yr + factor(newsid),subset=newsid<=32,unitid=newsid)
lm2 <- lm0(gr_sh ~ gr_yr + factor(newsid),subset=newsid<=32,se="cluster",unitid=country)
tabA13[1,2] <- as.coef(lm1$coef[2],p.val=lm1$p.val[2])
tabA13[2,2] <- as.se(lm1$se[2])
tabA13[7,2] <- lm1$N
tabA13[8,2] <- lm1$Clusters
tabA13[9,2] <- lm2$Clusters
tabA13[10,2] <- dig3(lm1$r.squared)

lm1 <- lm.cluster.wild(un_sh ~ un_yr + factor(newsid),subset=newsid<=32,unitid=newsid)
lm2 <- lm0(un_sh ~ un_yr + factor(newsid),subset=newsid<=32,se="cluster",unitid=country)
tabA13[3,3] <- as.coef(lm1$coef[2],p.val=lm1$p.val[2])
tabA13[4,3] <- as.se(lm1$se[2])
tabA13[7,3] <- lm1$N
tabA13[8,3] <- lm1$Clusters
tabA13[9,3] <- lm2$Clusters
tabA13[10,3] <- dig3(lm1$r.squared)

lm1 <- lm.cluster.wild(inf_sh ~ inf_yr + factor(newsid),subset=newsid<=32,unitid=newsid)
lm2 <- lm0(inf_sh ~ inf_yr + factor(newsid),subset=newsid<=32,se="cluster",unitid=country)
tabA13[5,4] <- as.coef(lm1$coef[2],p.val=lm1$p.val[2])
tabA13[6,4] <- as.se(lm1$se[2])
tabA13[7,4] <- lm1$N
tabA13[8,4] <- lm1$Clusters
tabA13[9,4] <- lm2$Clusters
tabA13[10,4] <- dig3(lm1$r.squared)

tabA13

# table A14

# specify wald tests to compute
idx1 <- rbind(one.true(35,1),one.true(35,2),one.true(35,3),one.true(35,4),two.true(35,3,4))
idx2 <- rbind(one.true(37,1),one.true(37,2),one.true(37,3),one.true(37,4),one.true(37,5),one.true(37,6),three.true(37,4,5,6))

tabA14 <- matrix(rep("",19*6),nrow=19)

lm1 <- lm.cluster.wild(gr_frac_pos ~ gr_yr + ideomatch + gr_yr_ideomatch + factor(newsid),idx=idx1,subset=newsid<=32,unitid=newsid)
lm2 <- lm0(gr_frac_pos ~ gr_yr + ideomatch + gr_yr_ideomatch + factor(newsid),subset=newsid<=32,unitid=country)
tabA14[1,1] <- as.coef(lm1$coef[2],p.val=lm1$p.val[2])
tabA14[2,1] <- as.se(lm1$se[2])
tabA14[7,1] <- as.coef(lm1$coef[3],p.val=lm1$p.val[3])
tabA14[8,1] <- as.se(lm1$se[3])
tabA14[9,1] <- as.coef(lm1$coef[4],p.val=lm1$p.val[4])
tabA14[10,1] <- as.se(lm1$se[4])
tabA14[15,1] <- lm1$N
tabA14[16,1] <- lm1$Clusters
tabA14[17,1] <- lm2$Clusters
tabA14[18,1] <- dig3(lm1$r.squared)
tabA14[19,1] <- paste(dig3(lm1$p.val[5]),stars.pval(lm1$p.val[5]),sep="")

lm1 <- lm.cluster.wild(un_frac_pos ~ gr_yr + unch_yr + ideomatch + gr_yr_ideomatch + unch_yr_ideomatch + factor(newsid),idx=idx2,subset=newsid<=32,unitid=newsid)
lm2 <- lm0(un_frac_pos ~ gr_yr + unch_yr + ideomatch + gr_yr_ideomatch + unch_yr_ideomatch + factor(newsid),subset=newsid<=32,unitid=country)
tabA14[1,2] <- as.coef(lm1$coef[2],p.val=lm1$p.val[2])
tabA14[2,2] <- as.se(lm1$se[2])
tabA14[3,2] <- as.coef(lm1$coef[3],p.val=lm1$p.val[3])
tabA14[4,2] <- as.se(lm1$se[3])
tabA14[7,2] <- as.coef(lm1$coef[4],p.val=lm1$p.val[4])
tabA14[8,2] <- as.se(lm1$se[4])
tabA14[9,2] <- as.coef(lm1$coef[5],p.val=lm1$p.val[5])
tabA14[10,2] <- as.se(lm1$se[5])
tabA14[11,2] <- as.coef(lm1$coef[6],p.val=lm1$p.val[6])
tabA14[12,2] <- as.se(lm1$se[6])
tabA14[15,2] <- lm1$N
tabA14[16,2] <- lm1$Clusters
tabA14[17,2] <- lm2$Clusters
tabA14[18,2] <- dig3(lm1$r.squared)
tabA14[19,2] <- paste(dig3(lm1$p.val[7]),stars.pval(lm1$p.val[7]),sep="")

lm1 <- lm.cluster.wild(inf_frac_pos ~ gr_yr + infch_yr + ideomatch + gr_yr_ideomatch + infch_yr_ideomatch + factor(newsid),idx=idx2,subset=newsid<=32,unitid=newsid)
lm2 <- lm0(inf_frac_pos ~ gr_yr + infch_yr + ideomatch + gr_yr_ideomatch + infch_yr_ideomatch + factor(newsid),subset=newsid<=32,unitid=country)
tabA14[1,3] <- as.coef(lm1$coef[2],p.val=lm1$p.val[2])
tabA14[2,3] <- as.se(lm1$se[2])
tabA14[5,3] <- as.coef(lm1$coef[3],p.val=lm1$p.val[3])
tabA14[6,3] <- as.se(lm1$se[3])
tabA14[7,3] <- as.coef(lm1$coef[4],p.val=lm1$p.val[4])
tabA14[8,3] <- as.se(lm1$se[4])
tabA14[9,3] <- as.coef(lm1$coef[5],p.val=lm1$p.val[5])
tabA14[10,3] <- as.se(lm1$se[5])
tabA14[13,3] <- as.coef(lm1$coef[6],p.val=lm1$p.val[6])
tabA14[14,3] <- as.se(lm1$se[6])
tabA14[15,3] <- lm1$N
tabA14[16,3] <- lm1$Clusters
tabA14[17,3] <- lm2$Clusters
tabA14[18,3] <- dig3(lm1$r.squared)
tabA14[19,3] <- paste(dig3(lm1$p.val[7]),stars.pval(lm1$p.val[7]),sep="")

lm1 <- lm.cluster.wild(gr_frac_pos_hl ~ gr_yr + ideomatch + gr_yr_ideomatch + factor(newsid),idx=idx1,subset=newsid<=32,unitid=newsid)
lm2 <- lm0(gr_frac_pos_hl ~ gr_yr + ideomatch + gr_yr_ideomatch + factor(newsid),subset=newsid<=32,unitid=country)
tabA14[1,4] <- as.coef(lm1$coef[2],p.val=lm1$p.val[2])
tabA14[2,4] <- as.se(lm1$se[2])
tabA14[7,4] <- as.coef(lm1$coef[3],p.val=lm1$p.val[3])
tabA14[8,4] <- as.se(lm1$se[3])
tabA14[9,4] <- as.coef(lm1$coef[4],p.val=lm1$p.val[4])
tabA14[10,4] <- as.se(lm1$se[4])
tabA14[15,4] <- lm1$N
tabA14[16,4] <- lm1$Clusters
tabA14[17,4] <- lm2$Clusters
tabA14[18,4] <- dig3(lm1$r.squared)
tabA14[19,4] <- paste(dig3(lm1$p.val[5]),stars.pval(lm1$p.val[5]),sep="")

lm1 <- lm.cluster.wild(un_frac_pos_hl ~ gr_yr + unch_yr + ideomatch + gr_yr_ideomatch + unch_yr_ideomatch + factor(newsid),idx=idx2,subset=newsid<=32,unitid=newsid)
lm2 <- lm0(un_frac_pos_hl ~ gr_yr + unch_yr + ideomatch + gr_yr_ideomatch + unch_yr_ideomatch + factor(newsid),subset=newsid<=32,unitid=country)
tabA14[1,5] <- as.coef(lm1$coef[2],p.val=lm1$p.val[2])
tabA14[2,5] <- as.se(lm1$se[2])
tabA14[3,5] <- as.coef(lm1$coef[3],p.val=lm1$p.val[3])
tabA14[4,5] <- as.se(lm1$se[3])
tabA14[7,5] <- as.coef(lm1$coef[4],p.val=lm1$p.val[4])
tabA14[8,5] <- as.se(lm1$se[4])
tabA14[9,5] <- as.coef(lm1$coef[5],p.val=lm1$p.val[5])
tabA14[10,5] <- as.se(lm1$se[5])
tabA14[11,5] <- as.coef(lm1$coef[6],p.val=lm1$p.val[6])
tabA14[12,5] <- as.se(lm1$se[6])
tabA14[15,5] <- lm1$N
tabA14[16,5] <- lm1$Clusters
tabA14[17,5] <- lm2$Clusters
tabA14[18,5] <- dig3(lm1$r.squared)
tabA14[19,5] <- paste(dig3(lm1$p.val[7]),stars.pval(lm1$p.val[7]),sep="")

lm1 <- lm.cluster.wild(inf_frac_pos_hl ~ gr_yr + infch_yr + ideomatch + gr_yr_ideomatch + infch_yr_ideomatch + factor(newsid),idx=idx2,subset=newsid<=32,unitid=newsid)
lm2 <- lm0(inf_frac_pos_hl ~ gr_yr + infch_yr + ideomatch + gr_yr_ideomatch + infch_yr_ideomatch + factor(newsid),subset=newsid<=32,unitid=country)
tabA14[1,6] <- as.coef(lm1$coef[2],p.val=lm1$p.val[2])
tabA14[2,6] <- as.se(lm1$se[2])
tabA14[5,6] <- as.coef(lm1$coef[3],p.val=lm1$p.val[3])
tabA14[6,6] <- as.se(lm1$se[3])
tabA14[7,6] <- as.coef(lm1$coef[4],p.val=lm1$p.val[4])
tabA14[8,6] <- as.se(lm1$se[4])
tabA14[9,6] <- as.coef(lm1$coef[5],p.val=lm1$p.val[5])
tabA14[10,6] <- as.se(lm1$se[5])
tabA14[13,6] <- as.coef(lm1$coef[6],p.val=lm1$p.val[6])
tabA14[14,6] <- as.se(lm1$se[6])
tabA14[15,6] <- lm1$N
tabA14[16,6] <- lm1$Clusters
tabA14[17,6] <- lm2$Clusters
tabA14[18,6] <- dig3(lm1$r.squared)
tabA14[19,6] <- paste(dig3(lm1$p.val[7]),stars.pval(lm1$p.val[7]),sep="")

tabA14

# table A15
tabA15 <- matrix(rep("",19*6),nrow=19)

lm1 <- lm.cluster.wild(gr_sh ~ gr_yr + ideomatch + gr_yr_ideomatch + factor(newsid),idx=idx1,subset=newsid<=32,unitid=newsid)
lm2 <- lm0(gr_sh ~ gr_yr + ideomatch + gr_yr_ideomatch + factor(newsid),subset=newsid<=32,unitid=country)
tabA15[1,1] <- as.coef(lm1$coef[2],p.val=lm1$p.val[2])
tabA15[2,1] <- as.se(lm1$se[2])
tabA15[7,1] <- as.coef(lm1$coef[3],p.val=lm1$p.val[3])
tabA15[8,1] <- as.se(lm1$se[3])
tabA15[9,1] <- as.coef(lm1$coef[4],p.val=lm1$p.val[4])
tabA15[10,1] <- as.se(lm1$se[4])
tabA15[15,1] <- lm1$N
tabA15[16,1] <- lm1$Clusters
tabA15[17,1] <- lm2$Clusters
tabA15[18,1] <- dig3(lm1$r.squared)
tabA15[19,1] <- paste(dig3(lm1$p.val[5]),stars.pval(lm1$p.val[5]),sep="")

lm1 <- lm.cluster.wild(un_sh ~ un_yr + ideomatch + un_yr_ideomatch + factor(newsid),idx=idx1,subset=newsid<=32,unitid=newsid)
lm2 <- lm0(un_sh ~ un_yr + ideomatch + un_yr_ideomatch + factor(newsid),subset=newsid<=32,unitid=country)
tabA15[3,2] <- as.coef(lm1$coef[2],p.val=lm1$p.val[2])
tabA15[4,2] <- as.se(lm1$se[2])
tabA15[7,2] <- as.coef(lm1$coef[3],p.val=lm1$p.val[3])
tabA15[8,2] <- as.se(lm1$se[3])
tabA15[11,2] <- as.coef(lm1$coef[4],p.val=lm1$p.val[4])
tabA15[12,2] <- as.se(lm1$se[4])
tabA15[15,2] <- lm1$N
tabA15[16,2] <- lm1$Clusters
tabA15[17,2] <- lm2$Clusters
tabA15[18,2] <- dig3(lm1$r.squared)
tabA15[19,2] <- paste(dig3(lm1$p.val[5]),stars.pval(lm1$p.val[5]),sep="")

lm1 <- lm.cluster.wild(inf_sh ~ inf_yr + ideomatch + inf_yr_ideomatch + factor(newsid),idx=idx1,subset=newsid<=32,unitid=newsid)
lm2 <- lm0(inf_sh ~ inf_yr + ideomatch + inf_yr_ideomatch + factor(newsid),subset=newsid<=32,unitid=country)
tabA15[5,3] <- as.coef(lm1$coef[2],p.val=lm1$p.val[2])
tabA15[6,3] <- as.se(lm1$se[2])
tabA15[7,3] <- as.coef(lm1$coef[3],p.val=lm1$p.val[3])
tabA15[8,3] <- as.se(lm1$se[3])
tabA15[13,3] <- as.coef(lm1$coef[4],p.val=lm1$p.val[4])
tabA15[14,3] <- as.se(lm1$se[4])
tabA15[15,3] <- lm1$N
tabA15[16,3] <- lm1$Clusters
tabA15[17,3] <- lm2$Clusters
tabA15[18,3] <- dig3(lm1$r.squared)
tabA15[19,3] <- paste(dig3(lm1$p.val[5]),stars.pval(lm1$p.val[5]),sep="")

lm1 <- lm.cluster.wild(gr_sh_hl ~ gr_yr + ideomatch + gr_yr_ideomatch + factor(newsid),idx=idx1,subset=newsid<=32,unitid=newsid)
lm2 <- lm0(gr_sh_hl ~ gr_yr + ideomatch + gr_yr_ideomatch + factor(newsid),subset=newsid<=32,unitid=country)
tabA15[1,4] <- as.coef(lm1$coef[2],p.val=lm1$p.val[2])
tabA15[2,4] <- as.se(lm1$se[2])
tabA15[7,4] <- as.coef(lm1$coef[3],p.val=lm1$p.val[3])
tabA15[8,4] <- as.se(lm1$se[3])
tabA15[9,4] <- as.coef(lm1$coef[4],p.val=lm1$p.val[4])
tabA15[10,4] <- as.se(lm1$se[4])
tabA15[15,4] <- lm1$N
tabA15[16,4] <- lm1$Clusters
tabA15[17,4] <- lm2$Clusters
tabA15[18,4] <- dig3(lm1$r.squared)
tabA15[19,4] <- paste(dig3(lm1$p.val[5]),stars.pval(lm1$p.val[5]),sep="")

lm1 <- lm.cluster.wild(un_sh_hl ~ un_yr + ideomatch + un_yr_ideomatch + factor(newsid),idx=idx1,subset=newsid<=32,unitid=newsid)
lm2 <- lm0(un_sh_hl ~ un_yr + ideomatch + un_yr_ideomatch + factor(newsid),subset=newsid<=32,unitid=country)
tabA15[3,5] <- as.coef(lm1$coef[2],p.val=lm1$p.val[2])
tabA15[4,5] <- as.se(lm1$se[2])
tabA15[7,5] <- as.coef(lm1$coef[3],p.val=lm1$p.val[3])
tabA15[8,5] <- as.se(lm1$se[3])
tabA15[11,5] <- as.coef(lm1$coef[4],p.val=lm1$p.val[4])
tabA15[12,5] <- as.se(lm1$se[4])
tabA15[15,5] <- lm1$N
tabA15[16,5] <- lm1$Clusters
tabA15[17,5] <- lm2$Clusters
tabA15[18,5] <- dig3(lm1$r.squared)
tabA15[19,5] <- paste(dig3(lm1$p.val[5]),stars.pval(lm1$p.val[5]),sep="")

lm1 <- lm.cluster.wild(inf_sh_hl ~ inf_yr + ideomatch + inf_yr_ideomatch + factor(newsid),idx=idx1,subset=newsid<=32,unitid=newsid)
lm2 <- lm0(inf_sh_hl ~ inf_yr + ideomatch + inf_yr_ideomatch + factor(newsid),subset=newsid<=32,unitid=country)
tabA15[5,6] <- as.coef(lm1$coef[2],p.val=lm1$p.val[2])
tabA15[6,6] <- as.se(lm1$se[2])
tabA15[7,6] <- as.coef(lm1$coef[3],p.val=lm1$p.val[3])
tabA15[8,6] <- as.se(lm1$se[3])
tabA15[13,6] <- as.coef(lm1$coef[4],p.val=lm1$p.val[4])
tabA15[14,6] <- as.se(lm1$se[4])
tabA15[15,6] <- lm1$N
tabA15[16,6] <- lm1$Clusters
tabA15[17,6] <- lm2$Clusters
tabA15[18,6] <- dig3(lm1$r.squared)
tabA15[19,6] <- paste(dig3(lm1$p.val[5]),stars.pval(lm1$p.val[5]),sep="")

tabA15

}

# table A16
tabA16 <- matrix(rep("",26*6),ncol=6)

# gr sent
lm1 <- logit0(gr_ratpn  ~ gr_yr2 + ideomatch2 + gr_yr_ideomatch2 + factor(newsid2),subset=type=="articles"&train==0,unitid=newsid2,se="cluster")
lm2 <- logit0(gr_ratpn  ~ gr_yr2 + ideomatch2 + gr_yr_ideomatch2 + factor(newsid2),subset=type=="articles"&train==0,unitid=country2,se="cluster")
tabA16[1,1] <- as.coef(lm1$coef[2],lm1$se[2])
tabA16[2,1] <- as.se(lm1$se[2])
tabA16[11,1] <- as.coef(lm1$coef[3],lm1$se[3])
tabA16[12,1] <- as.se(lm1$se[3])
tabA16[13,1] <- as.coef(lm1$coef[4],lm1$se[4])
tabA16[14,1] <- as.se(lm1$se[4])
tabA16[23,1] <- lm1$N
tabA16[24,1] <- lm1$Clusters
tabA16[25,1] <- lm2$Clusters
tabA16[26,1] <- paste(dig3(wald.test(wald34,lm1$coef,lm1$V)$pval),stars.pval(wald.test(wald34,lm1$coef,lm1$V)$pval),sep="")

# un sent
lm1 <- logit0(un_ratpn ~ gr_yr2 + unch_yr2  + ideomatch2 + gr_yr_ideomatch2 + unch_yr_ideomatch2 + factor(newsid2),subset=type=="articles"&train==0,unitid=newsid2,se="cluster")
lm2 <- logit0(un_ratpn ~ gr_yr2 + unch_yr2  + ideomatch2 + gr_yr_ideomatch2 + unch_yr_ideomatch2 + factor(newsid2),subset=type=="articles"&train==0,unitid=country2,se="cluster")
tabA16[1,2] <- as.coef(lm1$coef[2],lm1$se[2])
tabA16[2,2] <- as.se(lm1$se[2])
tabA16[5,2] <- as.coef(lm1$coef[3],lm1$se[3])
tabA16[6,2] <- as.se(lm1$se[3])
tabA16[11,2] <- as.coef(lm1$coef[4],lm1$se[4])
tabA16[12,2] <- as.se(lm1$se[4])
tabA16[13,2] <- as.coef(lm1$coef[5],lm1$se[5])
tabA16[14,2] <- as.se(lm1$se[5])
tabA16[17,2] <- as.coef(lm1$coef[6],lm1$se[6])
tabA16[18,2] <- as.se(lm1$se[6])
tabA16[23,2] <- lm1$N
tabA16[24,2] <- lm1$Clusters
tabA16[25,2] <- lm2$Clusters
tabA16[26,2] <- paste(dig3(wald.test(wald456,lm1$coef,lm1$V)$pval),stars.pval(wald.test(wald456,lm1$coef,lm1$V)$pval),sep="")

# inf sent
lm1 <- logit0(inf_ratpn ~ gr_yr2 + infch_yr2 + ideomatch2 + gr_yr_ideomatch2 + infch_yr_ideomatch2 + factor(newsid2),subset=type=="articles"&train==0,unitid=newsid2,se="cluster")
lm2 <- logit0(inf_ratpn ~ gr_yr2 + infch_yr2 + ideomatch2 + gr_yr_ideomatch2 + infch_yr_ideomatch2 + factor(newsid2),subset=type=="articles"&train==0,unitid=country2,se="cluster")
tabA16[1,3] <- as.coef(lm1$coef[2],lm1$se[2]) # gr
tabA16[2,3] <- as.se(lm1$se[2])
tabA16[9,3] <- as.coef(lm1$coef[3],lm1$se[3]) # infch
tabA16[10,3] <- as.se(lm1$se[3])
tabA16[11,3] <- as.coef(lm1$coef[4],lm1$se[4]) # ideo
tabA16[12,3] <- as.se(lm1$se[4])
tabA16[13,3] <- as.coef(lm1$coef[5],lm1$se[5]) # ideo * gr
tabA16[14,3] <- as.se(lm1$se[5])
tabA16[21,3] <- as.coef(lm1$coef[6],lm1$se[6]) # ideo * infch
tabA16[22,3] <- as.se(lm1$se[6])
tabA16[23,3] <- lm1$N
tabA16[24,3] <- lm1$Clusters
tabA16[25,3] <- lm2$Clusters
tabA16[26,3] <- paste(dig3(wald.test(wald456,lm1$coef,lm1$V)$pval),stars.pval(wald.test(wald456,lm1$coef,lm1$V)$pval),sep="")

# gr cov
lm1 <- logit0(gr_ratn6 ~ gr_yr2 + ideomatch2 + gr_yr_ideomatch2 + factor(newsid2),subset=type=="articles"&train==0,unitid=newsid2,se="cluster")
lm2 <- logit0(gr_ratn6 ~ gr_yr2 + ideomatch2 + gr_yr_ideomatch2 + factor(newsid2),subset=type=="articles"&train==0,unitid=country2,se="cluster")
tabA16[1,4] <- as.coef(lm1$coef[2],lm1$se[2]) # gr
tabA16[2,4] <- as.se(lm1$se[2])
tabA16[11,4] <- as.coef(lm1$coef[3],lm1$se[3]) # ideo
tabA16[12,4] <- as.se(lm1$se[3])
tabA16[13,4] <- as.coef(lm1$coef[4],lm1$se[4]) # ideo * gr
tabA16[14,4] <- as.se(lm1$se[4])
tabA16[23,4] <- lm1$N ## THIS WAS ERROR
tabA16[24,4] <- lm1$Clusters
tabA16[25,4] <- lm2$Clusters
tabA16[26,4] <- paste(dig3(wald.test(wald34,lm1$coef,lm1$V)$pval),stars.pval(wald.test(wald34,lm1$coef,lm1$V)$pval),sep="")

# un cov
lm1 <- logit0(un_ratn6 ~ un_yr2 + ideomatch2 + un_yr_ideomatch2 + factor(newsid2),subset=type=="articles"&train==0,unitid=newsid2,se="cluster")
lm2 <- logit0(un_ratn6 ~ un_yr2 + ideomatch2 + un_yr_ideomatch2 + factor(newsid2),subset=type=="articles"&train==0,unitid=country2,se="cluster")
tabA16[3,5] <- as.coef(lm1$coef[2],lm1$se[2]) # un
tabA16[4,5] <- as.se(lm1$se[2])
tabA16[11,5] <- as.coef(lm1$coef[3],lm1$se[3]) # ideo
tabA16[12,5] <- as.se(lm1$se[3])
tabA16[15,5] <- as.coef(lm1$coef[4],lm1$se[4]) # ideo * un
tabA16[16,5] <- as.se(lm1$se[4])
tabA16[23,5] <- lm1$N
tabA16[24,5] <- lm1$Clusters
tabA16[25,5] <- lm2$Clusters
tabA16[26,5] <- paste(dig3(wald.test(wald34,lm1$coef,lm1$V)$pval),stars.pval(wald.test(wald34,lm1$coef,lm1$V)$pval),sep="")

# inf cov
lm1 <- logit0(inf_ratn6 ~ inf_yr2 + ideomatch2 + inf_yr_ideomatch2 + factor(newsid2),subset=type=="articles"&train==0,unitid=newsid2,se="cluster")
lm2 <- logit0(inf_ratn6 ~ inf_yr2 + ideomatch2 + inf_yr_ideomatch2 + factor(newsid2),subset=type=="articles"&train==0,unitid=country2,se="cluster")
tabA16[7,6] <- as.coef(lm1$coef[2],lm1$se[2]) # inf
tabA16[8,6] <- as.se(lm1$se[2])
tabA16[11,6] <- as.coef(lm1$coef[3],lm1$se[3]) # ideo
tabA16[12,6] <- as.se(lm1$se[3])
tabA16[19,6] <- as.coef(lm1$coef[4],lm1$se[4]) # ideo * inf
tabA16[20,6] <- as.se(lm1$se[4])
tabA16[23,6] <- lm1$N
tabA16[24,6] <- lm1$Clusters
tabA16[25,6] <- lm2$Clusters
tabA16[26,6] <- paste(dig3(wald.test(wald34,lm1$coef,lm1$V)$pval),stars.pval(wald.test(wald34,lm1$coef,lm1$V)$pval),sep="")

tabA16

# create the latex code for the tables
file1 <- paste(dir1,"tables.tex",sep="")
latex.doc.start(file1)

# table 2
latex.add.line(file1,"\\begin{table}[htp]\\centering\\scriptsize")
latex.add.line(file1,"\\begin{singlespace}")
latex.add.line(file1,"\\begin{tabular}{ l c c c c c c c } \\hline \\hline")
latex.add.line(file1," & \\textbf{Month} & \\textbf{Quarter} & \\textbf{Semi-year} & \\textbf{Year} & \\textbf{2 Years} & \\textbf{4 Years} & \\textbf{N} \\\\")
latex.add.line(file1,"\\\\")
latex.add.line(file1,"\\textbf{Growth Sentiment}\\\\")
latex.table.entry(file1,"\\hspace{.4cm}Growth",tab2[1,1:7])
latex.table.entry(file1,"\\hspace{.6cm}\\textit{error corrected}",tab2[2,1:7])
latex.add.line(file1,"\\\\")
latex.add.line(file1,"\\textbf{Unemployment Sentiment}\\\\")
latex.table.entry(file1,"\\hspace{.4cm}Unemployment",tab2[3,1:7])
latex.table.entry(file1,"\\hspace{.6cm}\\textit{error corrected}",tab2[4,1:7])
latex.table.entry(file1,"\\\\ \\hspace{.4cm}Change in Unemployment",tab2[5,1:7])
latex.table.entry(file1,"\\hspace{.6cm}\\textit{error corrected}",tab2[6,1:7])
latex.add.line(file1,"\\\\")
latex.add.line(file1,"\\textbf{Inflation Sentiment}\\\\")
latex.table.entry(file1,"\\hspace{.4cm}Inflation ",tab2[7,1:7])
latex.table.entry(file1,"\\hspace{.6cm}\\textit{error corrected}",tab2[8,1:7])
latex.table.entry(file1,"\\\\ \\hspace{.4cm}Change in Inflation ",tab2[9,1:7])
latex.table.entry(file1,"\\hspace{.6cm}\\textit{error corrected}",tab2[10,1:7])
latex.add.line(file1,"\\hline \\hline")
latex.add.line(file1,"\\end{tabular}")
latex.add.line(file1,"\\end{singlespace}")
latex.add.line(file1,"\\caption{\\footnotesize{Correlations between Sentiment and the Economy, Corrected for Measurement Error --- Largest correlation for each measure of economy is highlighted in bold.}}")
latex.add.line(file1,"\\label{t:SentimentEconCorr2}")
latex.add.line(file1,"\\end{table}\n\n\n")

# table 3
latex.add.line(file1,"\\begin{table}[htp]\\centering")
latex.add.line(file1,"\\begin{footnotesize}")
latex.add.line(file1,"\\begin{tabular}{ l c c c c} \\hline \\hline")
latex.add.line(file1,"\\textbf{Dependent Variable:} & Economic & Growth & Unemployment & Inflation \\\\	")
latex.add.line(file1," & Sentiment & Sentiment & Sentiment & Sentiment \\\\")
latex.add.line(file1," & (articles) & (articles) & (articles) & (articles) \\\\")
latex.add.line(file1,"\\\\		")
latex.add.line(file1,"\\textbf{Independent Variables:} \\\\")
latex.table.entry(file1,"\\hspace{.4cm}Constant",tab3[1,])
latex.table.entry(file1,"",tab3[2,])
latex.table.entry(file1,"\\hspace{.4cm}Growth (yearly)",tab3[3,])
latex.table.entry(file1,paste("\\hspace{.4cm}(SD = ",dig3(sd_gr),")",sep=""),tab3[4,])
latex.table.entry(file1,"\\hspace{.4cm}Change in Unem. (yearly)",tab3[5,])
latex.table.entry(file1,paste("\\hspace{.4cm}(SD = ",dig3(sd_unch),")",sep=""),tab3[6,])
latex.table.entry(file1,"\\hspace{.4cm}Change in Inf. (yearly)",tab3[7,])
latex.table.entry(file1,paste("\\hspace{.4cm}(SD = ",dig3(sd_infch),")",sep=""),tab3[8,])
latex.add.line(file1,"\\\\")
latex.add.line(file1,"\\textbf{Predicted Values:} \\\\")
latex.table.entry(file1,"\\hspace{.4cm}2nd Percentile",tab3[13,])
latex.table.entry(file1,"\\hspace{.4cm}One S.D. Worse than Mean",tab3[15,])
latex.table.entry(file1,"\\hspace{.4cm}At Mean",tab3[17,])
latex.table.entry(file1,"\\hspace{.4cm}One S.D. Improv. over Mean",tab3[19,])
latex.table.entry(file1,"\\hspace{.4cm}98th Percentile",tab3[21,])
latex.add.line(file1,"\\\\")
latex.table.entry(file1,"\\textbf{Number of Months}",tab3[9,])
latex.table.entry(file1,"\\textbf{Number of Newspapers}",tab3[10,])
latex.table.entry(file1,"\\textbf{Number of Countries}",tab3[11,])
latex.table.entry(file1,"\\textbf{R-Squared}",tab3[12,])
latex.add.line(file1,"\\hline \\hline")
latex.add.line(file1,"\\end{tabular}")
latex.add.line(file1,"\\end{footnotesize}")
latex.add.line(file1,"\\caption{\\footnotesize{The Effect of the Economy on Newspaper Sentiment --- Newspaper fixed effects were included in each regression, but omitted from the table. Standard errors clustered by newspaper in parentheses. $^+ p<.10, ^{*} p<.05,  ^{**} p<.01, ^{***} p<.001$.}}")
latex.add.line(file1,"\\label{SentimentRegressions}")
latex.add.line(file1,"\\end{table}\n\n\n")

# table 4
latex.add.line(file1,"\\begin{table}[htp]\\centering\\scriptsize")
latex.add.line(file1,"\\begin{singlespace}")
latex.add.line(file1,"\\begin{tabular}{ l c c c c c c c } \\hline \\hline")
latex.add.line(file1," & \\textbf{Month} & \\textbf{Quarter} & \\textbf{Semi-year} & \\textbf{Year} & \\textbf{2 Years} & \\textbf{4 Years} & \\textbf{N} \\\\")
latex.add.line(file1,"\\\\")
latex.add.line(file1,"\\textbf{Growth Share of Coverage}\\\\")
latex.table.entry(file1,"\\hspace{.4cm}Growth",tab4[1,1:7])
latex.add.line(file1,"\\\\")
latex.add.line(file1,"\\textbf{Unemployment Share of Coverage}\\\\")
latex.table.entry(file1,"\\hspace{.4cm}Unemployment",tab4[2,1:7])
latex.table.entry(file1,"\\hspace{.4cm}Change in Unemployment",tab4[3,1:7])
latex.add.line(file1,"\\\\")
latex.add.line(file1,"\\textbf{Inflation Share of Coverage}\\\\")
latex.table.entry(file1,"\\hspace{.4cm}Inflation ",tab4[4,1:7])
latex.table.entry(file1,"\\hspace{.4cm}Change in Inflation ",tab4[5,1:7])
latex.add.line(file1,"\\hline \\hline")
latex.add.line(file1,"\\end{tabular}")
latex.add.line(file1,"\\end{singlespace}")
latex.add.line(file1,"\\caption{\\footnotesize{Correlations between Share of Coverage and the Economy --- Largest correlation for each measure of economy is highlighted in bold.}}")
latex.add.line(file1,"\\label{t:CorrCoverageEcon}")
latex.add.line(file1,"\\end{table}\n\n\n")

# table 5
latex.add.line(file1,"\\begin{table}\\centering")
latex.add.line(file1,"\\begin{footnotesize}")
latex.add.line(file1,"\\begin{tabular}{ l c c c c } \\hline \\hline")
latex.add.line(file1,"\\textbf{Dependent Variable:} & Economic & Growth Share & Unemployment Share & Inflation Share \\\\")
latex.add.line(file1," & Coverage & of Coverage & of Coverage & of Coverage \\\\")
latex.add.line(file1," & (articles) & (articles) & (articles) & (articles) \\\\")
latex.add.line(file1,"\\\\")
latex.add.line(file1,"\\textbf{Independent Variables:}\\\\")
latex.table.entry(file1,"\\hspace{.4cm}Growth (yearly)",tab5[1,1:4])
latex.table.entry(file1,"",tab5[2,1:4])
latex.table.entry(file1,"\\hspace{.4cm}Unemployment (yearly)",tab5[3,1:4])
latex.table.entry(file1,"",tab5[4,1:4])
latex.table.entry(file1,"\\hspace{.4cm}Inflation (yearly)",tab5[5,1:4])
latex.table.entry(file1,"",tab5[6,1:4])
latex.add.line(file1,"\\\\")
latex.table.entry(file1,"\\textbf{Number of Months}",tab5[7,1:4])
latex.table.entry(file1,"\\textbf{Number of Newspapers}",tab5[8,1:4])
latex.table.entry(file1,"\\textbf{Number of Countries}",tab5[9,1:4])
latex.table.entry(file1,"\\textbf{R-Squared}",tab5[10,1:4])
latex.add.line(file1,"\\hline \\hline")
latex.add.line(file1,"\\end{tabular}")
latex.add.line(file1,"\\end{footnotesize}")
latex.add.line(file1,"\\caption{\\footnotesize{The Effect of the Economy on Newspaper Coverage --- Newspaper fixed effects were included in each equation, but omitted from the table. Standard errors clustered by newspaper in parentheses. $^+ p<.10, ^{*} p<.05,  ^{**} p<.01, ^{***} p<.001$.}}")
latex.add.line(file1,"\\label{MultivariateCoverageReg}")
latex.add.line(file1,"\\end{table}")

# table 6
latex.add.line(file1,"\\begin{table}[htp]\\centering")
latex.add.line(file1,"\\begin{singlespace}")
latex.add.line(file1,"\\begin{footnotesize}")
latex.add.line(file1,"\\begin{tabular}{ l c c} \\hline \\hline")
latex.add.line(file1,"\\textbf{Country} & \\textbf{Correlation} & \\textbf{N} \\\\")
latex.table.entry(file1,"Australia ",tab6[1,])
latex.table.entry(file1,"Austria ",tab6[2,])
latex.table.entry(file1,"Canada ",tab6[3,])
latex.table.entry(file1,"France ",tab6[4,])
latex.table.entry(file1,"Germany ",tab6[5,])
latex.table.entry(file1,"Ireland ",tab6[6,])
latex.table.entry(file1,"Israel ",tab6[7,])
latex.table.entry(file1,"Italy ",tab6[8,])
latex.table.entry(file1,"Japan ",tab6[9,])
latex.table.entry(file1,"Luxembourg ",tab6[10,])
latex.table.entry(file1,"New Zealand ",tab6[11,])
latex.table.entry(file1,"Portugal ",tab6[12,])
latex.table.entry(file1,"Spain ",tab6[13,])
latex.table.entry(file1,"Switzerland ",tab6[14,])
latex.table.entry(file1,"United Kingdom ",tab6[15,])
latex.table.entry(file1,"United States ",tab6[16,])
latex.add.line(file1,"\\hline \\hline")
latex.add.line(file1,"\\end{tabular}")
latex.add.line(file1,"\\end{footnotesize}")
latex.add.line(file1,"\\end{singlespace}")
latex.add.line(file1,"\\caption{\\footnotesize{Correlation between Sentiment in Left-wing and Right-wing Papers.}}")
latex.add.line(file1,"\\label{t:LeftRightCorrTable}")
latex.add.line(file1,"\\end{table}\n\n\n")

# table 7
latex.add.line(file1,"\\begin{landscape}")
latex.add.line(file1,"\\begin{table}\\centering")
latex.add.line(file1,"\\begin{footnotesize}")
latex.add.line(file1,"\\begin{tabular}{ l c c c c c c} \\hline \\hline")
latex.add.line(file1,"\\textbf{Dependent Variable:} & Growth & Unemployment & Inflation & Growth & Unemployment & Inflation \\\\")
latex.add.line(file1," & Sentiment & Sentiment & Sentiment & Sentiment & Sentiment & Sentiment \\\\")
latex.add.line(file1," & (articles) & (articles) & (articles)  & (headlines) & (headlines) & (headlines) \\\\")
latex.add.line(file1,"\\\\")
latex.add.line(file1,"\\textbf{Independent Variables:}\\\\")
latex.table.entry(file1,"\\hspace{.4cm}Growth (yearly)",tab7[1,])
latex.table.entry(file1,"",tab7[2,])
latex.table.entry(file1,"\\hspace{.4cm}Change in Unemployment (yearly)",tab7[3,])
latex.table.entry(file1,"",tab7[4,])
latex.table.entry(file1,"\\hspace{.4cm}Change in Inflation (yearly)",tab7[5,])
latex.table.entry(file1,"",tab7[6,])
latex.table.entry(file1,"\\hspace{.4cm}Ideological Match",tab7[7,])
latex.table.entry(file1,"",tab7[8,])
latex.table.entry(file1,"\\hspace{.4cm}Growth * Ideo. Match",tab7[9,])
latex.table.entry(file1,"",tab7[10,])
latex.table.entry(file1,"\\hspace{.4cm}Change in Unem. * Ideo. Match",tab7[11,])
latex.table.entry(file1,"",tab7[12,])
latex.table.entry(file1,"\\hspace{.4cm}Change in Inf. * Ideo. Match",tab7[13,])
latex.table.entry(file1,"",tab7[14,])
latex.add.line(file1,"\\\\")
latex.add.line(file1,"\\textbf{p-Value from Wald Test:}\\\\")
latex.table.entry(file1,"\\hspace{.4cm} Ideology Terms = 0",tab7[19,])
latex.add.line(file1,"\\\\")
latex.table.entry(file1,"\\textbf{Number of Months}",tab7[15,])
latex.table.entry(file1,"\\textbf{Number of Newspapers}",tab7[16,])
latex.table.entry(file1,"\\textbf{Number of Countries}",tab7[17,])
latex.table.entry(file1,"\\textbf{R-Squared}",tab7[18,])
latex.add.line(file1,"\\hline \\hline")
latex.add.line(file1,"\\end{tabular}")
latex.add.line(file1,"\\end{footnotesize}")
latex.add.line(file1,"\\caption{Media Bias in Sentiment --- Newspaper fixed effects were included in the analysis, but omitted from the table. Standard errors clustered by newspaper in parentheses. In all cases, the null hypothesis in the Wald test is that Ideological Match and it's interactions with the economy are jointly zero. $^+ p<.10, ^{*} p<.05,  ^{**} p<.01, ^{***} p<.001$.}")
latex.add.line(file1,"\\label{ToneBiasTable}")
latex.add.line(file1,"\\end{table}")
latex.add.line(file1,"\\end{landscape}\n\n\n")

# table 8
latex.add.line(file1,"\\begin{landscape}")
latex.add.line(file1,"\\begin{table}\\centering")
latex.add.line(file1,"\\begin{footnotesize}")
latex.add.line(file1,"\\begin{tabular}{ l c c c c c c} \\hline \\hline")
latex.add.line(file1,"\\textbf{Dependent Variable:} & Growth & Unemployment & Inflation & Growth & Unemployment & Inflation \\\\")
latex.add.line(file1," & Coverage & Coverage & Coverage& Coverage & Coverage & Coverage  \\\\")
latex.add.line(file1," & (articles) & (articles) & (articles)  & (headlines) & (headlines) & (headlines) \\\\")
latex.add.line(file1,"\\\\")
latex.add.line(file1,"\\textbf{Independent Variables:}\\\\")
latex.table.entry(file1,"\\hspace{.4cm}Growth (yearly)",tab8[1,])
latex.table.entry(file1,"",tab8[2,])
latex.table.entry(file1,"\\hspace{.4cm}Unemployment (yearly)",tab8[3,])
latex.table.entry(file1,"",tab8[4,])
latex.table.entry(file1,"\\hspace{.4cm}Inflation (yearly)",tab8[5,])
latex.table.entry(file1,"",tab8[6,])
latex.table.entry(file1,"\\hspace{.4cm}Ideological Match",tab8[7,])
latex.table.entry(file1,"",tab8[8,])
latex.table.entry(file1,"\\hspace{.4cm}Growth * Ideo. Match",tab8[9,])
latex.table.entry(file1,"",tab8[10,])
latex.table.entry(file1,"\\hspace{.4cm}Unem. * Ideo. Match",tab8[11,])
latex.table.entry(file1,"",tab8[12,])
latex.table.entry(file1,"\\hspace{.4cm}Inf. * Ideo. Match",tab8[13,])
latex.table.entry(file1,"",tab8[14,])
latex.add.line(file1,"\\\\")
latex.add.line(file1,"\\textbf{p-Value from Wald Test:}\\\\")
latex.table.entry(file1,"\\hspace{.4cm} Ideology Terms = 0",tab8[19,])
latex.add.line(file1,"\\\\")
latex.table.entry(file1,"\\textbf{Number of Months}",tab8[15,])
latex.table.entry(file1,"\\textbf{Number of Newspapers}",tab8[16,])
latex.table.entry(file1,"\\textbf{Number of Countries}",tab8[17,])
latex.table.entry(file1,"\\textbf{R-Squared}",tab8[18,])
latex.add.line(file1,"\\hline \\hline")
latex.add.line(file1,"\\end{tabular}")
latex.add.line(file1,"\\end{footnotesize}")
latex.add.line(file1,"\\caption{Media Bias in Coverage --- Newspaper fixed effects were included in the analysis, but omitted from the table. Standard errors clustered by newspaper in parentheses. In all cases, the null hypothesis in the Wald test is that Ideological Match and it's interaction with the economy are jointly zero. $^+ p<.10, ^{*} p<.05,  ^{**} p<.01, ^{***} p<.001$.}")
latex.add.line(file1,"\\label{CoverageBiasTable}")
latex.add.line(file1,"\\end{table}")
latex.add.line(file1,"\\end{landscape}\n\n\n")

# table A1
latex.table.start(file1,8)
rats <- c("Economic Articles","Growth Articles","Unemployment Articles","Inflation Articles")
for(j in 1:4)
{
	latex.add.line(file1,paste(" & \\multicolumn{8}{c}{\\textbf{",rats[j],"}} \\\\",sep=""))
	latex.add.line(file1," & \\multicolumn{2}{c}{\\textbf{All}} & \\multicolumn{2}{c}{\\textbf{English}} & \\multicolumn{2}{c}{\\textbf{French}} & \\multicolumn{2}{c}{\\textbf{German}} \\\\")
	latex.add.line(file1," & \\textit{Articles} & \\textit{Headlines}& \\textit{Articles} & \\textit{Headlines}& \\textit{Articles} & \\textit{Headlines} & \\textit{Articles} & \\textit{Headlines} \\\\")
	latex.add.line(file1,"\\textbf{Topic:} \\\\")
	latex.table.entries(file1,c("\\hspace{.4cm}Both Yes","\\hspace{.4cm}Both No","\\hspace{.4cm}Error","\\hspace{.4cm}Kappa","\\hspace{.4cm}n"),tabA1[11*(j-1)+1:5,])
	latex.add.line(file1,"\\textbf{Sentiment:} \\\\")
	latex.table.entries(file1,c("\\hspace{.4cm}Same","\\hspace{.4cm}Same Direction","\\hspace{.4cm}One Neutral","\\hspace{.4cm}Error","\\hspace{.4cm}Kappa","\\hspace{.4cm}n"),tabA1[11*(j-1)+6:11,])
}
latex.add.line(file1,"\\hline \\hline")
latex.add.line(file1,"\\end{tabular}")
latex.add.line(file1,"\\end{singlespace}")
latex.add.line(file1,"\\caption{Coder Reliability --- \\textit{Both Yes} and \\textit{Both No} indicates both coders made the same choice in assigning an article to a topic. \\textit{Same} indicates that coders reported the same value on the five point scale. \\textit{Same Direction} indicates that both coders selected a positive rating, both coders selected a negative rating, or both coders selected a neutral rating. \\textit{One Neutral} indicates that one coder select a neutral rating with the other selecting a positive or negative rating. \\textit{Error} indicates that one coder assigned an article to a particular topic while the other did not, or that one coder selected a positive rating while the other selected a negative rating. \\textit{Kappa} is \\citeauthor{Cohen1960}'s (\\citeyear{Cohen1960}) measure of inter-coder reliability..}")
latex.add.line(file1,"\\label{CoderTable}")
latex.add.line(file1,"\\end{table}")

# table A2
latex.table.start(file1,3)
latex.add.line(file1," & \\textbf{Mean S.D.} & \\textbf{2.5\\% Quantile of S.D.} & \\textbf{97.5\\% Quantile of S.D.} \\\\")
latex.table.entries(file1,newspapers,tabA2)
latex.add.line(file1,"\\hline \\hline")
latex.add.line(file1,"\\end{tabular}")
latex.add.line(file1,"\\end{singlespace}")
latex.add.line(file1,"\\caption{Sampling Error in Dictionary Coding.}")
latex.add.line(file1,"\\label{METable}")
latex.add.line(file1,"\\end{table}")

# table A3
latex.table.start(file1,8)
latex.add.line(file1,"\\\\")
latex.add.line(file1,paste(" & \\multicolumn{8}{c}{\\textbf{Topics}} \\\\",sep=""))
latex.add.line(file1," & \\multicolumn{4}{c}{\\textbf{Articles}} & \\multicolumn{4}{c}{\\textbf{Headlines}} \\\\")
latex.add.line(file1," & \\textit{Economy} & \\textit{Growth}& \\textit{Unem.} & \\textit{Inflation}& \\textit{Economy} & \\textit{Growth}& \\textit{Unem.} & \\textit{Inflation} \\\\")
latex.table.entries(file1,c("Slope","","N"),tabA3[3:5,])
latex.add.line(file1,"\\\\")
latex.add.line(file1,paste(" & \\multicolumn{8}{c}{\\textbf{Sentiment (Logit model)}} \\\\",sep=""))
latex.add.line(file1," & \\multicolumn{4}{c}{\\textbf{Articles}} & \\multicolumn{4}{c}{\\textbf{Headlines}} \\\\")
latex.add.line(file1," & \\textit{Economy} & \\textit{Growth}& \\textit{Unem.} & \\textit{Inflation}& \\textit{Economy} & \\textit{Growth}& \\textit{Unem.} & \\textit{Inflation} \\\\")
latex.table.entries(file1,c("Slope","","N"),tabA3[8:10,])
latex.add.line(file1,"\\\\")
latex.add.line(file1,paste(" & \\multicolumn{8}{c}{\\textbf{Sentiment (Ordered Logit model)}} \\\\",sep=""))
latex.add.line(file1," & \\multicolumn{4}{c}{\\textbf{Articles}} & \\multicolumn{4}{c}{\\textbf{Headlines}} \\\\")
latex.add.line(file1," & \\textit{Economy} & \\textit{Growth}& \\textit{Unem.} & \\textit{Inflation}& \\textit{Economy} & \\textit{Growth}& \\textit{Unem.} & \\textit{Inflation} \\\\")
latex.table.entries(file1,c("Slope","","N"),tabA3[11:13,])
latex.add.line(file1,"\\hline \\hline")
latex.add.line(file1,"\\end{tabular}")
latex.add.line(file1,"\\end{singlespace}")
latex.add.line(file1,"\\caption{Comparing Human Coding to Dictionary Coding. In each case, the dependent variable is the human-coded measure and the independent variable is the dictionary-based measure. Constant terms and cutpoints are omitted from the table. Standard errors in parentheses. $^+ p<.10, ^{*} p<.05,  ^{**} p<.01, ^{***} p<.001$.}")
latex.add.line(file1,"\\label{CoderTable}")
latex.add.line(file1,"\\end{table}")

# table A4
latex.add.line(file1,"\\begin{table}[htp]\\centering")
latex.add.line(file1,"\\begin{footnotesize}")
latex.add.line(file1,"\\begin{tabular}{ l c c c c} \\hline \\hline")
latex.add.line(file1,"\\textbf{Dependent Variable:} & Economic & Growth & Unemployment & Inflation  \\\\	")
latex.add.line(file1," & Sentiment & Sentiment & Sentiment & Sentiment  \\\\")
latex.add.line(file1," & (headlines) & (headlines) & (headlines) & (headlines) \\\\")
latex.add.line(file1,"\\\\")
latex.add.line(file1,"\\textbf{Independent Variables:} \\\\")
latex.table.entry(file1,"\\hspace{.4cm}Constant",tabA4[1,])
latex.table.entry(file1,"",tabA4[2,])
latex.table.entry(file1,"\\hspace{.4cm}Growth (yearly)",tabA4[3,])
latex.table.entry(file1,paste("\\hspace{.4cm}(SD = ",dig3(sd0(gr_yr,subset=newsid<=32)),")",sep=""),tabA4[4,])
latex.table.entry(file1,"\\hspace{.4cm}Change in Unem. (yearly)",tabA4[5,])
latex.table.entry(file1,paste("\\hspace{.4cm}(SD = ",dig3(sd0(unch_yr,subset=newsid<=32)),")",sep=""),tabA4[6,])
latex.table.entry(file1,"\\hspace{.4cm}Change in Inf. (yearly)",tabA4[7,])
latex.table.entry(file1,paste("\\hspace{.4cm}(SD = ",dig3(sd0(remove.outliers(infch_yr,subset=newsid<=32,cutoff=5))),")",sep=""),tabA4[8,])
latex.add.line(file1,"\\\\")
latex.table.entry(file1,"\\textbf{Effect Size:}",tabA4[13,])
latex.table.entry(file1," ",tabA4[14,])
latex.add.line(file1,"\\\\")
latex.table.entry(file1,"\\textbf{Number of Months}",tabA4[9,])
latex.table.entry(file1,"\\textbf{Number of Newspapers}",tabA4[10,])
latex.table.entry(file1,"\\textbf{Number of Countries}",tabA4[11,])
latex.table.entry(file1,"\\textbf{R-Squared}",tabA4[12,])
latex.add.line(file1,"\\hline \\hline")
latex.add.line(file1,"\\end{tabular}")
latex.add.line(file1,"\\end{footnotesize}")
latex.add.line(file1,"\\caption{\\footnotesize{The Effect of the Economy on Newspaper Sentiment in Headlines --- Newspaper fixed effects were included in each regression, but omitted from the table. Standard errors clustered by newspaper in parentheses. $^+ p<.10, ^{*} p<.05,  ^{**} p<.01, ^{***} p<.001$.}}")
latex.add.line(file1,"\\label{SentimentRegressionsHL}")
latex.add.line(file1,"\\end{table}\n\n\n")

# table A5
latex.add.line(file1,"\\begin{table}\\centering")
latex.add.line(file1,"\\begin{footnotesize}")
latex.add.line(file1,"\\begin{tabular}{ l c c c c } \\hline \\hline")
latex.add.line(file1,"\\textbf{Dependent Variable:} & Economic & Growth Share & Unemployment Share & Inflation Share \\\\")
latex.add.line(file1," & Coverage & of Coverage & of Coverage & of Coverage \\\\")
latex.add.line(file1," & (articles) & (articles) & (articles) & (articles) \\\\")
latex.add.line(file1,"\\\\")
latex.add.line(file1,"\\textbf{Independent Variables:}\\\\")
latex.table.entry(file1,"\\hspace{.4cm}Growth (yearly)",tabA5[1,1:4])
latex.table.entry(file1,"",tabA5[2,1:4])
latex.table.entry(file1,"\\hspace{.4cm}Unemployment (yearly)",tabA5[3,1:4])
latex.table.entry(file1,"",tabA5[4,1:4])
latex.table.entry(file1,"\\hspace{.4cm}Inflation (yearly)",tabA5[5,1:4])
latex.table.entry(file1,"",tabA5[6,1:4])
latex.add.line(file1,"\\\\")
latex.table.entry(file1,"\\textbf{Number of Months}",tabA5[7,1:4])
latex.table.entry(file1,"\\textbf{Number of Newspapers}",tabA5[8,1:4])
latex.table.entry(file1,"\\textbf{Number of Countries}",tabA5[9,1:4])
latex.table.entry(file1,"\\textbf{R-Squared}",tabA5[10,1:4])
latex.add.line(file1,"\\hline \\hline")
latex.add.line(file1,"\\end{tabular}")
latex.add.line(file1,"\\end{footnotesize}")
latex.add.line(file1,"\\caption{\\footnotesize{The Effect of the Economy on Newspaper Coverage --- Newspaper fixed effects were included in each equation, but omitted from the table. Standard errors clustered by newspaper in parentheses. $^+ p<.10, ^{*} p<.05,  ^{**} p<.01, ^{***} p<.001$.}}")
latex.add.line(file1,"\\label{MultivariateCoverageReg}")
latex.add.line(file1,"\\end{table}")

# table A6
latex.add.line(file1,"\\begin{landscape}")
latex.add.line(file1,"\\begin{table}\\centering")
latex.add.line(file1,"\\begin{footnotesize}")
latex.add.line(file1,"\\begin{tabular}{ l c c c c c c} \\hline \\hline")
latex.add.line(file1,"\\textbf{Dependent Variable:} & Growth & Unemployment & Inflation & Growth & Unemployment & Inflation \\\\")
latex.add.line(file1," & Sentiment & Sentiment & Sentiment & Coverage & Coverage & Coverage \\\\")
latex.add.line(file1," & (cong. rec.) & (cong. rec.) & (cong. rec.)  & (cong. rec.) & (cong. rec.) & (cong. rec.) \\\\")
latex.add.line(file1,"\\\\")
latex.add.line(file1,"\\textbf{Independent Variables:}\\\\")
latex.table.entry(file1,"\\hspace{.4cm}Growth (yearly)",tabA6[1,])
latex.table.entry(file1,"",tabA6[2,])
latex.table.entry(file1,"\\hspace{.4cm}Unemployment (yearly)",tabA6[3,])
latex.table.entry(file1,"",tabA6[4,])
latex.table.entry(file1,"\\hspace{.4cm}Change in Unemployment (yearly)",tabA6[5,])
latex.table.entry(file1,"",tabA6[6,])
latex.table.entry(file1,"\\hspace{.4cm}Inflation (yearly)",tabA6[7,])
latex.table.entry(file1,"",tabA6[8,])
latex.table.entry(file1,"\\hspace{.4cm}Change in Inflation (yearly)",tabA6[9,])
latex.table.entry(file1,"",tabA6[10,])
latex.table.entry(file1,"\\hspace{.4cm}Ideological Match",tabA6[11,])
latex.table.entry(file1,"",tabA6[12,])
latex.table.entry(file1,"\\hspace{.4cm}Growth * Ideo. Match",tabA6[13,])
latex.table.entry(file1,"",tabA6[14,])
latex.table.entry(file1,"\\hspace{.4cm}Unem. * Ideo. Match",tabA6[15,])
latex.table.entry(file1,"",tabA6[16,])
latex.table.entry(file1,"\\hspace{.4cm}Change in Unem. * Ideo. Match",tabA6[17,])
latex.table.entry(file1,"",tabA6[18,])
latex.table.entry(file1,"\\hspace{.4cm}Inf. * Ideo. Match",tabA6[19,])
latex.table.entry(file1,"",tabA6[20,])
latex.table.entry(file1,"\\hspace{.4cm}Change in Inf. * Ideo. Match",tabA6[21,])
latex.table.entry(file1,"",tabA6[22,])
latex.add.line(file1,"\\\\")
latex.add.line(file1,"\\textbf{p-Value from Wald Test:}\\\\")
latex.table.entry(file1,"\\hspace{.4cm} Ideology Terms = 0",tabA6[25,])
latex.add.line(file1,"\\\\")
latex.table.entry(file1,"\\textbf{Number of Months}",tabA6[23,])
latex.table.entry(file1,"\\textbf{R-Squared}",tabA6[24,])
latex.add.line(file1,"\\hline \\hline")
latex.add.line(file1,"\\end{tabular}")
latex.add.line(file1,"\\end{footnotesize}")
latex.add.line(file1,"\\caption{\\footnotesize{Media Bias in Economic Sentiment in the Congressional Record --- Robust standard errors in parentheses. In all cases, the null hypothesis in the Wald test is that Ideological Match and it's interaction with the economy are jointly zero. $^+ p<.10, ^{*} p<.05,  ^{**} p<.01, ^{***} p<.001$.}}")
latex.add.line(file1,"\\label{SensitivityTable}")
latex.add.line(file1,"\\end{table}")
latex.add.line(file1,"\\end{landscape}\n\n\n")

# table A7
latex.add.line(file1,"\\begin{landscape}")
latex.add.line(file1,"\\begin{table}\\centering")
latex.add.line(file1,"\\begin{footnotesize}")
latex.add.line(file1,"\\begin{tabular}{ l c c c c c c} \\hline \\hline")
latex.add.line(file1,"\\textbf{Dependent Variable:} & Growth & Unemployment & Inflation & Growth & Unemployment & Inflation \\\\")
latex.add.line(file1," & Sentiment & Sentiment & Sentiment & Coverage & Coverage & Coverage \\\\")
latex.add.line(file1," & (articles) & (articles) & (articles)  & (articles) & (articles) & (articles) \\\\")
latex.add.line(file1,"\\\\")
latex.add.line(file1,"\\textbf{Independent Variables:}\\\\")
latex.table.entry(file1,"\\hspace{.4cm}Growth (yearly)",tabA7[1,])
latex.table.entry(file1,"",tabA7[2,])
latex.table.entry(file1,"\\hspace{.4cm}Unemployment (yearly)",tabA7[3,])
latex.table.entry(file1,"",tabA7[4,])
latex.table.entry(file1,"\\hspace{.4cm}Change in Unemployment (yearly)",tabA7[5,])
latex.table.entry(file1,"",tabA7[6,])
latex.table.entry(file1,"\\hspace{.4cm}Inflation (yearly)",tabA7[7,])
latex.table.entry(file1,"",tabA7[8,])
latex.table.entry(file1,"\\hspace{.4cm}Change in Inflation (yearly)",tabA7[9,])
latex.table.entry(file1,"",tabA7[10,])
latex.table.entry(file1,"\\hspace{.4cm}Ideological Match",tabA7[11,])
latex.table.entry(file1,"",tabA7[12,])
latex.table.entry(file1,"\\hspace{.4cm}Growth * Ideo. Match",tabA7[13,])
latex.table.entry(file1,"",tabA7[14,])
latex.table.entry(file1,"\\hspace{.4cm}Unem. * Ideo. Match",tabA7[15,])
latex.table.entry(file1,"",tabA7[16,])
latex.table.entry(file1,"\\hspace{.4cm}Change in Unem. * Ideo. Match",tabA7[17,])
latex.table.entry(file1,"",tabA7[18,])
latex.table.entry(file1,"\\hspace{.4cm}Inf. * Ideo. Match",tabA7[19,])
latex.table.entry(file1,"",tabA7[20,])
latex.table.entry(file1,"\\hspace{.4cm}Change in Inf. * Ideo. Match",tabA7[21,])
latex.table.entry(file1,"",tabA7[22,])
latex.add.line(file1,"\\\\")
latex.add.line(file1,"\\textbf{p-Value from Wald Test:}\\\\")
latex.table.entry(file1,"\\hspace{.4cm} Ideology Terms = 0",tabA7[27,])
latex.add.line(file1,"\\\\")
latex.table.entry(file1,"\\textbf{Number of Months}",tabA7[23,])
latex.table.entry(file1,"\\textbf{Number of Newspapers}",tabA7[24,])
latex.table.entry(file1,"\\textbf{Number of Countries}",tabA7[25,])
latex.table.entry(file1,"\\textbf{R-Squared}",tabA7[26,])
latex.add.line(file1,"\\hline \\hline")
latex.add.line(file1,"\\end{tabular}")
latex.add.line(file1,"\\end{footnotesize}")
latex.add.line(file1,"\\caption{\\footnotesize{Bias in Economic Sentiment and Coverage within Six Months of an Election --- Newspaper fixed effects were included in the analysis, but omitted from the table. Standard errors clustered by newspaper are in parentheses. In all cases, the null hypothesis in the Wald test is that Ideological Match and it's interaction with the economy are jointly zero. $^+ p<.10, ^{*} p<.05,  ^{**} p<.01, ^{***} p<.001$.}}")
latex.add.line(file1,"\\label{ElecIn6Table}")
latex.add.line(file1,"\\end{table}")
latex.add.line(file1,"\\end{landscape}\n\n\n")

# table A8
latex.add.line(file1,"\\begin{landscape}")
latex.add.line(file1,"\\begin{table}\\centering")
latex.add.line(file1,"\\begin{footnotesize}")
latex.add.line(file1,"\\begin{tabular}{ l c c c c c c} \\hline \\hline")
latex.add.line(file1,"\\textbf{Dependent Variable:} & Growth & Unemployment & Inflation & Growth & Unemployment & Inflation \\\\")
latex.add.line(file1," & Sentiment & Sentiment & Sentiment & Coverage & Coverage & Coverage \\\\")
latex.add.line(file1," & (articles) & (articles) & (articles)  & (articles) & (articles) & (articles) \\\\")
latex.add.line(file1,"\\\\")
latex.add.line(file1,"\\textbf{Independent Variables:}\\\\")
latex.table.entry(file1,"\\hspace{.4cm}Growth (yearly)",tabA8[1,])
latex.table.entry(file1,"",tabA8[2,])
latex.table.entry(file1,"\\hspace{.4cm}Unemployment (yearly)",tabA8[3,])
latex.table.entry(file1,"",tabA8[4,])
latex.table.entry(file1,"\\hspace{.4cm}Change in Unemployment (yearly)",tabA8[5,])
latex.table.entry(file1,"",tabA8[6,])
latex.table.entry(file1,"\\hspace{.4cm}Inflation (yearly)",tabA8[7,])
latex.table.entry(file1,"",tabA8[8,])
latex.table.entry(file1,"\\hspace{.4cm}Change in Inflation (yearly)",tabA8[9,])
latex.table.entry(file1,"",tabA8[10,])
latex.table.entry(file1,"\\hspace{.4cm}Ideological Match",tabA8[11,])
latex.table.entry(file1,"",tabA8[12,])
latex.table.entry(file1,"\\hspace{.4cm}Growth * Ideo. Match",tabA8[13,])
latex.table.entry(file1,"",tabA8[14,])
latex.table.entry(file1,"\\hspace{.4cm}Unem. * Ideo. Match",tabA8[15,])
latex.table.entry(file1,"",tabA8[16,])
latex.table.entry(file1,"\\hspace{.4cm}Change in Unem. * Ideo. Match",tabA8[17,])
latex.table.entry(file1,"",tabA8[18,])
latex.table.entry(file1,"\\hspace{.4cm}Inf. * Ideo. Match",tabA8[19,])
latex.table.entry(file1,"",tabA8[20,])
latex.table.entry(file1,"\\hspace{.4cm}Change in Inf. * Ideo. Match",tabA8[21,])
latex.table.entry(file1,"",tabA8[22,])
latex.add.line(file1,"\\\\")
latex.add.line(file1,"\\textbf{p-Value from Wald Test:}\\\\")
latex.table.entry(file1,"\\hspace{.4cm} Ideology Terms = 0",tabA8[27,])
latex.add.line(file1,"\\\\")
latex.table.entry(file1,"\\textbf{Number of Months}",tabA8[23,])
latex.table.entry(file1,"\\textbf{Number of Newspapers}",tabA8[24,])
latex.table.entry(file1,"\\textbf{Number of Countries}",tabA8[25,])
latex.table.entry(file1,"\\textbf{R-Squared}",tabA8[26,])
latex.add.line(file1,"\\hline \\hline")
latex.add.line(file1,"\\end{tabular}")
latex.add.line(file1,"\\end{footnotesize}")
latex.add.line(file1,"\\caption{\\footnotesize{Bias in Economic Sentiment and Coverage, Beginnings of Articles --- Newspaper fixed effects were included in the analysis, but omitted from the table. Standard errors clustered by newspaper are in parentheses. In all cases, the null hypothesis in the Wald test is that Ideological Match and it's interaction with the economy are jointly zero. $^+ p<.10, ^{*} p<.05,  ^{**} p<.01, ^{***} p<.001$.}}")
latex.add.line(file1,"\\label{BeginTable}")
latex.add.line(file1,"\\end{table}")
latex.add.line(file1,"\\end{landscape}\n\n\n")

# table A9
latex.add.line(file1,"\\begin{landscape}")
latex.add.line(file1,"\\begin{table}\\centering")
latex.add.line(file1,"\\begin{footnotesize}")
latex.add.line(file1,"\\begin{tabular}{ l c c c c c c} \\hline \\hline")
latex.add.line(file1,"\\textbf{Dependent Variable:} & Growth & Unemployment & Inflation & Growth & Unemployment & Inflation \\\\")
latex.add.line(file1," & Sentiment & Sentiment & Sentiment & Coverage & Coverage & Coverage \\\\")
latex.add.line(file1," & (articles) & (articles) & (articles)  & (articles) & (articles) & (articles) \\\\")
latex.add.line(file1,"\\\\")
latex.add.line(file1,"\\textbf{p-Value from Wald Test:}\\\\")
latex.add.line(file1,"\\hspace{.4cm} Interactions between Government \\\\")
latex.table.entry(file1,"\\hspace{.4cm}and Newspaper Ideology = 0 ",tabA9[,])
latex.add.line(file1,"\\hline \\hline")
latex.add.line(file1,"\\end{tabular}")
latex.add.line(file1,"\\end{footnotesize}")
latex.add.line(file1,"\\caption{\\footnotesize{Bias in Economic Sentiment and Coverage, Continuous Measures of Ideology --- Newspaper fixed effects were included in the analysis. Standard errors were clustered by newspaper. In all cases, the null hypothesis in the Wald test is that the coefficient on Newspaper Ideology * Government Ideology and it's interaction with the economy are jointly zero. $^+ p<.10, ^{*} p<.05,  ^{**} p<.01, ^{***} p<.001$.}}")
latex.add.line(file1,"\\label{ContTable}")
latex.add.line(file1,"\\end{table}")
latex.add.line(file1,"\\end{landscape}")

# table A11
latex.add.line(file1,"\\begin{landscape}")
latex.add.line(file1,"\\begin{table}\\centering")
latex.add.line(file1,"\\begin{footnotesize}")
latex.add.line(file1,"\\begin{tabular}{ l c c c c c c} \\hline \\hline")
latex.add.line(file1,"\\textbf{Dependent Variable:} & Growth & Unemployment & Inflation & Growth & Unemployment & Inflation \\\\")
latex.add.line(file1," & Sentiment & Sentiment & Sentiment & Coverage & Coverage & Coverage \\\\")
latex.add.line(file1," & (articles) & (articles) & (articles)  & (articles) & (articles) & (articles) \\\\")
latex.add.line(file1,"\\\\")
latex.add.line(file1,"\\textbf{p-Value from Wald Test:}\\\\")
latex.table.entry(file1,"\\hspace{.4cm}Ideology Terms = 0",tabA11[,])
latex.add.line(file1,"\\hline \\hline")
latex.add.line(file1,"\\end{tabular}")
latex.add.line(file1,"\\end{footnotesize}")
latex.add.line(file1,"\\caption{\\footnotesize{Bias in Economic Sentiment and Coverage, Left vs. Right-wing Papers --- Newspaper fixed effects were included in the analysis. Standard errors were clustered by newspaper. In all cases, the null hypothesis in the Wald test is that the coefficient on Ideological Match and it's interactions are jointly zero. $^+ p<.10, ^{*} p<.05,  ^{**} p<.01, ^{***} p<.001$.}}")
latex.add.line(file1,"\\label{BiasLRTable}")
latex.add.line(file1,"\\end{table}")
latex.add.line(file1,"\\end{landscape}")

if(win64)
{

# table A12
latex.add.line(file1,"\\begin{table}[htp]\\centering")
latex.add.line(file1,"\\begin{footnotesize}")
latex.add.line(file1,"\\begin{tabular}{ l c c c c} \\hline \\hline")
latex.add.line(file1,"\\textbf{Dependent Variable:} & Economic & Growth & Unemployment & Inflation \\\\	")
latex.add.line(file1," & Sentiment & Sentiment & Sentiment & Sentiment \\\\")
latex.add.line(file1," & (articles) & (articles) & (articles) & (articles) \\\\")
latex.add.line(file1,"\\\\		")
latex.add.line(file1,"\\textbf{Independent Variables:} \\\\")
latex.table.entry(file1,"\\hspace{.4cm}Constant",tabA12[1,])
latex.table.entry(file1,"",tabA12[2,])
latex.table.entry(file1,"\\hspace{.4cm}Growth (yearly)",tabA12[3,])
latex.table.entry(file1,paste("\\hspace{.4cm}(SD = ",dig3(sd_gr),")",sep=""),tabA12[4,])
latex.table.entry(file1,"\\hspace{.4cm}Change in Unem. (yearly)",tabA12[5,])
latex.table.entry(file1,paste("\\hspace{.4cm}(SD = ",dig3(sd_unch),")",sep=""),tabA12[6,])
latex.table.entry(file1,"\\hspace{.4cm}Change in Inf. (yearly)",tabA12[7,])
latex.table.entry(file1,paste("\\hspace{.4cm}(SD = ",dig3(sd_infch),")",sep=""),tabA12[8,])
latex.add.line(file1,"\\\\")
latex.table.entry(file1,"\\textbf{Number of Months}",tabA12[9,])
latex.table.entry(file1,"\\textbf{Number of Newspapers}",tabA12[10,])
latex.table.entry(file1,"\\textbf{Number of Countries}",tabA12[11,])
latex.table.entry(file1,"\\textbf{R-Squared}",tabA12[12,])
latex.add.line(file1,"\\hline \\hline")
latex.add.line(file1,"\\end{tabular}")
latex.add.line(file1,"\\end{footnotesize}")
latex.add.line(file1,"\\caption{\\footnotesize{The Effect of the Economy on Newspaper Sentiment (bootstrapped p-values) --- Newspaper fixed effects were included in each regression, but omitted from the table. Standard errors clustered by newspaper in parentheses. P-values were computed using the wild bootstrap. $^+ p<.10, ^{*} p<.05,  ^{**} p<.01, ^{***} p<.001$.}}")
latex.add.line(file1,"\\label{SentimentRegressionsBS}")
latex.add.line(file1,"\\end{table}\n\n\n")

# table A13
latex.add.line(file1,"\\begin{table}\\centering")
latex.add.line(file1,"\\begin{footnotesize}")
latex.add.line(file1,"\\begin{tabular}{ l c c c c } \\hline \\hline")
latex.add.line(file1,"\\textbf{Dependent Variable:} & Economic & Growth Share & Unemployment Share & Inflation Share \\\\")
latex.add.line(file1," & Coverage & of Coverage & of Coverage & of Coverage \\\\")
latex.add.line(file1," & (articles) & (articles) & (articles) & (articles) \\\\")
latex.add.line(file1,"\\\\")
latex.add.line(file1,"\\textbf{Independent Variables:}\\\\")
latex.table.entry(file1,"\\hspace{.4cm}Growth (yearly)",tabA13[1,1:4])
latex.table.entry(file1,"",tabA13[2,1:4])
latex.table.entry(file1,"\\hspace{.4cm}Unemployment (yearly)",tabA13[3,1:4])
latex.table.entry(file1,"",tabA13[4,1:4])
latex.table.entry(file1,"\\hspace{.4cm}Inflation (yearly)",tabA13[5,1:4])
latex.table.entry(file1,"",tabA13[6,1:4])
latex.add.line(file1,"\\\\")
latex.table.entry(file1,"\\textbf{Number of Months}",tabA13[7,1:4])
latex.table.entry(file1,"\\textbf{Number of Newspapers}",tabA13[8,1:4])
latex.table.entry(file1,"\\textbf{Number of Countries}",tabA13[9,1:4])
latex.table.entry(file1,"\\textbf{R-Squared}",tabA13[10,1:4])
latex.add.line(file1,"\\hline \\hline")
latex.add.line(file1,"\\end{tabular}")
latex.add.line(file1,"\\end{footnotesize}")
latex.add.line(file1,"\\caption{\\footnotesize{The Effect of the Economy on Newspaper Coverage (bootstrapped p-values) --- Newspaper fixed effects were included in each equation, but omitted from the table. Standard errors clustered by newspaper in parentheses. P-values were computed using the wild bootstrap. $^+ p<.10, ^{*} p<.05,  ^{**} p<.01, ^{***} p<.001$.}}")
latex.add.line(file1,"\\label{MultivariateCoverageRegBS}")
latex.add.line(file1,"\\end{table}")

# table A14
latex.add.line(file1,"\\begin{landscape}")
latex.add.line(file1,"\\begin{table}\\centering")
latex.add.line(file1,"\\begin{footnotesize}")
latex.add.line(file1,"\\begin{tabular}{ l c c c c c c} \\hline \\hline")
latex.add.line(file1,"\\textbf{Dependent Variable:} & Growth & Unemployment & Inflation & Growth & Unemployment & Inflation \\\\")
latex.add.line(file1," & Sentiment & Sentiment & Sentiment & Sentiment & Sentiment & Sentiment \\\\")
latex.add.line(file1," & (articles) & (articles) & (articles)  & (headlines) & (headlines) & (headlines) \\\\")
latex.add.line(file1,"\\\\")
latex.add.line(file1,"\\textbf{Independent Variables:}\\\\")
latex.table.entry(file1,"\\hspace{.4cm}Growth (yearly)",tabA14[1,])
latex.table.entry(file1,"",tabA14[2,])
latex.table.entry(file1,"\\hspace{.4cm}Change in Unemployment (yearly)",tabA14[3,])
latex.table.entry(file1,"",tabA14[4,])
latex.table.entry(file1,"\\hspace{.4cm}Change in Inflation (yearly)",tabA14[5,])
latex.table.entry(file1,"",tabA14[6,])
latex.table.entry(file1,"\\hspace{.4cm}Ideological Match",tabA14[7,])
latex.table.entry(file1,"",tabA14[8,])
latex.table.entry(file1,"\\hspace{.4cm}Growth * Ideo. Match",tabA14[9,])
latex.table.entry(file1,"",tabA14[10,])
latex.table.entry(file1,"\\hspace{.4cm}Change in Unem. * Ideo. Match",tabA14[11,])
latex.table.entry(file1,"",tabA14[12,])
latex.table.entry(file1,"\\hspace{.4cm}Change in Inf. * Ideo. Match",tabA14[13,])
latex.table.entry(file1,"",tabA14[14,])
latex.add.line(file1,"\\\\")
latex.add.line(file1,"\\textbf{p-Value from Wald Test:}\\\\")
latex.table.entry(file1,"\\hspace{.4cm} Ideology Terms = 0",tabA14[19,])
latex.add.line(file1,"\\\\")
latex.table.entry(file1,"\\textbf{Number of Months}",tabA14[15,])
latex.table.entry(file1,"\\textbf{Number of Newspapers}",tabA14[16,])
latex.table.entry(file1,"\\textbf{Number of Countries}",tabA14[17,])
latex.table.entry(file1,"\\textbf{R-Squared}",tabA14[18,])
latex.add.line(file1,"\\hline \\hline")
latex.add.line(file1,"\\end{tabular}")
latex.add.line(file1,"\\end{footnotesize}")
latex.add.line(file1,"\\caption{Media Bias in Sentiment (bootstrapped p-values) --- Newspaper fixed effects were included in the analysis, but omitted from the table. Standard errors clustered by newspaper in parentheses. P-values were computed using the wild bootstrap. In all cases, the null hypothesis in the Wald test is that Ideological Match and it's interactions with the economy are jointly zero. $^+ p<.10, ^{*} p<.05,  ^{**} p<.01, ^{***} p<.001$.}")
latex.add.line(file1,"\\label{ToneBiasTableBS}")
latex.add.line(file1,"\\end{table}")
latex.add.line(file1,"\\end{landscape}\n\n\n")

# table A15
latex.add.line(file1,"\\begin{landscape}")
latex.add.line(file1,"\\begin{table}\\centering")
latex.add.line(file1,"\\begin{footnotesize}")
latex.add.line(file1,"\\begin{tabular}{ l c c c c c c} \\hline \\hline")
latex.add.line(file1,"\\textbf{Dependent Variable:} & Growth & Unemployment & Inflation & Growth & Unemployment & Inflation \\\\")
latex.add.line(file1," & Coverage & Coverage & Coverage& Coverage & Coverage & Coverage  \\\\")
latex.add.line(file1," & (articles) & (articles) & (articles)  & (headlines) & (headlines) & (headlines) \\\\")
latex.add.line(file1,"\\\\")
latex.add.line(file1,"\\textbf{Independent Variables:}\\\\")
latex.table.entry(file1,"\\hspace{.4cm}Growth (yearly)",tabA15[1,])
latex.table.entry(file1,"",tabA15[2,])
latex.table.entry(file1,"\\hspace{.4cm}Unemployment (yearly)",tabA15[3,])
latex.table.entry(file1,"",tabA15[4,])
latex.table.entry(file1,"\\hspace{.4cm}Inflation (yearly)",tabA15[5,])
latex.table.entry(file1,"",tabA15[6,])
latex.table.entry(file1,"\\hspace{.4cm}Ideological Match",tabA15[7,])
latex.table.entry(file1,"",tabA15[8,])
latex.table.entry(file1,"\\hspace{.4cm}Growth * Ideo. Match",tabA15[9,])
latex.table.entry(file1,"",tabA15[10,])
latex.table.entry(file1,"\\hspace{.4cm}Unem. * Ideo. Match",tabA15[11,])
latex.table.entry(file1,"",tabA15[12,])
latex.table.entry(file1,"\\hspace{.4cm}Inf. * Ideo. Match",tabA15[13,])
latex.table.entry(file1,"",tabA15[14,])
latex.add.line(file1,"\\\\")
latex.add.line(file1,"\\textbf{p-Value from Wald Test:}\\\\")
latex.table.entry(file1,"\\hspace{.4cm} Ideology Terms = 0",tabA15[19,])
latex.add.line(file1,"\\\\")
latex.table.entry(file1,"\\textbf{Number of Months}",tabA15[15,])
latex.table.entry(file1,"\\textbf{Number of Newspapers}",tabA15[16,])
latex.table.entry(file1,"\\textbf{Number of Countries}",tabA15[17,])
latex.table.entry(file1,"\\textbf{R-Squared}",tabA15[18,])
latex.add.line(file1,"\\hline \\hline")
latex.add.line(file1,"\\end{tabular}")
latex.add.line(file1,"\\end{footnotesize}")
latex.add.line(file1,"\\caption{Media Bias in Coverage (bootstrapped p-values) --- Newspaper fixed effects were included in the analysis, but omitted from the table. Standard errors clustered by newspaper in parentheses. P-values were computed using the wild bootstrap. In all cases, the null hypothesis in the Wald test is that Ideological Match and it's interaction with the economy are jointly zero. $^+ p<.10, ^{*} p<.05,  ^{**} p<.01, ^{***} p<.001$.}")
latex.add.line(file1,"\\label{CoverageBiasTableBS}")
latex.add.line(file1,"\\end{table}")
latex.add.line(file1,"\\end{landscape}\n\n\n")

}

# table A16
latex.add.line(file1,"\\begin{landscape}")
latex.add.line(file1,"\\begin{table}\\centering")
latex.add.line(file1,"\\begin{footnotesize}")
latex.add.line(file1,"\\begin{tabular}{ l c c c c c c} \\hline \\hline")
latex.add.line(file1,"\\textbf{Dependent Variable:} & Growth & Unemployment & Inflation & Growth & Unemployment & Inflation \\\\")
latex.add.line(file1," & Sentiment & Sentiment & Sentiment & Coverage & Coverage & Coverage \\\\")
latex.add.line(file1," & (articles) & (articles) & (articles)  & (articles) & (articles) & (articles) \\\\")
latex.add.line(file1,"\\\\")
latex.add.line(file1,"\\textbf{Independent Variables:}\\\\")
latex.table.entry(file1,"\\hspace{.4cm}Growth (yearly)",tabA16[1,])
latex.table.entry(file1,"",tabA16[2,])
latex.table.entry(file1,"\\hspace{.4cm}Unemployment (yearly)",tabA16[3,])
latex.table.entry(file1,"",tabA16[4,])
latex.table.entry(file1,"\\hspace{.4cm}Change in Unemployment (yearly)",tabA16[5,])
latex.table.entry(file1,"",tabA16[6,])
latex.table.entry(file1,"\\hspace{.4cm}Inflation (yearly)",tabA16[7,])
latex.table.entry(file1,"",tabA16[8,])
latex.table.entry(file1,"\\hspace{.4cm}Change in Inflation (yearly)",tabA16[9,])
latex.table.entry(file1,"",tabA16[10,])
latex.table.entry(file1,"\\hspace{.4cm}Ideological Match",tabA16[11,])
latex.table.entry(file1,"",tabA16[12,])
latex.table.entry(file1,"\\hspace{.4cm}Growth * Ideo. Match",tabA16[13,])
latex.table.entry(file1,"",tabA16[14,])
latex.table.entry(file1,"\\hspace{.4cm}Unem. * Ideo. Match",tabA16[15,])
latex.table.entry(file1,"",tabA16[16,])
latex.table.entry(file1,"\\hspace{.4cm}Change in Unem. * Ideo. Match",tabA16[17,])
latex.table.entry(file1,"",tabA16[18,])
latex.table.entry(file1,"\\hspace{.4cm}Inf. * Ideo. Match",tabA16[19,])
latex.table.entry(file1,"",tabA16[20,])
latex.table.entry(file1,"\\hspace{.4cm}Change in Inf. * Ideo. Match",tabA16[21,])
latex.table.entry(file1,"",tabA16[22,])
latex.add.line(file1,"\\\\")
latex.add.line(file1,"\\textbf{p-Value from Wald Test:}\\\\")
latex.table.entry(file1,"\\hspace{.4cm} Ideology Terms = 0",tabA16[26,])
latex.add.line(file1,"\\\\")
latex.table.entry(file1,"\\textbf{Number of Months}",tabA16[23,])
latex.table.entry(file1,"\\textbf{Number of Newspapers}",tabA16[24,])
latex.table.entry(file1,"\\textbf{Number of Countries}",tabA16[25,])
latex.add.line(file1,"\\hline \\hline")
latex.add.line(file1,"\\end{tabular}")
latex.add.line(file1,"\\end{footnotesize}")
latex.add.line(file1,"\\caption{\\footnotesize{Bias in Human-coded Sentiment and Coverage --- Newspaper fixed effects were included in the analysis, but omitted from the table. Standard errors clustered by newspaper are in parentheses. In all cases, the null hypothesis in the Wald test is that Ideological Match and it's interaction with the economy are jointly zero. $^+ p<.10, ^{*} p<.05,  ^{**} p<.01, ^{***} p<.001$.}}")
latex.add.line(file1,"\\label{HCBiasTable}")
latex.add.line(file1,"\\end{table}")
latex.add.line(file1,"\\end{landscape}\n\n\n")

latex.doc.end(file1)

# create the figures

# figure 1
idxs <- 1:length(leadrightconst)
begins <- list()
ends <- list()
govtype <- list()
for(i in 1:16)
{
	temp <- subset(leadrightconst,newsid==2*i)
	for(j in 1:844)
	{
		if(is.na(temp[j])) {
			temp[j] <- 2
		}
	}
	begins[[i]] <- list()
	ends[[i]] <- list()
	govtype[[i]] <- list()
	begins[[i]][[1]] <- 1
	govtype[[i]][[1]] <- temp[1]
	curr <- 2	
	for(j in 2:844)
	{
		if(temp[j] != temp[j-1]) {
			begins[[i]][[curr]] <- j
			govtype[[i]][[curr]] <- temp[j]
			ends[[i]][[curr-1]] <- j-1
			curr <- curr + 1
		}
	}
	ends[[i]][[curr-1]] <- 844
}
par(oma=c(0,0,3,0))
par(mar=c(2,2,2,2))
par(mfrow=c(4,4))
for(i in 1:16)
{
	leftnews <- 2 * i - 1
	rightnews <- 2 * i
	minfrac <- min(subset(econ_frac_pos,newsid==leftnews|newsid==rightnews),na.rm=TRUE)
	maxfrac <- max(subset(econ_frac_pos,newsid==leftnews|newsid==rightnews),na.rm=TRUE)
	minmonth <- max(min(subset(monthid,newsid==leftnews&!is.na(econ_frac_pos))),min(subset(monthid,newsid==rightnews&!is.na(econ_frac_pos))))
	maxmonth <- min(max(subset(monthid,newsid==leftnews&!is.na(econ_frac_pos))),max(subset(monthid,newsid==rightnews&!is.na(econ_frac_pos))))
	diffmonth <- ceiling(.2 * (maxmonth - minmonth))
	at1 <- c(minmonth,minmonth+diffmonth,minmonth+2*diffmonth,minmonth+3*diffmonth,minmonth+4*diffmonth,minmonth+5*diffmonth)
	labels1 <- monthyear[at1]
	plot(0:1,type='n',ylim=c(minfrac-0.03,maxfrac+0.03),xlim=c(minmonth,maxmonth),ylab='Econ. Sent.',xlab='Date',main=countries[i],at=at1,labels=labels1,cex.axis=0.8)
	points(subset(monthid,newsid==leftnews),subset(econ_frac_pos,newsid==leftnews),type='l',col='red')
	points(subset(monthid,newsid==rightnews),subset(econ_frac_pos,newsid==rightnews),type='l',col='blue')
	for(j in 1:length(begins[[i]]))
	{
		if(govtype[[i]][[j]]==1) {
			polygon(c(begins[[i]][[j]]-.5,begins[[i]][[j]]-.5,ends[[i]][[j]]+.5,ends[[i]][[j]]+.5),c(-100,100,100,-100),col=make.transparent("blue",alpha=25),border=NA)
		} else if(govtype[[i]][[j]]==0) {
			polygon(c(begins[[i]][[j]]-.5,begins[[i]][[j]]-.5,ends[[i]][[j]]+.5,ends[[i]][[j]]+.5),c(-100,100,100,-100),col=make.transparent("red",alpha=25),border=NA)

		}
	}
}

# figure 2
x11()
par(mfrow=c(2,3))

cl1 <- cluster0(lm(gr_frac_pos  ~ gr_yr + ideomatch + gr_yr_ideomatch + factor(newsid)),newsid)
const1 <- cl1$coef[1] + sum(cl1$coef[5:35])*0.03125
gr_low <- quantile0(gr_yr,.02)
gr_high <- quantile0(gr_yr,.98)
gr_points <- seq(from=gr_low,to=gr_high,length.out=101)
unmatched1 <- const1 + cl1$coef[2] * gr_points
matched1 <- const1 + cl1$coef[3] + (cl1$coef[2] + cl1$coef[4]) * gr_points
plot(gr_points,matched1,col='purple',type='l',xlab="Growth",ylab="Growth Sentiment",ylim=c(.2,.8))
points(gr_points,unmatched1,col='orange',type='l',lty=2)
legend("top",c("Matched Ideo.","Unmatched Ideo."),col=c('purple','orange'),lty=c(1,2),bty='n')

cl2 <- cluster0(lm(un_frac_pos  ~ gr_yr + unch_yr  + ideomatch + gr_yr_ideomatch + unch_yr_ideomatch  + factor(newsid)),newsid)
const2 <- cl2$coef[1] + sum(cl2$coef[7:37])*0.03125
un_ch_low <- quantile0(unch_yr,.02)
un_ch_high <- quantile0(unch_yr,.98)
un_ch_points <- seq(from=un_ch_low,to=un_ch_high,length.out=101)
unmatched2 <- const2 + cl2$coef[2] * mean(gr_yr,na.rm=TRUE) + cl2$coef[3]*un_ch_points
matched2 <- const2 + cl2$coef[4] + (cl2$coef[2] + cl2$coef[5]) * mean(gr_yr,na.rm=TRUE) + (cl2$coef[3] + cl2$coef[6]) * un_ch_points
plot(un_ch_points,matched2,col='purple',type='l',xlab="Change in Unemployment",ylab="Unemployment Sentiment",ylim=c(.2,.8),main="Sentiment in Articles")
points(un_ch_points,unmatched2,col='orange',type='l',lty=2)

cl3 <- cluster0(lm(inf_frac_pos ~ gr_yr + infch_yr + ideomatch + gr_yr_ideomatch + infch_yr_ideomatch + factor(newsid)),newsid)
const3 <- cl3$coef[1] + sum(cl3$coef[7:37])*0.03125
inf_ch_low <- quantile(infch_yr,c(.02,.98),na.rm=TRUE)[1]
inf_ch_high <- quantile(infch_yr,c(.02,.98),na.rm=TRUE)[2]
inf_ch_points <- seq(from=inf_ch_low,to=inf_ch_high,length.out=101)
unmatched3 <- const3 + cl3$coef[2] * mean(gr_yr,na.rm=TRUE) + cl3$coef[3]*inf_ch_points
matched3 <- const3 + cl3$coef[4] + (cl3$coef[2] + cl3$coef[5]) * mean(gr_yr,na.rm=TRUE) + (cl3$coef[3] + cl3$coef[6]) * inf_ch_points
plot(inf_ch_points,matched3,col='purple',type='l',xlab="Change in Inflation",ylab="Inflation Sentiment",ylim=c(.2,.8))
points(inf_ch_points,unmatched3,col='orange',type='l',lty=2)

cl1 <- cluster0(lm(gr_frac_pos_hl  ~ gr_yr              + ideomatch + gr_yr_ideomatch                        + factor(newsid)),newsid)
const1 <- cl1$coef[1] + sum(cl1$coef[5:34])*(1/31)
gr_low <- quantile(gr_yr,c(.02,.98),na.rm=TRUE)[1]
gr_high <- quantile(gr_yr,c(.02,.98),na.rm=TRUE)[2]
gr_points <- seq(from=gr_low,to=gr_high,length.out=101)
unmatched1 <- const1 + cl1$coef[2] * gr_points
matched1 <- const1 + cl1$coef[3] + (cl1$coef[2] + cl1$coef[4]) * gr_points
plot(gr_points,matched1,col='purple',type='l',xlab="Growth",ylab="Growth Sentiment",ylim=c(.2,.8))
points(gr_points,unmatched1,col='orange',type='l',lty=2)

cl2 <- cluster0(lm(un_frac_pos_hl  ~ gr_yr + unch_yr  + ideomatch + gr_yr_ideomatch + unch_yr_ideomatch  + factor(newsid)),newsid)
const2 <- cl2$coef[1] + sum(cl2$coef[7:36])*(1/31)
un_ch_low <- quantile(unch_yr,c(.02,.98),na.rm=TRUE)[1]
un_ch_high <- quantile(unch_yr,c(.02,.98),na.rm=TRUE)[2]
un_ch_points <- seq(from=un_ch_low,to=un_ch_high,length.out=101)
unmatched2 <- const2 + cl2$coef[2] * mean(gr_yr,na.rm=TRUE) + cl2$coef[3]*un_ch_points
matched2 <- const2 + cl2$coef[4] + (cl2$coef[2] + cl2$coef[5]) * mean(gr_yr,na.rm=TRUE) + (cl2$coef[3] + cl2$coef[6]) * un_ch_points
plot(un_ch_points,matched2,col='purple',type='l',xlab="Change in Unemployment",ylab="Unemployment Sentiment",ylim=c(.2,.8),main="Sentiment in Headlines")
points(un_ch_points,unmatched2,col='orange',type='l',lty=2)

cl3 <- cluster0(lm(inf_frac_pos_hl ~ gr_yr + infch_yr + ideomatch + gr_yr_ideomatch + infch_yr_ideomatch + factor(newsid)),newsid)
const3 <- cl3$coef[1] + sum(cl3$coef[7:36])*(1/31)
inf_ch_low <- quantile(infch_yr,c(.02,.98),na.rm=TRUE)[1]
inf_ch_high <- quantile(infch_yr,c(.02,.98),na.rm=TRUE)[2]
inf_ch_points <- seq(from=inf_ch_low,to=inf_ch_high,length.out=101)
unmatched3 <- const3 + cl3$coef[2] * mean(gr_yr,na.rm=TRUE) + cl3$coef[3]*inf_ch_points
matched3 <- const3 + cl3$coef[4] + (cl3$coef[2] + cl3$coef[5]) * mean(gr_yr,na.rm=TRUE) + (cl3$coef[3] + cl3$coef[6]) * inf_ch_points
plot(inf_ch_points,matched3,col='purple',type='l',xlab="Change in Inflation",ylab="Inflation Sentiment",ylim=c(.2,.8))
points(inf_ch_points,unmatched3,col='orange',type='l',lty=2)

# figure 3
x11()
par(mfrow=c(2,3))

cl1 <- cluster0(lm(gr_sh ~ gr_yr + ideomatch + gr_yr_ideomatch + factor(newsid)),newsid)
const1 <- cl1$coef[1] + sum(cl1$coef[5:35])*0.03125
gr_low <- quantile(gr_yr,c(.02,.98),na.rm=TRUE)[1]
gr_high <- quantile(gr_yr,c(.02,.98),na.rm=TRUE)[2]
gr_points <- seq(from=gr_low,to=gr_high,length.out=101)
unmatched1 <- const1 + cl1$coef[2] * gr_points
matched1 <- const1 + cl1$coef[3] + (cl1$coef[2] + cl1$coef[4]) * gr_points
plot(gr_points,matched1,col='purple',type='l',ylim=c(.1,.7),xlab = "Growth",ylab="Growth Share of Coverage")
points(gr_points,unmatched1,col='orange',type='l',lty=2)
legend("top",c("Matched Ideo.","Unmatched Ideo."),col=c('purple','orange'),lty=c(1,2),bty='n')

cl1 <- cluster0(lm(un_sh ~ un_yr + ideomatch + un_yr_ideomatch + factor(newsid)),newsid)
const1 <- cl1$coef[1] + sum(cl1$coef[5:35])*0.03125
gr_low <- quantile(un_yr,c(.02,.98),na.rm=TRUE)[1]
gr_high <- quantile(un_yr,c(.02,.98),na.rm=TRUE)[2]
gr_points <- seq(from=gr_low,to=gr_high,length.out=101)
unmatched1 <- const1 + cl1$coef[2] * gr_points
matched1 <- const1 + cl1$coef[3] + (cl1$coef[2] + cl1$coef[4]) * gr_points
plot(gr_points,matched1,col='purple',type='l',ylim=c(.1,.7),xlab = "Unemployment",main="Share of Coverage in Articles",ylab="Unemployment Share of Coverage")
points(gr_points,unmatched1,col='orange',type='l',lty=2)

cl1 <- cluster0(lm(inf_sh ~ inf_yr + ideomatch + inf_yr_ideomatch + factor(newsid)),newsid)
const1 <- cl1$coef[1] + sum(cl1$coef[5:35])*0.03125
gr_low <- quantile(inf_yr,c(.02,.98),na.rm=TRUE)[1]
gr_high <- quantile(inf_yr,c(.02,.98),na.rm=TRUE)[2]
gr_points <- seq(from=gr_low,to=gr_high,length.out=101)
unmatched1 <- const1 + cl1$coef[2] * gr_points
matched1 <- const1 + cl1$coef[3] + (cl1$coef[2] + cl1$coef[4]) * gr_points
plot(gr_points,matched1,col='purple',type='l',ylim=c(.1,.7),xlab = "Inflation",,ylab="Inflation Share of Coverage")
points(gr_points,unmatched1,col='orange',type='l',lty=2)

cl1 <- cluster0(lm(gr_sh_hl ~ gr_yr + ideomatch + gr_yr_ideomatch + factor(newsid)),newsid)
const1 <- cl1$coef[1] + sum(cl1$coef[5:34])*(1/31)
gr_low <- quantile(gr_yr,c(.02,.98),na.rm=TRUE)[1]
gr_high <- quantile(gr_yr,c(.02,.98),na.rm=TRUE)[2]
gr_points <- seq(from=gr_low,to=gr_high,length.out=101)
unmatched1 <- const1 + cl1$coef[2] * gr_points
matched1 <- const1 + cl1$coef[3] + (cl1$coef[2] + cl1$coef[4]) * gr_points
plot(gr_points,matched1,col='purple',type='l',ylim=c(.1,.7),xlab = "Growth",,ylab="Growth Share of Coverage")
points(gr_points,unmatched1,col='orange',type='l',lty=2)

cl1 <- cluster0(lm(un_sh_hl ~ un_yr + ideomatch + un_yr_ideomatch + factor(newsid)),newsid)
const1 <- cl1$coef[1] + sum(cl1$coef[5:34])*(1/31)
gr_low <- quantile(un_yr,c(.02,.98),na.rm=TRUE)[1]
gr_high <- quantile(un_yr,c(.02,.98),na.rm=TRUE)[2]
gr_points <- seq(from=gr_low,to=gr_high,length.out=101)
unmatched1 <- const1 + cl1$coef[2] * gr_points
matched1 <- const1 + cl1$coef[3] + (cl1$coef[2] + cl1$coef[4]) * gr_points
plot(gr_points,matched1,col='purple',type='l',ylim=c(.1,.7),xlab = "Unemployment",main="Share of Coverage in Headlines",ylab="Unemployment Share of Coverage")
points(gr_points,unmatched1,col='orange',type='l',lty=2)

cl1 <- cluster0(lm(inf_sh_hl ~ inf_yr + ideomatch + inf_yr_ideomatch + factor(newsid)),newsid)
const1 <- cl1$coef[1] + sum(cl1$coef[5:34])*(1/31)
gr_low <- quantile(inf_yr,c(.02,.98),na.rm=TRUE)[1]
gr_high <- quantile(inf_yr,c(.02,.98),na.rm=TRUE)[2]
gr_points <- seq(from=gr_low,to=gr_high,length.out=101)
unmatched1 <- const1 + cl1$coef[2] * gr_points
matched1 <- const1 + cl1$coef[3] + (cl1$coef[2] + cl1$coef[4]) * gr_points
plot(gr_points,matched1,col='purple',type='l',ylim=c(.1,.7),xlab = "Inflation",,ylab="Inflation Share of Coverage")
points(gr_points,unmatched1,col='orange',type='l',lty=2)

# figure A1
SigmaPLhat <- 0.327323
SigmaPMhat <- 0.00564533
SigmaPDhat <- 0.0317776
Ls <- c(25,50,100,200,400,800,1600,3200)
errs <- rep(NA,length(Ls))
for(i in 1:length(Ls)) errs[i] <- ((1/Ls[i])*SigmaPLhat^2+1/(30*Ls[i])*SigmaPDhat^2+SigmaPMhat^2)^.5
Ls2 <- c(0,(Ls[1:(length(Ls)-1)] + Ls[2:length(Ls)]) / 2,100000)
counts <- rep(NA,length(Ls))
for(i in 1:length(Ls)) counts[i] <- sum0(articles >= Ls2[i] & articles <= Ls2[i+1]) / 30000
x11()
plot(0:1,type='n',xlab="Articles per Month",ylab="Measurement Error St. Dev.",xaxt='n',xlim=c(.5,length(Ls)+.5),ylim=c(0,.08))
for(i in 1:length(Ls)) polygon(c(i-.25,i+.25,i+.25,i-.25),c(0,0,counts[i],counts[i]),col='magenta')
points(1:length(Ls),errs)
points(1:length(Ls),errs,type='l')
axis(side=1,at=1:length(Ls),labels=Ls)

# figure A2
x11()
par(mfrow=c(2,3))

lm1 <- lm0(cong_gr_frac_pos ~ gr_yr + ideomatch + gr_yr_ideomatch)
const1 <- lm1$coef[1]
gr_low <- quantile0(gr_yr,.02,subset=!is.na(cong_econ_frac_pos))
gr_high <- quantile0(gr_yr,.98,subset=!is.na(cong_econ_frac_pos))
gr_points <- seq(from=gr_low,to=gr_high,length.out=101)
unmatched1 <- const1 + lm1$coef[2] * gr_points
matched1 <- const1 + lm1$coef[3] + (lm1$coef[2] + lm1$coef[4]) * gr_points
plot(gr_points,matched1,col='purple',type='l',xlab="Growth",ylab="Growth Sentiment",ylim=c(.5,.7))
points(gr_points,unmatched1,col='orange',type='l',lty=2)
legend("top",c("Matched Ideo.","Unmatched Ideo."),col=c('purple','orange'),lty=c(1,2),bty='n')

lm1 <- lm0(cong_un_frac_pos ~ gr_yr + unch_yr + ideomatch + gr_yr_ideomatch + unch_yr_ideomatch)
const1 <- lm1$coef[1]
un_ch_low <- quantile0(unch_yr,.02,subset=!is.na(cong_econ_frac_pos))
un_ch_high <- quantile0(unch_yr,.98,subset=!is.na(cong_econ_frac_pos))
un_ch_points <- seq(from=un_ch_low,to=un_ch_high,length.out=101)
unmatched1 <- const1 + lm1$coef[2] * mean0(gr_yr,subset=!is.na(cong_econ_frac_pos)) + lm1$coef[3]*un_ch_points
matched1 <- const1 + lm1$coef[4] + (lm1$coef[2] + lm1$coef[5]) * mean0(gr_yr,subset=!is.na(cong_econ_frac_pos)) + (lm1$coef[3] + lm1$coef[6]) * un_ch_points
plot(un_ch_points,matched1,col='purple',type='l',xlab="Change in Unemployment",ylab="Unemployment Sentiment",ylim=c(.5,.7),main="Sentiment")
points(un_ch_points,unmatched1,col='orange',type='l',lty=2)

lm1 <- lm0(cong_inf_frac_pos ~ gr_yr + infch_yr + ideomatch + gr_yr_ideomatch + infch_yr_ideomatch)
const1 <- lm1$coef[1]
inf_ch_low <- quantile0(infch_yr,.02,subset=!is.na(cong_econ_frac_pos))
inf_ch_high <- quantile0(infch_yr,.98,subset=!is.na(cong_econ_frac_pos))
inf_ch_points <- seq(from=inf_ch_low,to=inf_ch_high,length.out=101)
unmatched1 <- const1 + lm1$coef[2] * mean0(gr_yr,subset=!is.na(cong_econ_frac_pos)) + lm1$coef[3]*inf_ch_points
matched1 <- const1 + lm1$coef[4] + (lm1$coef[2] + lm1$coef[5]) * mean0(gr_yr,subset=!is.na(cong_econ_frac_pos)) + (lm1$coef[3] + lm1$coef[6]) * inf_ch_points
plot(inf_ch_points,matched1,col='purple',type='l',xlab="Change in Inflation",ylab="Inflation Sentiment",ylim=c(.5,.7))
points(inf_ch_points,unmatched1,col='orange',type='l',lty=2)

lm1 <- lm0(cong_gr_sh ~ gr_yr + ideomatch + gr_yr_ideomatch)
const1 <- lm1$coef[1]
gr_low <- quantile0(gr_yr,.02,subset=!is.na(cong_econ_frac_pos))
gr_high <- quantile0(gr_yr,.98,subset=!is.na(cong_econ_frac_pos))
gr_points <- seq(from=gr_low,to=gr_high,length.out=101)
unmatched1 <- const1 + lm1$coef[2] * gr_points
matched1 <- const1 + lm1$coef[3] + (lm1$coef[2] + lm1$coef[4]) * gr_points
plot(gr_points,matched1,col='purple',type='l',xlab="Growth",ylab="Growth Converage",ylim=c(.1,.9))
points(gr_points,unmatched1,col='orange',type='l',lty=2)

lm1 <- lm0(cong_un_sh ~ un_yr + ideomatch + un_yr_ideomatch)
const1 <- lm1$coef[1]
un_low <- quantile0(un_yr,.02,subset=!is.na(cong_econ_frac_pos))
un_high <- quantile0(un_yr,.98,subset=!is.na(cong_econ_frac_pos))
un_points <- seq(from=un_low,to=un_high,length.out=101)
unmatched1 <- const1 + lm1$coef[2] * un_points
matched1 <- const1 + lm1$coef[3] + (lm1$coef[2] + lm1$coef[4]) * un_points
plot(un_points,matched1,col='purple',type='l',xlab="Unemployment",ylab="Unemployment Converage",ylim=c(.1,.9),main="Share of Speech")
points(un_points,unmatched1,col='orange',type='l',lty=2)

lm1 <- lm0(cong_inf_sh ~ inf_yr + ideomatch + inf_yr_ideomatch)
const1 <- lm1$coef[1]
inf_low <- quantile0(inf_yr,.02,subset=!is.na(cong_econ_frac_pos))
inf_high <- quantile0(inf_yr,.98,subset=!is.na(cong_econ_frac_pos))
inf_points <- seq(from=inf_low,to=inf_high,length.out=101)
unmatched1 <- const1 + lm1$coef[2] * inf_points
matched1 <- const1 + lm1$coef[3] + (lm1$coef[2] + lm1$coef[4]) * inf_points
plot(inf_points,matched1,col='purple',type='l',xlab="Inflation",ylab="Inflation Converage",ylim=c(.1,.9))
points(inf_points,unmatched1,col='orange',type='l',lty=2)

# figure A3
x11()
par(mfrow=c(2,3))

# gr sent
lm1 <- lm0(gr_frac_pos ~ gr_yr + ideomatch + gr_yr_ideomatch + factor(newsid),subset=newsid<=32&elecin6==1,se="cluster",unitid=newsid)
const1 <- lm1$coef[1] + median0(c(0,lm1$coef[5:34]))
gr_low <- quantile0(gr_yr,.02,subset=newsid<=32)
gr_high <- quantile0(gr_yr,.98,subset=newsid<=32)
gr_points <- seq(from=gr_low,to=gr_high,length.out=101)
unmatched1 <- const1 + lm1$coef[2] * gr_points
matched1 <- const1 + lm1$coef[3] + (lm1$coef[2] + lm1$coef[4]) * gr_points
plot(gr_points,matched1,col='purple',type='l',xlab="Growth",ylab="Growth Sentiment",ylim=c(.2,.8))
points(gr_points,unmatched1,col='orange',type='l')
legend("top",c("Matched Ideo.","Unmatched Ideo."),col=c('purple','orange'),lty=c(1,1),bty='n')

# un sent
lm1 <- lm0(un_frac_pos ~ gr_yr + unch_yr + ideomatch + gr_yr_ideomatch + unch_yr_ideomatch + factor(newsid),subset=newsid<=32&elecin6==1,se="cluster",unitid=newsid)
const1 <- lm1$coef[1] + median0(c(0,lm1$coef[7:36]))
un_ch_low <- quantile0(unch_yr,.02,subset=newsid<=32)
un_ch_high <- quantile0(unch_yr,.98,subset=newsid<=32)
un_ch_points <- seq(from=un_ch_low,to=un_ch_high,length.out=101)
unmatched1 <- const1 + lm1$coef[2] * mean0(gr_yr,subset=newsid<=32) + lm1$coef[3]*un_ch_points
matched1 <- const1 + lm1$coef[4] + (lm1$coef[2] + lm1$coef[5]) * mean0(gr_yr,newsid<=32) + (lm1$coef[3] + lm1$coef[6]) * un_ch_points
plot(un_ch_points,matched1,col='purple',type='l',xlab="Change in Unemployment",ylab="Unemployment Sentiment",ylim=c(.2,.8),main="Sentiment")
points(un_ch_points,unmatched1,col='orange',type='l')

# inf sent
lm1 <- lm0(inf_frac_pos ~ gr_yr + infch_yr + ideomatch + gr_yr_ideomatch + infch_yr_ideomatch + factor(newsid),subset=newsid<=32&elecin6==1,se="cluster",unitid=newsid)
const1 <- lm1$coef[1] + median0(c(0,lm1$coef[7:36]))
inf_ch_low <- quantile0(infch_yr,.02,subset=newsid<=32)
inf_ch_high <- quantile0(infch_yr,.98,subset=newsid<=32)
inf_ch_points <- seq(from=inf_ch_low,to=inf_ch_high,length.out=101)
unmatched3 <- const3 + lm1$coef[2] * mean0(gr_yr,subset=newsid<=32) + lm1$coef[3]*inf_ch_points
matched3 <- const3 + lm1$coef[4] + (lm1$coef[2] + lm1$coef[5]) * mean0(gr_yr,subset=newsid<=32) + (lm1$coef[3] + lm1$coef[6]) * inf_ch_points
plot(inf_ch_points,matched1,col='purple',type='l',xlab="Change in Inflation",ylab="Inflation Sentiment",ylim=c(.2,.8))
points(inf_ch_points,unmatched1,col='orange',type='l',lty=1)

# gr cov
lm1 <- lm0(gr_sh ~ gr_yr + ideomatch + gr_yr_ideomatch + factor(newsid),subset=newsid<=32&elecin6==1,se="cluster",unitid=newsid)
const1 <- lm1$coef[1] + median(c(0,lm1$coef[5:34]))
gr_low <- quantile0(gr_yr,.02,subset=newsid<=32)
gr_high <- quantile0(gr_yr,.98,subset=newsid<=32)
gr_points <- seq(from=gr_low,to=gr_high,length.out=101)
unmatched1 <- const1 + lm1$coef[2] * gr_points
matched1 <- const1 + lm1$coef[3] + (lm1$coef[2] + lm1$coef[4]) * gr_points
plot(gr_points,matched1,col='purple',type='l',ylim=c(.1,.7),xlab = "Growth",ylab="Growth Share of Coverage")
points(gr_points,unmatched1,col='orange',type='l')

# un cov
lm1 <- lm0(un_sh ~ un_yr + ideomatch + un_yr_ideomatch + factor(newsid),subset=newsid<=32&elecin6==1,se="cluster",unitid=newsid)
const1 <- lm1$coef[1] + median0(c(0,lm1$coef[5:34]))
un_low <- quantile0(un_yr,.02,subset=newsid<=32)
un_high <- quantile0(un_yr,.98,subset=newsid<=32)
un_points <- seq(from=un_low,to=un_high,length.out=101)
unmatched1 <- const1 + lm1$coef[2] * un_points
matched1 <- const1 + lm1$coef[3] + (lm1$coef[2] + lm1$coef[4]) * un_points
plot(un_points,matched1,col='purple',type='l',ylim=c(.1,.7),xlab = "Unemployment",main="Share of Coverage",ylab="Unemployment Share of Coverage")
points(un_points,unmatched1,col='orange',type='l')

# inf cov
lm1 <- lm0(inf_sh ~ inf_yr + ideomatch + inf_yr_ideomatch + factor(newsid),subset=newsid<=32&elecin6==1,se="cluster",unitid=newsid)
const1 <- lm1$coef[1] + median0(c(0,lm1$coef[5:34]))
inf_low <- quantile0(inf_yr,.02)
inf_high <- quantile0(inf_yr,.98)
inf_points <- seq(from=inf_low,to=inf_high,length.out=101)
unmatched1 <- const1 + lm1$coef[2] * inf_points
matched1 <- const1 + lm1$coef[3] + (lm1$coef[2] + lm1$coef[4]) * inf_points
plot(inf_points,matched1,col='purple',type='l',ylim=c(.1,.7),xlab = "Inflation",,ylab="Inflation Share of Coverage")
points(inf_points,unmatched1,col='orange',type='l')

# figure A4
x11()
par(mfrow=c(2,3))

# gr sent
lm1 <- lm0(gr_frac_pos_th ~ gr_yr + ideomatch + gr_yr_ideomatch + factor(newsid),subset=newsid<=32,se="cluster",unitid=newsid)
const1 <- lm1$coef[1] + median0(c(0,lm1$coef[5:34]))
gr_low <- quantile0(gr_yr,.02,subset=newsid<=32)
gr_high <- quantile0(gr_yr,.98,subset=newsid<=32)
gr_points <- seq(from=gr_low,to=gr_high,length.out=101)
unmatched1 <- const1 + lm1$coef[2] * gr_points
matched1 <- const1 + lm1$coef[3] + (lm1$coef[2] + lm1$coef[4]) * gr_points
plot(gr_points,matched1,col='purple',type='l',xlab="Growth",ylab="Growth Sentiment",ylim=c(.2,.8))
points(gr_points,unmatched1,col='orange',type='l')
legend("top",c("Matched Ideo.","Unmatched Ideo."),col=c('purple','orange'),lty=c(1,1),bty='n')

# un sent
lm1 <- lm0(un_frac_pos_th ~ gr_yr + unch_yr + ideomatch + gr_yr_ideomatch + unch_yr_ideomatch + factor(newsid),subset=newsid<=32,se="cluster",unitid=newsid)
const1 <- lm1$coef[1] + median0(c(0,lm1$coef[7:36]))
un_ch_low <- quantile0(unch_yr,.02,subset=newsid<=32)
un_ch_high <- quantile0(unch_yr,.98,subset=newsid<=32)
un_ch_points <- seq(from=un_ch_low,to=un_ch_high,length.out=101)
unmatched1 <- const1 + lm1$coef[2] * mean0(gr_yr,subset=newsid<=32) + lm1$coef[3]*un_ch_points
matched1 <- const1 + lm1$coef[4] + (lm1$coef[2] + lm1$coef[5]) * mean0(gr_yr,newsid<=32) + (lm1$coef[3] + lm1$coef[6]) * un_ch_points
plot(un_ch_points,matched1,col='purple',type='l',xlab="Change in Unemployment",ylab="Unemployment Sentiment",ylim=c(.2,.8),main="Sentiment")
points(un_ch_points,unmatched1,col='orange',type='l')

# inf sent
lm1 <- lm0(inf_frac_pos_th ~ gr_yr + infch_yr + ideomatch + gr_yr_ideomatch + infch_yr_ideomatch + factor(newsid),subset=newsid<=32,se="cluster",unitid=newsid)
const1 <- lm1$coef[1] + median0(c(0,lm1$coef[7:36]))
inf_ch_low <- quantile0(infch_yr,.02,subset=newsid<=32)
inf_ch_high <- quantile0(infch_yr,.98,subset=newsid<=32)
inf_ch_points <- seq(from=inf_ch_low,to=inf_ch_high,length.out=101)
unmatched3 <- const3 + lm1$coef[2] * mean0(gr_yr,subset=newsid<=32) + lm1$coef[3]*inf_ch_points
matched3 <- const3 + lm1$coef[4] + (lm1$coef[2] + lm1$coef[5]) * mean0(gr_yr,subset=newsid<=32) + (lm1$coef[3] + lm1$coef[6]) * inf_ch_points
plot(inf_ch_points,matched1,col='purple',type='l',xlab="Change in Inflation",ylab="Inflation Sentiment",ylim=c(.2,.8))
points(inf_ch_points,unmatched1,col='orange',type='l',lty=1)

# gr cov
lm1 <- lm0(gr_sh_th ~ gr_yr + ideomatch + gr_yr_ideomatch + factor(newsid),subset=newsid<=32,se="cluster",unitid=newsid)
const1 <- lm1$coef[1] + median(c(0,lm1$coef[5:34]))
gr_low <- quantile0(gr_yr,.02,subset=newsid<=32)
gr_high <- quantile0(gr_yr,.98,subset=newsid<=32)
gr_points <- seq(from=gr_low,to=gr_high,length.out=101)
unmatched1 <- const1 + lm1$coef[2] * gr_points
matched1 <- const1 + lm1$coef[3] + (lm1$coef[2] + lm1$coef[4]) * gr_points
plot(gr_points,matched1,col='purple',type='l',ylim=c(.1,.7),xlab = "Growth",ylab="Growth Share of Coverage")
points(gr_points,unmatched1,col='orange',type='l')

# un cov
lm1 <- lm0(un_sh_th ~ un_yr + ideomatch + un_yr_ideomatch + factor(newsid),subset=newsid<=32,se="cluster",unitid=newsid)
const1 <- lm1$coef[1] + median0(c(0,lm1$coef[5:34]))
un_low <- quantile0(un_yr,.02,subset=newsid<=32)
un_high <- quantile0(un_yr,.98,subset=newsid<=32)
un_points <- seq(from=un_low,to=un_high,length.out=101)
unmatched1 <- const1 + lm1$coef[2] * un_points
matched1 <- const1 + lm1$coef[3] + (lm1$coef[2] + lm1$coef[4]) * un_points
plot(un_points,matched1,col='purple',type='l',ylim=c(.1,.7),xlab = "Unemployment",main="Share of Coverage",ylab="Unemployment Share of Coverage")
points(un_points,unmatched1,col='orange',type='l')

# inf cov
lm1 <- lm0(inf_sh_th ~ inf_yr + ideomatch + inf_yr_ideomatch + factor(newsid),subset=newsid<=32,se="cluster",unitid=newsid)
const1 <- lm1$coef[1] + median0(c(0,lm1$coef[5:34]))
inf_low <- quantile0(inf_yr,.02)
inf_high <- quantile0(inf_yr,.98)
inf_points <- seq(from=inf_low,to=inf_high,length.out=101)
unmatched1 <- const1 + lm1$coef[2] * inf_points
matched1 <- const1 + lm1$coef[3] + (lm1$coef[2] + lm1$coef[4]) * inf_points
plot(inf_points,matched1,col='purple',type='l',ylim=c(.1,.7),xlab = "Inflation",,ylab="Inflation Share of Coverage")
points(inf_points,unmatched1,col='orange',type='l')

# figure A5
x11()
par(mfrow=c(2,3))

# gr sent
lm1 <- logit0(gr_ratpn  ~ gr_yr2 + ideomatch2 + gr_yr_ideomatch2 + factor(newsid2),subset=type=="articles"&train==0,unitid=newsid2,se="cluster")
const1 <- lm1$coef[1] + median0(c(0,lm1$coef[5:29]))
gr_low <- quantile0(gr_yr,.02,subset=newsid<=32)
gr_high <- quantile0(gr_yr,.98,subset=newsid<=32)
gr_points <- seq(from=gr_low,to=gr_high,length.out=101)
unmatched1 <- inv.logit(const1 + lm1$coef[2] * gr_points)
matched1 <- inv.logit(const1 + lm1$coef[3] + (lm1$coef[2] + lm1$coef[4]) * gr_points)
plot(gr_points,matched1,col='purple',type='l',xlab="Growth",ylab="Growth Sentiment",ylim=c(0,1))
points(gr_points,unmatched1,col='orange',type='l')
legend("top",c("Matched Ideo.","Unmatched Ideo."),col=c('purple','orange'),lty=c(1,1),bty='n')

# un sent
lm1 <- logit0(un_ratpn ~ gr_yr2 + unch_yr2  + ideomatch2 + gr_yr_ideomatch2 + unch_yr_ideomatch2 + factor(newsid2),subset=type=="articles"&train==0,unitid=newsid2,se="cluster")
const1 <- lm1$coef[1] + median0(c(0,lm1$coef[7:30]))
un_ch_low <- quantile0(unch_yr,.02,subset=newsid<=32)
un_ch_high <- quantile0(unch_yr,.98,subset=newsid<=32)
un_ch_points <- seq(from=un_ch_low,to=un_ch_high,length.out=101)
unmatched1 <- inv.logit(const1 + lm1$coef[2] * mean0(gr_yr,subset=newsid<=32) + lm1$coef[3]*un_ch_points)
matched1 <- inv.logit(const1 + lm1$coef[4] + (lm1$coef[2] + lm1$coef[5]) * mean0(gr_yr,newsid<=32) + (lm1$coef[3] + lm1$coef[6]) * un_ch_points)
plot(un_ch_points,matched1,col='purple',type='l',xlab="Change in Unemployment",ylab="Unemployment Sentiment",ylim=c(0,1),main="Sentiment")
points(un_ch_points,unmatched1,col='orange',type='l')

# inf sent
lm1 <- logit0(inf_ratpn ~ gr_yr2 + infch_yr2 + ideomatch2 + gr_yr_ideomatch2 + infch_yr_ideomatch2 + factor(newsid2),subset=type=="articles"&train==0,unitid=newsid2,se="cluster")
const1 <- lm1$coef[1] + median0(c(0,lm1$coef[7:26]))
inf_ch_low <- quantile0(infch_yr,.02,subset=newsid<=32)
inf_ch_high <- quantile0(infch_yr,.98,subset=newsid<=32)
inf_ch_points <- seq(from=inf_ch_low,to=inf_ch_high,length.out=101)
unmatched3 <- inv.logit(const3 + lm1$coef[2] * mean0(gr_yr,subset=newsid<=32) + lm1$coef[3]*inf_ch_points)
matched3 <- inv.logit(const3 + lm1$coef[4] + (lm1$coef[2] + lm1$coef[5]) * mean0(gr_yr,subset=newsid<=32) + (lm1$coef[3] + lm1$coef[6]) * inf_ch_points)
plot(inf_ch_points,matched1,col='purple',type='l',xlab="Change in Inflation",ylab="Inflation Sentiment",ylim=c(0,1))
points(inf_ch_points,unmatched1,col='orange',type='l',lty=1)

# gr cov
lm1 <- logit0(gr_ratn6 ~ gr_yr2 + ideomatch2 + gr_yr_ideomatch2 + factor(newsid2),subset=type=="articles"&train==0,unitid=newsid2,se="cluster")
const1 <- lm1$coef[1] + median(c(0,lm1$coef[5:29]))
gr_low <- quantile0(gr_yr,.02,subset=newsid<=32)
gr_high <- quantile0(gr_yr,.98,subset=newsid<=32)
gr_points <- seq(from=gr_low,to=gr_high,length.out=101)
unmatched1 <- inv.logit(const1 + lm1$coef[2] * gr_points)
matched1 <- inv.logit(const1 + lm1$coef[3] + (lm1$coef[2] + lm1$coef[4]) * gr_points)
plot(gr_points,matched1,col='purple',type='l',ylim=c(0,1),xlab = "Growth",ylab="Growth Share of Coverage")
points(gr_points,unmatched1,col='orange',type='l')

# un cov
lm1 <- logit0(un_ratn6 ~ un_yr2 + ideomatch2 + un_yr_ideomatch2 + factor(newsid2),subset=type=="articles"&train==0,unitid=newsid2,se="cluster")
const1 <- lm1$coef[1] + median0(c(0,lm1$coef[5:29]))
un_low <- quantile0(un_yr,.02,subset=newsid<=32)
un_high <- quantile0(un_yr,.98,subset=newsid<=32)
un_points <- seq(from=un_low,to=un_high,length.out=101)
unmatched1 <- inv.logit(const1 + lm1$coef[2] * un_points)
matched1 <- inv.logit(const1 + lm1$coef[3] + (lm1$coef[2] + lm1$coef[4]) * un_points)
plot(un_points,matched1,col='purple',type='l',ylim=c(0,1),xlab = "Unemployment",main="Share of Coverage",ylab="Unemployment Share of Coverage")
points(un_points,unmatched1,col='orange',type='l')

# inf cov
lm1 <- logit0(inf_ratn6 ~ inf_yr2 + ideomatch2 + inf_yr_ideomatch2 + factor(newsid2),subset=type=="articles"&train==0,unitid=newsid2,se="cluster")
const1 <- lm1$coef[1] + median0(c(0,lm1$coef[5:29]))
inf_low <- quantile0(inf_yr,.02)
inf_high <- quantile0(inf_yr,.98)
inf_points <- seq(from=inf_low,to=inf_high,length.out=101)
unmatched1 <- inv.logit(const1 + lm1$coef[2] * inf_points)
matched1 <- inv.logit(const1 + lm1$coef[3] + (lm1$coef[2] + lm1$coef[4]) * inf_points)
plot(inf_points,matched1,col='purple',type='l',ylim=c(0,1),xlab = "Inflation",,ylab="Inflation Share of Coverage")
points(inf_points,unmatched1,col='orange',type='l')
